@@ -160,6 +160,12 @@ mpz & mpz::operator*=(unsigned u) { mpz_mul_ui(m_val, m_val, u); return *this; }
 
 mpz & mpz::operator*=(int u) { mpz_mul_si(m_val, m_val, u); return *this; }
 
+mpz mpz::divexact(mpz const & n, mpz const & d) {
+    mpz q;
+    mpz_divexact(q.m_val, n.m_val, d.m_val);
+    return q;
+}
+
 mpz mpz::ediv(mpz const & n, mpz const & d) {
     mpz q;
     mpz_t r;
@@ -241,36 +247,46 @@ void div2k(mpz & a, mpz const & b, unsigned k) {
 
 uint8 mpz::mod8() const {
     mpz a;
-    mpz_tdiv_r_2exp(a.m_val, m_val, 8);
+    mpz_fdiv_r_2exp(a.m_val, m_val, 8);
     return static_cast<uint8>(a.get_unsigned_int());
 }
 
 uint16 mpz::mod16() const {
     mpz a;
-    mpz_tdiv_r_2exp(a.m_val, m_val, 16);
+    mpz_fdiv_r_2exp(a.m_val, m_val, 16);
     return static_cast<uint16>(a.get_unsigned_int());
 }
 
 uint32 mpz::mod32() const {
     mpz a;
-    mpz_tdiv_r_2exp(a.m_val, m_val, 32);
+    mpz_fdiv_r_2exp(a.m_val, m_val, 32);
     return static_cast<uint32>(a.get_unsigned_int());
 }
 
 uint64 mpz::mod64() const {
     mpz r;
-    mpz_tdiv_r_2exp(r.m_val, m_val, 64);
+    mpz_fdiv_r_2exp(r.m_val, m_val, 64);
     mpz l;
-    mpz_tdiv_r_2exp(l.m_val, r.m_val, 32);
+    mpz_fdiv_r_2exp(l.m_val, r.m_val, 32);
     mpz h;
-    mpz_tdiv_q_2exp(h.m_val, r.m_val, 32);
+    mpz_fdiv_q_2exp(h.m_val, r.m_val, 32);
     return (static_cast<uint64>(h.get_unsigned_int()) << 32) + static_cast<uint64>(l.get_unsigned_int());
 }
 
 int8 mpz::smod8() const {
-    mpz a;
-    mpz_tdiv_r_2exp(a.m_val, m_val, 8);
-    return static_cast<int8>(a.get_int());
+    return static_cast<int8>(mod8());
+}
+
+int16 mpz::smod16() const {
+    return static_cast<int16>(mod16());
+}
+
+int32 mpz::smod32() const {
+    return static_cast<int32>(mod32());
+}
+
+int64 mpz::smod64() const {
+    return static_cast<int64>(mod64());
 }
 
 void power(mpz & a, mpz const & b, unsigned k) {
@@ -305,6 +321,8 @@ std::ostream & operator<<(std::ostream & out, mpz const & v) {
 static void *mpz_alloc(size_t size) {
 #ifdef LEAN_SMALL_ALLOCATOR
     return alloc(size);
+#elif defined(LEAN_MIMALLOC)
+    return mi_malloc(size);
 #else
     return malloc(size);
 #endif
@@ -313,8 +331,10 @@ static void *mpz_alloc(size_t size) {
 static void mpz_dealloc(void *ptr, size_t size) {
 #ifdef LEAN_SMALL_ALLOCATOR
         dealloc(ptr, size);
+#elif defined(LEAN_MIMALLOC)
+        mi_free_size(ptr, size);
 #else
-        free(ptr);
+        free_sized(ptr, size);
 #endif
 }
 
@@ -743,6 +763,10 @@ mpz & mpz::operator%=(mpz const & o) {
     return rem(o.m_size, o.m_digits);
 }
 
+mpz mpz::divexact(mpz const & n, mpz const & d) {
+    return n / d;
+}
+
 mpz mpz::ediv(mpz const & n, mpz const & d) {
     if (d.m_size > n.m_size) {
         if (n.is_neg()) {
@@ -952,30 +976,57 @@ void div2k(mpz & a, mpz const & b, unsigned k) {
 }
 
 uint8 mpz::mod8() const {
-    return static_cast<uint8>(m_digits[0] & 0xFFu);
+    uint8 ret = static_cast<uint8>(m_digits[0] & 0xFFu);
+    if (m_sign) {
+        ret = -ret;
+    }
+    return ret;
 }
 
 uint16 mpz::mod16() const {
-    return static_cast<uint16>(m_digits[0] & 0xFFFFu);
+    uint16 ret = static_cast<uint16>(m_digits[0] & 0xFFFFu);
+    if (m_sign) {
+        ret = -ret;
+    }
+    return ret;
 }
 
 uint32 mpz::mod32() const {
-    return static_cast<uint32>(m_digits[0]);
+    uint32 ret = static_cast<uint32>(m_digits[0]);
+    if (m_sign) {
+        ret = -ret;
+    }
+    return ret;
 }
 
 uint64 mpz::mod64() const {
-    if (m_size == 1)
-        return m_digits[0];
-    else
-        return m_digits[0] + (static_cast<uint64>(m_digits[1]) << 8*sizeof(mpn_digit));
+    uint64 ret;
+    if (m_size == 1) {
+        ret = m_digits[0];
+    }
+    else {
+        ret = m_digits[0] + (static_cast<uint64>(m_digits[1]) << 8*sizeof(mpn_digit));
+    }
+    if (m_sign) {
+        ret = -ret;
+    }
+    return ret;
 }
 
 int8 mpz::smod8() const {
-    int8_t val = mod8();
-    if (m_sign) {
-        val = -val;
-    }
-    return val;
+    return static_cast<int8>(mod8());
+}
+
+int16 mpz::smod16() const {
+    return static_cast<int16>(mod16());
+}
+
+int32 mpz::smod32() const {
+    return static_cast<int32>(mod32());
+}
+
+int64 mpz::smod64() const {
+    return static_cast<int64>(mod64());
 }
 
 void power(mpz & a, mpz const & b, unsigned k) {
