@@ -5,6 +5,7 @@ Released under Apache 2.0 license as described in the file LICENSE.
 Authors: Leonardo de Moura, Sebastian Ullrich
 */
 #if defined(LEAN_WINDOWS)
+#include <icu.h>
 #include <windows.h>
 #include <io.h>
 #define NOMINMAX // prevent ntdef.h from defining min/max macros
@@ -47,6 +48,7 @@ Authors: Leonardo de Moura, Sebastian Ullrich
 #include "runtime/object.h"
 #include "runtime/thread.h"
 #include "runtime/allocprof.h"
+#include "runtime/option_ref.h"
 
 #ifdef _MSC_VER
 #define S_ISDIR(mode) ((mode & _S_IFDIR) != 0)
@@ -305,7 +307,7 @@ extern "C" LEAN_EXPORT obj_res lean_decode_uv_error(int errnum, b_obj_arg fname)
     /* LibUV does not map ECHILD as of version 1.48.0 */
     case UV_ENXIO: case UV_EHOSTUNREACH: case UV_ENETUNREACH:
     case UV_ECONNREFUSED:
-#if UV_VERSION_HEX >= 0x014500
+#if UV_VERSION_HEX >= 0x012D00
     case UV_ENODATA:
 #endif
     case UV_ESRCH:
@@ -360,9 +362,19 @@ extern "C" LEAN_EXPORT obj_res lean_decode_uv_error(int errnum, b_obj_arg fname)
     }
 }
 
-/* IO.setAccessRights (filename : @& String) (mode : UInt32) : IO Handle */
+// Used for when you try to convert a string with NUL bytes into a C string
+obj_res mk_embedded_nul_error(b_obj_arg str) {
+    lean_inc(str);
+    return io_result_mk_error(lean_mk_io_error_invalid_argument_file(str, EINVAL, mk_string("string contains NUL bytes")));
+}
+
+/* IO.setAccessRights (filename : @& String) (mode : UInt32) : IO Unit */
 extern "C" LEAN_EXPORT obj_res lean_chmod (b_obj_arg filename, uint32_t mode, obj_arg /* w */) {
-    if (!chmod(lean_string_cstr(filename), mode)) {
+    const char* fname = string_cstr(filename);
+    if (strlen(fname) != lean_string_size(filename) - 1) {
+        return mk_embedded_nul_error(filename);
+    }
+    if (!chmod(fname, mode)) {
         return io_result_mk_ok(box(0));
     } else {
         return io_result_mk_error(decode_io_error(errno, filename));
@@ -388,7 +400,11 @@ extern "C" LEAN_EXPORT obj_res lean_io_prim_handle_mk(b_obj_arg filename, uint8
     case 3: flags |= O_RDWR; break;  // readWrite
     case 4: flags |= O_WRONLY | O_CREAT | O_APPEND; break;  // append
     }
-    int fd = open(lean_string_cstr(filename), flags, 0666);
+    const char* fname = string_cstr(filename);
+    if (strlen(fname) != lean_string_size(filename) - 1) {
+        return mk_embedded_nul_error(filename);
+    }
+    int fd = open(fname, flags, 0666);
     if (fd == -1) {
         return io_result_mk_error(decode_io_error(errno, filename));
     }
@@ -630,6 +646,176 @@ extern "C" LEAN_EXPORT obj_res lean_io_prim_handle_put_str(b_obj_arg h, b_obj_ar
     }
 }
 
+/* Std.Time.Timestamp.now : IO Timestamp */
+extern "C" LEAN_EXPORT obj_res lean_get_current_time(obj_arg /* w */) {
+    using namespace std::chrono;
+
+    std::chrono::system_clock::time_point now = std::chrono::system_clock::now();
+    long long timestamp = std::chrono::duration_cast<std::chrono::nanoseconds>(now.time_since_epoch()).count();
+
+    long long secs = timestamp / 1000000000;
+    long long nano = timestamp % 1000000000;
+
+    lean_object *lean_ts = lean_alloc_ctor(0, 2, 0);
+    lean_ctor_set(lean_ts, 0, lean_int64_to_int(secs));
+    lean_ctor_set(lean_ts, 1, lean_int64_to_int(nano));
+
+    return lean_io_result_mk_ok(lean_ts);
+}
+
+/* Std.Time.Database.Windows.getNextTransition : @&String -> Int64 -> Bool -> IO (Option (Int64 × TimeZone)) */
+extern "C" LEAN_EXPORT obj_res lean_windows_get_next_transition(b_obj_arg timezone_str, uint64_t tm_obj, uint8 default_time, obj_arg /* w */) {
+#if defined(LEAN_WINDOWS)
+    UErrorCode status = U_ZERO_ERROR;
+    const char* dst_name_id = lean_string_cstr(timezone_str);
+
+    UChar tzID[256];
+    u_strFromUTF8(tzID, sizeof(tzID) / sizeof(tzID[0]), NULL, dst_name_id, lean_string_size(timezone_str) - 1, &status);
+
+    if (U_FAILURE(status)) {
+        return lean_io_result_mk_error(lean_mk_io_error_invalid_argument(EINVAL, mk_string("failed to read identifier")));
+    }
+
+    UCalendar *cal = ucal_open(tzID, -1, NULL, UCAL_GREGORIAN, &status);
+
+    if (U_FAILURE(status)) {
+        ucal_close(cal);
+        return lean_io_result_mk_error(lean_mk_io_error_invalid_argument(EINVAL, mk_string("failed to open calendar")));
+    }
+
+    int64_t tm = 0;
+
+    if (!default_time) {
+        int64_t timestamp_secs = (int64_t)tm_obj;
+
+        ucal_setMillis(cal, timestamp_secs * 1000, &status);
+        if (U_FAILURE(status)) {
+            ucal_close(cal);
+            return lean_io_result_mk_error(lean_mk_io_error_invalid_argument(EINVAL, mk_string("failed to set calendar time")));
+        }
+
+        UDate nextTransition;
+        if (!ucal_getTimeZoneTransitionDate(cal, UCAL_TZ_TRANSITION_NEXT, &nextTransition, &status)) {
+            ucal_close(cal);
+            return io_result_mk_ok(mk_option_none());
+        }
+
+        if (U_FAILURE(status)) {
+            ucal_close(cal);
+            return lean_io_result_mk_error(lean_mk_io_error_invalid_argument(EINVAL, mk_string("failed to get next transition")));
+        }
+
+        tm = (int64_t)(nextTransition / 1000.0);
+    }
+
+    int32_t dst_offset = ucal_get(cal, UCAL_DST_OFFSET, &status);
+
+    if (U_FAILURE(status)) {
+        ucal_close(cal);
+        return lean_io_result_mk_error(lean_mk_io_error_invalid_argument(EINVAL, mk_string("failed to get dst_offset")));
+    }
+
+    int is_dst = dst_offset != 0;
+
+    int32_t tzIDLength = ucal_getTimeZoneDisplayName(cal, is_dst ? UCAL_DST : UCAL_STANDARD, "en_US", tzID, 32, &status);
+
+    if (U_FAILURE(status)) {
+        ucal_close(cal);
+        return lean_io_result_mk_error(lean_mk_io_error_invalid_argument(EINVAL, mk_string("failed to timezone identifier")));
+    }
+
+    char dst_name[256];
+    int32_t dst_name_len;
+    u_strToUTF8(dst_name, sizeof(dst_name), &dst_name_len, tzID, tzIDLength, &status);
+
+    if (U_FAILURE(status)) {
+        return lean_io_result_mk_error(lean_mk_io_error_invalid_argument(EINVAL, mk_string("failed to convert DST name to UTF-8")));
+    }
+
+    UChar display_name[32];
+    int32_t display_name_len = ucal_getTimeZoneDisplayName(cal, is_dst ? UCAL_SHORT_DST : UCAL_SHORT_STANDARD, "en_US", display_name, 32, &status);
+
+    if (U_FAILURE(status)) {
+        ucal_close(cal);
+        return lean_io_result_mk_error(lean_mk_io_error_invalid_argument(EINVAL, mk_string("failed to read abbreaviation")));
+    }
+
+    char display_name_str[256];
+    int32_t display_name_str_len;
+    u_strToUTF8(display_name_str, sizeof(display_name_str), &display_name_str_len, display_name, display_name_len, &status);
+
+    if (U_FAILURE(status)) {
+        ucal_close(cal);
+        return lean_io_result_mk_error(lean_mk_io_error_invalid_argument(EINVAL, mk_string("failed to get abbreviation to cstr")));
+    }
+
+    int32_t zone_offset = ucal_get(cal, UCAL_ZONE_OFFSET, &status);
+    zone_offset += dst_offset;
+
+    if (U_FAILURE(status)) {
+        ucal_close(cal);
+        return lean_io_result_mk_error(lean_mk_io_error_invalid_argument(EINVAL, mk_string("failed to get zone_offset")));
+    }
+
+    ucal_close(cal);
+
+    int offset_seconds = zone_offset / 1000;
+
+    lean_object *lean_tz = lean_alloc_ctor(0, 3, 1);
+    lean_ctor_set(lean_tz, 0, lean_int_to_int(offset_seconds));
+    lean_ctor_set(lean_tz, 1, lean_mk_string_from_bytes_unchecked(dst_name, dst_name_len));
+    lean_ctor_set(lean_tz, 2, lean_mk_string_from_bytes_unchecked(display_name_str, display_name_str_len));
+    lean_ctor_set_uint8(lean_tz, sizeof(void*)*3, is_dst);
+
+    lean_object *lean_pair = lean_alloc_ctor(0, 2, 0);
+    lean_ctor_set(lean_pair, 0, lean_box_uint64((uint64_t)tm));
+    lean_ctor_set(lean_pair, 1, lean_tz);
+
+    return lean_io_result_mk_ok(mk_option_some(lean_pair));
+#else
+    return lean_io_result_mk_error(lean_mk_io_error_invalid_argument(EINVAL, mk_string("failed to get timezone, its windows only.")));
+#endif
+}
+
+/* Std.Time.Database.Windows.getLocalTimeZoneIdentifierAt : Int64 → IO String */
+extern "C" LEAN_EXPORT obj_res lean_get_windows_local_timezone_id_at(uint64_t tm_obj, obj_arg /* w */) {
+#if defined(LEAN_WINDOWS)
+    UErrorCode status = U_ZERO_ERROR;
+    UCalendar* cal = ucal_open(NULL, -1, NULL, UCAL_GREGORIAN, &status);
+
+    if (U_FAILURE(status)) {
+        return lean_io_result_mk_error(lean_mk_io_error_invalid_argument(EINVAL, mk_string("failed to open calendar")));
+    }
+
+    int64_t timestamp_secs = (int64_t)tm_obj;
+    ucal_setMillis(cal, timestamp_secs * 1000, &status);
+
+    if (U_FAILURE(status)) {
+        ucal_close(cal);
+        return lean_io_result_mk_error(lean_mk_io_error_invalid_argument(EINVAL, mk_string("failed to set calendar time")));
+    }
+
+    UChar tzId[256];
+    int32_t tzIdLength = ucal_getTimeZoneID(cal, tzId, sizeof(tzId) / sizeof(tzId[0]), &status);
+    ucal_close(cal);
+
+    if (U_FAILURE(status)) {
+        return lean_io_result_mk_error(lean_mk_io_error_invalid_argument(EINVAL, mk_string("failed to get timezone ID")));
+    }
+
+    char tzIdStr[256];
+    u_strToUTF8(tzIdStr, sizeof(tzIdStr), NULL, tzId, tzIdLength, &status);
+
+    if (U_FAILURE(status)) {
+        return lean_io_result_mk_error(lean_mk_io_error_invalid_argument(EINVAL, mk_string("failed to convert timezone ID to UTF-8")));
+    }
+
+    return lean_io_result_mk_ok(lean_mk_ascii_string_unchecked(tzIdStr));
+#else
+    return lean_io_result_mk_error(lean_mk_io_error_invalid_argument(EINVAL, mk_string("timezone retrieval is Windows-only")));
+#endif
+}
+
 /* monoMsNow : BaseIO Nat */
 extern "C" LEAN_EXPORT obj_res lean_io_mono_ms_now(obj_arg /* w */) {
     static_assert(sizeof(std::chrono::milliseconds::rep) <= sizeof(uint64), "size of std::chrono::nanoseconds::rep may not exceed 64");
@@ -741,13 +927,18 @@ extern "C" LEAN_EXPORT obj_res lean_io_get_num_heartbeats(obj_arg /* w */) {
     return io_result_mk_ok(lean_uint64_to_nat(get_num_heartbeats()));
 }
 
-/* addHeartbeats (count : Int64) : BaseIO Unit */
-extern "C" LEAN_EXPORT obj_res lean_io_add_heartbeats(int64_t count, obj_arg /* w */) {
-    add_heartbeats(count);
+/* setHeartbeats (count : Nat) : BaseIO Unit */
+extern "C" LEAN_EXPORT obj_res lean_io_set_heartbeats(obj_arg count, obj_arg /* w */) {
+    set_heartbeats(lean_uint64_of_nat(count));
+    lean_dec(count);
     return io_result_mk_ok(box(0));
 }
 
 extern "C" LEAN_EXPORT obj_res lean_io_getenv(b_obj_arg env_var, obj_arg) {
+    const char* env_var_str = string_cstr(env_var);
+    if (strlen(env_var_str) != lean_string_size(env_var) - 1) {
+        return io_result_mk_ok(mk_option_none());
+    }
 #if defined(LEAN_EMSCRIPTEN)
     // HACK(WN): getenv doesn't seem to work in Emscripten even though it should
     // see https://emscripten.org/docs/porting/connecting_cpp_and_javascript/Interacting-with-code.html#interacting-with-code-environment-variables
@@ -762,7 +953,7 @@ extern "C" LEAN_EXPORT obj_res lean_io_getenv(b_obj_arg env_var, obj_arg) {
         } else {
             return 0;
         }
-    }, string_cstr(env_var)));
+    }, env_var_str));
 
     if (val) {
         object * valLean = mk_string(val);
@@ -772,7 +963,7 @@ extern "C" LEAN_EXPORT obj_res lean_io_getenv(b_obj_arg env_var, obj_arg) {
         return io_result_mk_ok(mk_option_none());
     }
 #else
-    char * val = std::getenv(string_cstr(env_var));
+    char * val = std::getenv(env_var_str);
     if (val) {
         return io_result_mk_ok(mk_option_some(mk_string(val)));
     } else {
@@ -781,32 +972,56 @@ extern "C" LEAN_EXPORT obj_res lean_io_getenv(b_obj_arg env_var, obj_arg) {
 #endif
 }
 
-extern "C" LEAN_EXPORT obj_res lean_io_realpath(obj_arg fname, obj_arg) {
+extern "C" LEAN_EXPORT obj_res lean_io_realpath(obj_arg filename, obj_arg) {
+    const char* fname = string_cstr(filename);
+    if (strlen(fname) != lean_string_size(filename) - 1) {
+        obj_res res = mk_embedded_nul_error(filename);
+        dec_ref(filename);
+        return res;
+    }
 #if defined(LEAN_WINDOWS)
     constexpr unsigned BufferSize = 8192;
     char buffer[BufferSize];
-    DWORD retval = GetFullPathName(string_cstr(fname), BufferSize, buffer, nullptr);
+    HANDLE handle = CreateFile(fname, 0, FILE_SHARE_READ, NULL, OPEN_EXISTING, FILE_FLAG_BACKUP_SEMANTICS, NULL);
+    if (handle == INVALID_HANDLE_VALUE) {
+        obj_res res = mk_file_not_found_error(filename);
+        dec_ref(filename);
+        return res;
+    }
+    DWORD retval = GetFinalPathNameByHandle(handle, buffer, BufferSize, 0);
+    CloseHandle(handle);
     if (retval == 0 || retval > BufferSize) {
-        return io_result_mk_ok(fname);
+        return io_result_mk_ok(filename);
     } else {
-        dec_ref(fname);
+        dec_ref(filename);
+        char * res = buffer;
+        if (memcmp(res, "\\\\?\\", 4) == 0) {
+            if (memcmp(res + 4, "UNC\\", 4) == 0) {
+                // network path: convert "\\\\?\\UNC\\..." to "\\\\..."
+                res[6] = '\\';
+                res += 6;
+            } else {
+                // simple path: convert "\\\\?\\C:\\.." to "C:\\..."
+                res += 4;
+            }
+        }
         // Hack for making sure disk is lower case
         // TODO(Leo): more robust solution
-        if (strlen(buffer) >= 2 && buffer[1] == ':') {
-            buffer[0] = tolower(buffer[0]);
+        if (strlen(res) >= 2 && res[1] == ':') {
+            res[0] = tolower(res[0]);
         }
-        return io_result_mk_ok(mk_string(buffer));
+        return io_result_mk_ok(mk_string(res));
     }
 #else
     char buffer[PATH_MAX];
-    char * tmp = realpath(string_cstr(fname), buffer);
+    char * tmp = realpath(fname, buffer);
     if (tmp) {
         obj_res s = mk_string(tmp);
-        dec_ref(fname);
+        dec_ref(filename);
         return io_result_mk_ok(s);
     } else {
-        obj_res res = mk_file_not_found_error(fname);
-        dec_ref(fname);
+        obj_res res = mk_file_not_found_error(filename);
+        dec_ref(filename);
         return res;
     }
 #endif
@@ -820,8 +1035,12 @@ structure DirEntry where
 constant readDir : @& FilePath → IO (Array DirEntry)
 */
 extern "C" LEAN_EXPORT obj_res lean_io_read_dir(b_obj_arg dirname, obj_arg) {
+    const char* dirname_ptr = string_cstr(dirname);
+    if (strlen(dirname_ptr) != lean_string_size(dirname) - 1) {
+        return mk_embedded_nul_error(dirname);
+    }
     object * arr = array_mk_empty();
-    DIR * dp = opendir(string_cstr(dirname));
+    DIR * dp = opendir(dirname_ptr);
     if (!dp) {
         return io_result_mk_error(decode_io_error(errno, dirname));
     }
@@ -866,11 +1085,7 @@ static obj_res timespec_to_obj(timespec const & ts) {
     return o;
 }
 
-extern "C" LEAN_EXPORT obj_res lean_io_metadata(b_obj_arg fname, obj_arg) {
-    struct stat st;
-    if (stat(string_cstr(fname), &st) != 0) {
-        return io_result_mk_error(decode_io_error(errno, fname));
-    }
+static obj_res metadata_core(struct stat const & st) {
     object * mdata = alloc_cnstr(0, 2, sizeof(uint64) + sizeof(uint8));
 #ifdef __APPLE__
     cnstr_set(mdata, 0, timespec_to_obj(st.st_atimespec));
@@ -894,11 +1109,43 @@ extern "C" LEAN_EXPORT obj_res lean_io_metadata(b_obj_arg fname, obj_arg) {
     return io_result_mk_ok(mdata);
 }
 
-extern "C" LEAN_EXPORT obj_res lean_io_create_dir(b_obj_arg p, obj_arg) {
+extern "C" LEAN_EXPORT obj_res lean_io_metadata(b_obj_arg filename, obj_arg) {
+    const char* fname = string_cstr(filename);
+    if (strlen(fname) != lean_string_size(filename) - 1) {
+        return mk_embedded_nul_error(filename);
+    }
+    struct stat st;
+    if (stat(fname, &st) != 0) {
+        return io_result_mk_error(decode_io_error(errno, filename));
+    }
+    return metadata_core(st);
+}
+
+extern "C" LEAN_EXPORT obj_res lean_io_symlink_metadata(b_obj_arg filename, obj_arg) {
 #ifdef LEAN_WINDOWS
-    if (mkdir(string_cstr(p)) == 0) {
+    return lean_io_metadata(filename, io_mk_world());
 #else
-    if (mkdir(string_cstr(p), 0777) == 0) {
+    const char* fname = string_cstr(filename);
+    if (strlen(fname) != lean_string_size(filename) - 1) {
+        return mk_embedded_nul_error(filename);
+    }
+    struct stat st;
+    if (lstat(string_cstr(filename), &st) != 0) {
+        return io_result_mk_error(decode_io_error(errno, filename));
+    }
+    return metadata_core(st);
+#endif
+}
+
+extern "C" LEAN_EXPORT obj_res lean_io_create_dir(b_obj_arg p, obj_arg) {
+    const char* str = string_cstr(p);
+    if (strlen(str) != lean_string_size(p) - 1) {
+        return mk_embedded_nul_error(p);
+    }
+#ifdef LEAN_WINDOWS
+    if (mkdir(str) == 0) {
+#else
+    if (mkdir(str, 0777) == 0) {
 #endif
         return io_result_mk_ok(box(0));
     } else {
@@ -907,7 +1154,11 @@ extern "C" LEAN_EXPORT obj_res lean_io_create_dir(b_obj_arg p, obj_arg) {
 }
 
 extern "C" LEAN_EXPORT obj_res lean_io_remove_dir(b_obj_arg p, obj_arg) {
-    if (rmdir(string_cstr(p)) == 0) {
+    const char* str = string_cstr(p);
+    if (strlen(str) != lean_string_size(p) - 1) {
+        return mk_embedded_nul_error(p);
+    }
+    if (rmdir(str) == 0) {
         return io_result_mk_ok(box(0));
     } else {
         return io_result_mk_error(decode_io_error(errno, p));
@@ -915,21 +1166,30 @@ extern "C" LEAN_EXPORT obj_res lean_io_remove_dir(b_obj_arg p, obj_arg) {
 }
 
 extern "C" LEAN_EXPORT obj_res lean_io_rename(b_obj_arg from, b_obj_arg to, lean_object * /* w */) {
+    const char* from_str = string_cstr(from);
+    if (strlen(from_str) != lean_string_size(from) - 1) {
+        return mk_embedded_nul_error(from);
+    }
+    const char* to_str = string_cstr(to);
+    if (strlen(to_str) != lean_string_size(to) - 1) {
+        inc(to);
+        return mk_embedded_nul_error(to);
+    }
 #ifdef LEAN_WINDOWS
     // Note: On windows, std::rename gives an error if the `to` file already exists,
     // so we have to call the underlying windows API directly to get behavior consistent
     // with the unix-like OSs
-    bool ok = MoveFileEx(string_cstr(from), string_cstr(to), MOVEFILE_REPLACE_EXISTING) != 0;
+    bool ok = MoveFileEx(from_str, to_str, MOVEFILE_REPLACE_EXISTING) != 0;
     if (!ok) {
         // TODO: actually produce the right type of IO error
         return io_result_mk_error((sstream()
-            << "failed to rename '" << string_cstr(from) << "' to '" << string_cstr(to) << "': " << GetLastError()).str());
+            << "failed to rename '" << from_str << "' to '" << to_str << "': " << GetLastError()).str());
     }
 #else
-    bool ok = std::rename(string_cstr(from), string_cstr(to)) == 0;
+    bool ok = std::rename(from_str, to_str) == 0;
     if (!ok) {
         std::ostringstream s;
-        s << string_cstr(from) << " and/or " << string_cstr(to);
+        s << from_str << " and/or " << to_str;
         object_ref out{mk_string(s.str())};
         return io_result_mk_error(decode_io_error(errno, out.raw()));
     }
@@ -969,6 +1229,7 @@ extern "C" LEAN_EXPORT obj_res lean_io_create_tempfile(lean_object * /* w */) {
     strcat(path, file_pattern);
 
     uv_fs_t req;
+    // Differences from lean_io_create_tempdir start here
     ret = uv_fs_mkstemp(NULL, &req, path, NULL);
     if (ret < 0) {
         // If mkstemp throws an error we cannot rely on path to contain a proper file name.
@@ -976,15 +1237,64 @@ extern "C" LEAN_EXPORT obj_res lean_io_create_tempfile(lean_object * /* w */) {
     } else {
         FILE* handle = fdopen(req.result, "r+");
         object_ref pair = mk_cnstr(0, io_wrap_handle(handle), mk_string(req.path));
+        uv_fs_req_cleanup(&req);
         return lean_io_result_mk_ok(pair.steal());
     }
 }
 
-extern "C" LEAN_EXPORT obj_res lean_io_remove_file(b_obj_arg fname, obj_arg) {
-    if (std::remove(string_cstr(fname)) == 0) {
+/* createTempDir : IO FilePath */
+extern "C" LEAN_EXPORT obj_res lean_io_create_tempdir(lean_object * /* w */) {
+    char path[PATH_MAX];
+    size_t base_len = PATH_MAX;
+    int ret = uv_os_tmpdir(path, &base_len);
+    if (ret < 0) {
+        return io_result_mk_error(decode_uv_error(ret, nullptr));
+    } else if (base_len == 0) {
+        return lean_io_result_mk_error(decode_uv_error(UV_ENOENT, mk_string("")));
+    }
+
+#if defined(LEAN_WINDOWS)
+    // On Windows `GetTempPathW` always returns a path ending in \, but libuv removes it.
+    // https://learn.microsoft.com/en-us/windows/win32/fileio/creating-and-using-a-temporary-file
+    if (path[base_len - 1] != '\\') {
+        lean_always_assert(PATH_MAX >= base_len + 1 + 1);
+        strcat(path, "\\");
+    }
+#else
+    // No guarantee that we have a trailing / in TMPDIR.
+    if (path[base_len - 1] != '/') {
+        lean_always_assert(PATH_MAX >= base_len + 1 + 1);
+        strcat(path, "/");
+    }
+#endif
+
+    const char* file_pattern = "tmp.XXXXXXXX";
+    const size_t file_pattern_size = strlen(file_pattern);
+    lean_always_assert(PATH_MAX >= strlen(path) + file_pattern_size + 1);
+    strcat(path, file_pattern);
+
+    uv_fs_t req;
+    // Differences from lean_io_create_tempfile start here
+    ret = uv_fs_mkdtemp(NULL, &req, path, NULL);
+    if (ret < 0) {
+        // If mkdtemp throws an error we cannot rely on path to contain a proper file name.
+        return io_result_mk_error(decode_uv_error(ret, nullptr));
+    } else {
+        obj_res res = lean_io_result_mk_ok(mk_string(req.path));
+        uv_fs_req_cleanup(&req);
+        return res;
+    }
+}
+
+extern "C" LEAN_EXPORT obj_res lean_io_remove_file(b_obj_arg filename, obj_arg) {
+    const char* fname = string_cstr(filename);
+    if (strlen(fname) != lean_string_size(filename) - 1) {
+        return mk_embedded_nul_error(filename);
+    }
+    if (std::remove(fname) == 0) {
         return io_result_mk_ok(box(0));
     } else {
-        return io_result_mk_error(decode_io_error(errno, fname));
+        return io_result_mk_error(decode_io_error(errno, filename));
     }
 }
 
@@ -1225,17 +1535,49 @@ extern "C" LEAN_EXPORT obj_res lean_io_wait(obj_arg t, obj_arg) {
     return io_result_mk_ok(lean_task_get_own(t));
 }
 
-extern "C" LEAN_EXPORT obj_res lean_io_wait_any(b_obj_arg task_list, obj_arg) {
-    object * t = lean_io_wait_any_core(task_list);
-    object * v = lean_task_get(t);
-    lean_inc(v);
-    return io_result_mk_ok(v);
-}
-
 extern "C" LEAN_EXPORT obj_res lean_io_exit(uint8_t code, obj_arg /* w */) {
     exit(code);
 }
 
+extern "C" LEAN_EXPORT obj_res lean_runtime_mark_multi_threaded(obj_arg a, obj_arg /* w */) {
+    lean_mark_mt(a);
+    return io_result_mk_ok(a);
+}
+
+extern "C" LEAN_EXPORT obj_res lean_runtime_mark_persistent(obj_arg a, obj_arg /* w */) {
+    lean_mark_persistent(a);
+    return io_result_mk_ok(a);
+}
+
+#if defined(__has_feature)
+#if __has_feature(address_sanitizer)
+#include <sanitizer/lsan_interface.h>
+#endif
+#endif
+
+extern "C" LEAN_EXPORT obj_res lean_runtime_forget(obj_arg o, obj_arg /* w */) {
+#if defined(__has_feature)
+#if __has_feature(address_sanitizer)
+    __lsan_ignore_object(o);
+#endif
+#endif
+    return io_result_mk_ok(box(0));
+}
+
+extern "C" LEAN_EXPORT obj_res lean_option_get_or_block(obj_arg o_opt) {
+    option_ref<object_ref> opt = option_ref<object_ref>(o_opt);
+    if (opt) {
+        return opt.get_val().steal();
+    } else {
+        lean_panic("PANIC: Promise.result!: promise has been dropped without ever being resolved",
+          /* force_stderr */ true);
+        // this is only reachable when using non-fatal panics
+        while (true) {
+            this_thread::sleep_for(std::chrono::seconds::max());
+        }
+    }
+}
+
 void initialize_io() {
     g_io_error_nullptr_read = lean_mk_io_user_error(mk_ascii_string_unchecked("null reference read"));
     mark_persistent(g_io_error_nullptr_read);
