@@ -1,6 +1,6 @@
 // Lean compiler output
 // Module: Init.Control.Lawful
-// Imports: Init.Control.Lawful.Basic Init.Control.Lawful.Instances
+// Imports: Init.Control.Lawful.Basic Init.Control.Lawful.Instances Init.Control.Lawful.Lemmas Init.Control.Lawful.MonadLift
 #include <lean/lean.h>
 #if defined(__clang__)
 #pragma clang diagnostic ignored "-Wunused-parameter"
@@ -15,6 +15,8 @@ extern "C" {
 #endif
 lean_object* initialize_Init_Control_Lawful_Basic(uint8_t builtin, lean_object*);
 lean_object* initialize_Init_Control_Lawful_Instances(uint8_t builtin, lean_object*);
+lean_object* initialize_Init_Control_Lawful_Lemmas(uint8_t builtin, lean_object*);
+lean_object* initialize_Init_Control_Lawful_MonadLift(uint8_t builtin, lean_object*);
 static bool _G_initialized = false;
 LEAN_EXPORT lean_object* initialize_Init_Control_Lawful(uint8_t builtin, lean_object* w) {
 lean_object * res;
@@ -26,6 +28,12 @@ lean_dec_ref(res);
 res = initialize_Init_Control_Lawful_Instances(builtin, lean_io_mk_world());
 if (lean_io_result_is_error(res)) return res;
 lean_dec_ref(res);
+res = initialize_Init_Control_Lawful_Lemmas(builtin, lean_io_mk_world());
+if (lean_io_result_is_error(res)) return res;
+lean_dec_ref(res);
+res = initialize_Init_Control_Lawful_MonadLift(builtin, lean_io_mk_world());
+if (lean_io_result_is_error(res)) return res;
+lean_dec_ref(res);
 return lean_io_result_mk_ok(lean_box(0));
 }
 #ifdef __cplusplus
