@@ -13,35 +13,44 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
-LEAN_EXPORT lean_object* l_Bool_instDecidableForallOfDecidablePred(lean_object*);
+LEAN_EXPORT uint8_t l_Bool_instDecidableForallOfDecidablePred(lean_object*, lean_object*);
+LEAN_EXPORT lean_object* l_Bool_toInt___boxed(lean_object*);
+LEAN_EXPORT lean_object* l_Bool_instDecidableForallOfDecidablePred___redArg___boxed(lean_object*);
 static lean_object* l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__4;
 static lean_object* l_Bool_term___x5e_x5e_____closed__10;
-LEAN_EXPORT uint8_t l_Bool_instMin(uint8_t, uint8_t);
+LEAN_EXPORT lean_object* l_Bool_instMin;
+LEAN_EXPORT lean_object* l_Bool_instMin___lam__0___boxed(lean_object*, lean_object*);
 static lean_object* l_Bool_term___x5e_x5e_____closed__4;
 static lean_object* l_Bool_term___x5e_x5e_____closed__8;
 lean_object* l_Lean_replaceRef(lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1___boxed(lean_object*, lean_object*, lean_object*);
+LEAN_EXPORT lean_object* l_Bool_instDecidableExistsOfDecidablePred___boxed(lean_object*, lean_object*);
 static lean_object* l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__12;
 LEAN_EXPORT lean_object* l_boolPredToPred(lean_object*);
+LEAN_EXPORT lean_object* l_Bool_instMax___lam__0___boxed(lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_Bool_instDecidableLe___boxed(lean_object*, lean_object*);
-LEAN_EXPORT lean_object* l_Bool_instDecidableForallOfDecidablePred___rarg(lean_object*);
+LEAN_EXPORT uint8_t l_Bool_instDecidableExistsOfDecidablePred___redArg(lean_object*);
 LEAN_EXPORT lean_object* l_Bool_toNat(uint8_t);
 uint8_t l_Lean_Syntax_isOfKind(lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_Bool_xor___boxed(lean_object*, lean_object*);
+static lean_object* l_Bool_term___x5e_x5e_____closed__0;
+LEAN_EXPORT uint8_t l_Bool_instMax___lam__0(uint8_t, uint8_t);
 static lean_object* l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__3;
 static lean_object* l_Bool_term___x5e_x5e_____closed__5;
 static lean_object* l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__1;
 lean_object* l_Lean_SourceInfo_fromRef(lean_object*, uint8_t);
+lean_object* lean_nat_to_int(lean_object*);
+LEAN_EXPORT lean_object* l_Bool_instDecidableForallOfDecidablePred___boxed(lean_object*, lean_object*);
+static lean_object* l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1___closed__0;
 LEAN_EXPORT lean_object* l_boolRelToRel(lean_object*);
 static lean_object* l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__5;
+LEAN_EXPORT lean_object* l_Bool_instDecidableExistsOfDecidablePred___redArg___boxed(lean_object*);
 static lean_object* l_Bool_term___x5e_x5e_____closed__9;
 LEAN_EXPORT lean_object* l_Bool_toNat___boxed(lean_object*);
 lean_object* l_Lean_Syntax_node3(lean_object*, lean_object*, lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_Bool_instLT;
 lean_object* l_Lean_addMacroScope(lean_object*, lean_object*, lean_object*);
-LEAN_EXPORT uint8_t l_Bool_instMax(uint8_t, uint8_t);
-lean_object* l_Lean_Name_str___override(lean_object*, lean_object*);
-static lean_object* l_Bool_term___x5e_x5e_____closed__12;
+LEAN_EXPORT lean_object* l_Bool_instMax;
 LEAN_EXPORT uint8_t l_Bool_instDecidableLt(uint8_t, uint8_t);
 lean_object* l_Lean_Syntax_node2(lean_object*, lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_Bool_instLE;
@@ -53,8 +62,8 @@ LEAN_EXPORT uint8_t l_Bool_xor(uint8_t, uint8_t);
 static lean_object* l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__10;
 static lean_object* l_Bool_term___x5e_x5e_____closed__1;
 LEAN_EXPORT lean_object* l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1(lean_object*, lean_object*, lean_object*);
-LEAN_EXPORT lean_object* l_Bool_instMin___boxed(lean_object*, lean_object*);
 static lean_object* l_Bool_term___x5e_x5e_____closed__3;
+LEAN_EXPORT uint8_t l_Bool_instDecidableForallOfDecidablePred___redArg(lean_object*);
 LEAN_EXPORT lean_object* l_Bool_instDecidableLt___boxed(lean_object*, lean_object*);
 static lean_object* l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__7;
 static lean_object* l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__9;
@@ -62,18 +71,20 @@ static lean_object* l_Bool_term___x5e_x5e_____closed__2;
 lean_object* l_Lean_Name_mkStr2(lean_object*, lean_object*);
 static lean_object* l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__8;
 LEAN_EXPORT lean_object* l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1(lean_object*, lean_object*, lean_object*);
+static lean_object* l_Bool_toInt___closed__0;
+LEAN_EXPORT lean_object* l_Bool_toInt(uint8_t);
 static lean_object* l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__6;
 static lean_object* l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__11;
 LEAN_EXPORT uint8_t l_Bool_instDecidableLe(uint8_t, uint8_t);
 static lean_object* l_Bool_term___x5e_x5e_____closed__6;
-static lean_object* l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__13;
-static lean_object* l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1___closed__2;
-LEAN_EXPORT lean_object* l_Bool_instDecidableExistsOfDecidablePred___rarg(lean_object*);
+static lean_object* l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__0;
 static lean_object* l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1___closed__1;
+LEAN_EXPORT uint8_t l_Bool_instMin___lam__0(uint8_t, uint8_t);
+static lean_object* l_Bool_toInt___closed__1;
+lean_object* l_Lean_Name_mkStr1(lean_object*);
 static lean_object* l_Bool_term___x5e_x5e_____closed__11;
 lean_object* l_Lean_Name_mkStr4(lean_object*, lean_object*, lean_object*, lean_object*);
-LEAN_EXPORT lean_object* l_Bool_instMax___boxed(lean_object*, lean_object*);
-LEAN_EXPORT lean_object* l_Bool_instDecidableExistsOfDecidablePred(lean_object*);
+LEAN_EXPORT uint8_t l_Bool_instDecidableExistsOfDecidablePred(lean_object*, lean_object*);
 static lean_object* l_Bool_term___x5e_x5e_____closed__7;
 lean_object* l_String_toSubstring_x27(lean_object*);
 LEAN_EXPORT uint8_t l_Bool_xor(uint8_t x_1, uint8_t x_2) {
@@ -87,15 +98,13 @@ else
 {
 if (x_2 == 0)
 {
-uint8_t x_3; 
-x_3 = 1;
-return x_3;
+return x_1;
 }
 else
 {
-uint8_t x_4; 
-x_4 = 0;
-return x_4;
+uint8_t x_3; 
+x_3 = 0;
+return x_3;
 }
 }
 }
@@ -105,15 +114,13 @@ _start:
 {
 uint8_t x_3; uint8_t x_4; uint8_t x_5; lean_object* x_6; 
 x_3 = lean_unbox(x_1);
-lean_dec(x_1);
 x_4 = lean_unbox(x_2);
-lean_dec(x_2);
 x_5 = l_Bool_xor(x_3, x_4);
 x_6 = lean_box(x_5);
 return x_6;
 }
 }
-static lean_object* _init_l_Bool_term___x5e_x5e_____closed__1() {
+static lean_object* _init_l_Bool_term___x5e_x5e_____closed__0() {
 _start:
 {
 lean_object* x_1; 
@@ -121,7 +128,7 @@ x_1 = lean_mk_string_unchecked("Bool", 4, 4);
 return x_1;
 }
 }
-static lean_object* _init_l_Bool_term___x5e_x5e_____closed__2() {
+static lean_object* _init_l_Bool_term___x5e_x5e_____closed__1() {
 _start:
 {
 lean_object* x_1; 
@@ -129,17 +136,17 @@ x_1 = lean_mk_string_unchecked("term_^^_", 8, 8);
 return x_1;
 }
 }
-static lean_object* _init_l_Bool_term___x5e_x5e_____closed__3() {
+static lean_object* _init_l_Bool_term___x5e_x5e_____closed__2() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; lean_object* x_3; 
 x_1 = l_Bool_term___x5e_x5e_____closed__1;
-x_2 = l_Bool_term___x5e_x5e_____closed__2;
-x_3 = l_Lean_Name_mkStr2(x_1, x_2);
+x_2 = l_Bool_term___x5e_x5e_____closed__0;
+x_3 = l_Lean_Name_mkStr2(x_2, x_1);
 return x_3;
 }
 }
-static lean_object* _init_l_Bool_term___x5e_x5e_____closed__4() {
+static lean_object* _init_l_Bool_term___x5e_x5e_____closed__3() {
 _start:
 {
 lean_object* x_1; 
@@ -147,17 +154,16 @@ x_1 = lean_mk_string_unchecked("andthen", 7, 7);
 return x_1;
 }
 }
-static lean_object* _init_l_Bool_term___x5e_x5e_____closed__5() {
+static lean_object* _init_l_Bool_term___x5e_x5e_____closed__4() {
 _start:
 {
-lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = lean_box(0);
-x_2 = l_Bool_term___x5e_x5e_____closed__4;
-x_3 = l_Lean_Name_str___override(x_1, x_2);
-return x_3;
+lean_object* x_1; lean_object* x_2; 
+x_1 = l_Bool_term___x5e_x5e_____closed__3;
+x_2 = l_Lean_Name_mkStr1(x_1);
+return x_2;
 }
 }
-static lean_object* _init_l_Bool_term___x5e_x5e_____closed__6() {
+static lean_object* _init_l_Bool_term___x5e_x5e_____closed__5() {
 _start:
 {
 lean_object* x_1; 
@@ -165,17 +171,17 @@ x_1 = lean_mk_string_unchecked(" ^^ ", 4, 4);
 return x_1;
 }
 }
-static lean_object* _init_l_Bool_term___x5e_x5e_____closed__7() {
+static lean_object* _init_l_Bool_term___x5e_x5e_____closed__6() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; 
-x_1 = l_Bool_term___x5e_x5e_____closed__6;
+x_1 = l_Bool_term___x5e_x5e_____closed__5;
 x_2 = lean_alloc_ctor(5, 1, 0);
 lean_ctor_set(x_2, 0, x_1);
 return x_2;
 }
 }
-static lean_object* _init_l_Bool_term___x5e_x5e_____closed__8() {
+static lean_object* _init_l_Bool_term___x5e_x5e_____closed__7() {
 _start:
 {
 lean_object* x_1; 
@@ -183,54 +189,53 @@ x_1 = lean_mk_string_unchecked("term", 4, 4);
 return x_1;
 }
 }
+static lean_object* _init_l_Bool_term___x5e_x5e_____closed__8() {
+_start:
+{
+lean_object* x_1; lean_object* x_2; 
+x_1 = l_Bool_term___x5e_x5e_____closed__7;
+x_2 = l_Lean_Name_mkStr1(x_1);
+return x_2;
+}
+}
 static lean_object* _init_l_Bool_term___x5e_x5e_____closed__9() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = lean_box(0);
+x_1 = lean_unsigned_to_nat(34u);
 x_2 = l_Bool_term___x5e_x5e_____closed__8;
-x_3 = l_Lean_Name_str___override(x_1, x_2);
+x_3 = lean_alloc_ctor(7, 2, 0);
+lean_ctor_set(x_3, 0, x_2);
+lean_ctor_set(x_3, 1, x_1);
 return x_3;
 }
 }
 static lean_object* _init_l_Bool_term___x5e_x5e_____closed__10() {
 _start:
 {
-lean_object* x_1; lean_object* x_2; lean_object* x_3; 
+lean_object* x_1; lean_object* x_2; lean_object* x_3; lean_object* x_4; 
 x_1 = l_Bool_term___x5e_x5e_____closed__9;
-x_2 = lean_unsigned_to_nat(34u);
-x_3 = lean_alloc_ctor(7, 2, 0);
-lean_ctor_set(x_3, 0, x_1);
-lean_ctor_set(x_3, 1, x_2);
-return x_3;
+x_2 = l_Bool_term___x5e_x5e_____closed__6;
+x_3 = l_Bool_term___x5e_x5e_____closed__4;
+x_4 = lean_alloc_ctor(2, 3, 0);
+lean_ctor_set(x_4, 0, x_3);
+lean_ctor_set(x_4, 1, x_2);
+lean_ctor_set(x_4, 2, x_1);
+return x_4;
 }
 }
 static lean_object* _init_l_Bool_term___x5e_x5e_____closed__11() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; lean_object* x_3; lean_object* x_4; 
-x_1 = l_Bool_term___x5e_x5e_____closed__5;
-x_2 = l_Bool_term___x5e_x5e_____closed__7;
-x_3 = l_Bool_term___x5e_x5e_____closed__10;
-x_4 = lean_alloc_ctor(2, 3, 0);
-lean_ctor_set(x_4, 0, x_1);
-lean_ctor_set(x_4, 1, x_2);
-lean_ctor_set(x_4, 2, x_3);
-return x_4;
-}
-}
-static lean_object* _init_l_Bool_term___x5e_x5e_____closed__12() {
-_start:
-{
-lean_object* x_1; lean_object* x_2; lean_object* x_3; lean_object* x_4; 
-x_1 = l_Bool_term___x5e_x5e_____closed__3;
+x_1 = l_Bool_term___x5e_x5e_____closed__10;
 x_2 = lean_unsigned_to_nat(33u);
-x_3 = l_Bool_term___x5e_x5e_____closed__11;
+x_3 = l_Bool_term___x5e_x5e_____closed__2;
 x_4 = lean_alloc_ctor(4, 4, 0);
-lean_ctor_set(x_4, 0, x_1);
+lean_ctor_set(x_4, 0, x_3);
 lean_ctor_set(x_4, 1, x_2);
 lean_ctor_set(x_4, 2, x_2);
-lean_ctor_set(x_4, 3, x_3);
+lean_ctor_set(x_4, 3, x_1);
 return x_4;
 }
 }
@@ -238,11 +243,11 @@ static lean_object* _init_l_Bool_term___x5e_x5e__() {
 _start:
 {
 lean_object* x_1; 
-x_1 = l_Bool_term___x5e_x5e_____closed__12;
+x_1 = l_Bool_term___x5e_x5e_____closed__11;
 return x_1;
 }
 }
-static lean_object* _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__1() {
+static lean_object* _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__0() {
 _start:
 {
 lean_object* x_1; 
@@ -250,7 +255,7 @@ x_1 = lean_mk_string_unchecked("Lean", 4, 4);
 return x_1;
 }
 }
-static lean_object* _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__2() {
+static lean_object* _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__1() {
 _start:
 {
 lean_object* x_1; 
@@ -258,7 +263,7 @@ x_1 = lean_mk_string_unchecked("Parser", 6, 6);
 return x_1;
 }
 }
-static lean_object* _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__3() {
+static lean_object* _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__2() {
 _start:
 {
 lean_object* x_1; 
@@ -266,7 +271,7 @@ x_1 = lean_mk_string_unchecked("Term", 4, 4);
 return x_1;
 }
 }
-static lean_object* _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__4() {
+static lean_object* _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__3() {
 _start:
 {
 lean_object* x_1; 
@@ -274,19 +279,19 @@ x_1 = lean_mk_string_unchecked("app", 3, 3);
 return x_1;
 }
 }
-static lean_object* _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__5() {
+static lean_object* _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__4() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; lean_object* x_3; lean_object* x_4; lean_object* x_5; 
-x_1 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__1;
+x_1 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__3;
 x_2 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__2;
-x_3 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__3;
-x_4 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__4;
-x_5 = l_Lean_Name_mkStr4(x_1, x_2, x_3, x_4);
+x_3 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__1;
+x_4 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__0;
+x_5 = l_Lean_Name_mkStr4(x_4, x_3, x_2, x_1);
 return x_5;
 }
 }
-static lean_object* _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__6() {
+static lean_object* _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__5() {
 _start:
 {
 lean_object* x_1; 
@@ -294,12 +299,21 @@ x_1 = lean_mk_string_unchecked("xor", 3, 3);
 return x_1;
 }
 }
+static lean_object* _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__6() {
+_start:
+{
+lean_object* x_1; lean_object* x_2; 
+x_1 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__5;
+x_2 = l_String_toSubstring_x27(x_1);
+return x_2;
+}
+}
 static lean_object* _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__7() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; 
-x_1 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__6;
-x_2 = l_String_toSubstring_x27(x_1);
+x_1 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__5;
+x_2 = l_Lean_Name_mkStr1(x_1);
 return x_2;
 }
 }
@@ -307,9 +321,9 @@ static lean_object* _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__
 _start:
 {
 lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = lean_box(0);
-x_2 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__6;
-x_3 = l_Lean_Name_str___override(x_1, x_2);
+x_1 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__5;
+x_2 = l_Bool_term___x5e_x5e_____closed__0;
+x_3 = l_Lean_Name_mkStr2(x_2, x_1);
 return x_3;
 }
 }
@@ -317,9 +331,11 @@ static lean_object* _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__
 _start:
 {
 lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = l_Bool_term___x5e_x5e_____closed__1;
-x_2 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__6;
-x_3 = l_Lean_Name_mkStr2(x_1, x_2);
+x_1 = lean_box(0);
+x_2 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__8;
+x_3 = lean_alloc_ctor(1, 2, 0);
+lean_ctor_set(x_3, 0, x_2);
+lean_ctor_set(x_3, 1, x_1);
 return x_3;
 }
 }
@@ -338,44 +354,31 @@ return x_3;
 static lean_object* _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__11() {
 _start:
 {
-lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = lean_box(0);
-x_2 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__10;
-x_3 = lean_alloc_ctor(1, 2, 0);
-lean_ctor_set(x_3, 0, x_2);
-lean_ctor_set(x_3, 1, x_1);
-return x_3;
-}
-}
-static lean_object* _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__12() {
-_start:
-{
 lean_object* x_1; 
 x_1 = lean_mk_string_unchecked("null", 4, 4);
 return x_1;
 }
 }
-static lean_object* _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__13() {
+static lean_object* _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__12() {
 _start:
 {
-lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = lean_box(0);
-x_2 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__12;
-x_3 = l_Lean_Name_str___override(x_1, x_2);
-return x_3;
+lean_object* x_1; lean_object* x_2; 
+x_1 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__11;
+x_2 = l_Lean_Name_mkStr1(x_1);
+return x_2;
 }
 }
 LEAN_EXPORT lean_object* l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1(lean_object* x_1, lean_object* x_2, lean_object* x_3) {
 _start:
 {
 lean_object* x_4; uint8_t x_5; 
-x_4 = l_Bool_term___x5e_x5e_____closed__3;
+x_4 = l_Bool_term___x5e_x5e_____closed__2;
 lean_inc(x_1);
 x_5 = l_Lean_Syntax_isOfKind(x_1, x_4);
 if (x_5 == 0)
 {
 lean_object* x_6; lean_object* x_7; 
-lean_dec(x_2);
+lean_dec_ref(x_2);
 lean_dec(x_1);
 x_6 = lean_box(1);
 x_7 = lean_alloc_ctor(1, 2, 0);
@@ -385,37 +388,37 @@ return x_7;
 }
 else
 {
-lean_object* x_8; lean_object* x_9; lean_object* x_10; lean_object* x_11; lean_object* x_12; uint8_t x_13; lean_object* x_14; lean_object* x_15; lean_object* x_16; lean_object* x_17; lean_object* x_18; lean_object* x_19; lean_object* x_20; lean_object* x_21; lean_object* x_22; lean_object* x_23; lean_object* x_24; lean_object* x_25; lean_object* x_26; 
-x_8 = lean_unsigned_to_nat(0u);
-x_9 = l_Lean_Syntax_getArg(x_1, x_8);
-x_10 = lean_unsigned_to_nat(2u);
-x_11 = l_Lean_Syntax_getArg(x_1, x_10);
+lean_object* x_8; lean_object* x_9; lean_object* x_10; lean_object* x_11; lean_object* x_12; lean_object* x_13; lean_object* x_14; uint8_t x_15; lean_object* x_16; lean_object* x_17; lean_object* x_18; lean_object* x_19; lean_object* x_20; lean_object* x_21; lean_object* x_22; lean_object* x_23; lean_object* x_24; lean_object* x_25; lean_object* x_26; 
+x_8 = lean_ctor_get(x_2, 1);
+lean_inc(x_8);
+x_9 = lean_ctor_get(x_2, 2);
+lean_inc(x_9);
+x_10 = lean_ctor_get(x_2, 5);
+lean_inc(x_10);
+lean_dec_ref(x_2);
+x_11 = lean_unsigned_to_nat(0u);
+x_12 = l_Lean_Syntax_getArg(x_1, x_11);
+x_13 = lean_unsigned_to_nat(2u);
+x_14 = l_Lean_Syntax_getArg(x_1, x_13);
 lean_dec(x_1);
-x_12 = lean_ctor_get(x_2, 5);
-lean_inc(x_12);
-x_13 = 0;
-x_14 = l_Lean_SourceInfo_fromRef(x_12, x_13);
-lean_dec(x_12);
-x_15 = lean_ctor_get(x_2, 2);
-lean_inc(x_15);
-x_16 = lean_ctor_get(x_2, 1);
-lean_inc(x_16);
-lean_dec(x_2);
-x_17 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__8;
-x_18 = l_Lean_addMacroScope(x_16, x_17, x_15);
+x_15 = 0;
+x_16 = l_Lean_SourceInfo_fromRef(x_10, x_15);
+lean_dec(x_10);
+x_17 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__4;
+x_18 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__6;
 x_19 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__7;
-x_20 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__11;
-lean_inc(x_14);
-x_21 = lean_alloc_ctor(3, 4, 0);
-lean_ctor_set(x_21, 0, x_14);
-lean_ctor_set(x_21, 1, x_19);
-lean_ctor_set(x_21, 2, x_18);
-lean_ctor_set(x_21, 3, x_20);
-x_22 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__13;
-lean_inc(x_14);
-x_23 = l_Lean_Syntax_node2(x_14, x_22, x_9, x_11);
-x_24 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__5;
-x_25 = l_Lean_Syntax_node2(x_14, x_24, x_21, x_23);
+x_20 = l_Lean_addMacroScope(x_8, x_19, x_9);
+x_21 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__10;
+lean_inc(x_16);
+x_22 = lean_alloc_ctor(3, 4, 0);
+lean_ctor_set(x_22, 0, x_16);
+lean_ctor_set(x_22, 1, x_18);
+lean_ctor_set(x_22, 2, x_20);
+lean_ctor_set(x_22, 3, x_21);
+x_23 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__12;
+lean_inc(x_16);
+x_24 = l_Lean_Syntax_node2(x_16, x_23, x_12, x_14);
+x_25 = l_Lean_Syntax_node2(x_16, x_17, x_22, x_24);
 x_26 = lean_alloc_ctor(0, 2, 0);
 lean_ctor_set(x_26, 0, x_25);
 lean_ctor_set(x_26, 1, x_3);
@@ -423,7 +426,7 @@ return x_26;
 }
 }
 }
-static lean_object* _init_l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1___closed__1() {
+static lean_object* _init_l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1___closed__0() {
 _start:
 {
 lean_object* x_1; 
@@ -431,21 +434,20 @@ x_1 = lean_mk_string_unchecked("ident", 5, 5);
 return x_1;
 }
 }
-static lean_object* _init_l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1___closed__2() {
+static lean_object* _init_l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1___closed__1() {
 _start:
 {
-lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = lean_box(0);
-x_2 = l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1___closed__1;
-x_3 = l_Lean_Name_str___override(x_1, x_2);
-return x_3;
+lean_object* x_1; lean_object* x_2; 
+x_1 = l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1___closed__0;
+x_2 = l_Lean_Name_mkStr1(x_1);
+return x_2;
 }
 }
 LEAN_EXPORT lean_object* l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1(lean_object* x_1, lean_object* x_2, lean_object* x_3) {
 _start:
 {
 lean_object* x_4; uint8_t x_5; 
-x_4 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__5;
+x_4 = l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__4;
 lean_inc(x_1);
 x_5 = l_Lean_Syntax_isOfKind(x_1, x_4);
 if (x_5 == 0)
@@ -463,7 +465,7 @@ else
 lean_object* x_8; lean_object* x_9; lean_object* x_10; uint8_t x_11; 
 x_8 = lean_unsigned_to_nat(0u);
 x_9 = l_Lean_Syntax_getArg(x_1, x_8);
-x_10 = l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1___closed__2;
+x_10 = l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1___closed__1;
 lean_inc(x_9);
 x_11 = l_Lean_Syntax_isOfKind(x_9, x_10);
 if (x_11 == 0)
@@ -508,13 +510,13 @@ lean_dec(x_9);
 x_23 = 0;
 x_24 = l_Lean_SourceInfo_fromRef(x_22, x_23);
 lean_dec(x_22);
-x_25 = l_Bool_term___x5e_x5e_____closed__6;
+x_25 = l_Bool_term___x5e_x5e_____closed__2;
+x_26 = l_Bool_term___x5e_x5e_____closed__5;
 lean_inc(x_24);
-x_26 = lean_alloc_ctor(2, 2, 0);
-lean_ctor_set(x_26, 0, x_24);
-lean_ctor_set(x_26, 1, x_25);
-x_27 = l_Bool_term___x5e_x5e_____closed__3;
-x_28 = l_Lean_Syntax_node3(x_24, x_27, x_20, x_26, x_21);
+x_27 = lean_alloc_ctor(2, 2, 0);
+lean_ctor_set(x_27, 0, x_24);
+lean_ctor_set(x_27, 1, x_26);
+x_28 = l_Lean_Syntax_node3(x_24, x_25, x_20, x_27, x_21);
 x_29 = lean_alloc_ctor(0, 2, 0);
 lean_ctor_set(x_29, 0, x_28);
 lean_ctor_set(x_29, 1, x_3);
@@ -533,76 +535,108 @@ lean_dec(x_2);
 return x_4;
 }
 }
-LEAN_EXPORT lean_object* l_Bool_instDecidableForallOfDecidablePred___rarg(lean_object* x_1) {
+LEAN_EXPORT uint8_t l_Bool_instDecidableForallOfDecidablePred___redArg(lean_object* x_1) {
 _start:
 {
 uint8_t x_2; lean_object* x_3; lean_object* x_4; uint8_t x_5; 
 x_2 = 1;
 x_3 = lean_box(x_2);
-lean_inc(x_1);
+lean_inc_ref(x_1);
 x_4 = lean_apply_1(x_1, x_3);
 x_5 = lean_unbox(x_4);
-lean_dec(x_4);
 if (x_5 == 0)
 {
-uint8_t x_6; lean_object* x_7; 
-lean_dec(x_1);
-x_6 = 0;
-x_7 = lean_box(x_6);
+uint8_t x_6; 
+lean_dec_ref(x_1);
+x_6 = lean_unbox(x_4);
+return x_6;
+}
+else
+{
+uint8_t x_7; lean_object* x_8; lean_object* x_9; uint8_t x_10; 
+x_7 = 0;
+x_8 = lean_box(x_7);
+x_9 = lean_apply_1(x_1, x_8);
+x_10 = lean_unbox(x_9);
+return x_10;
+}
+}
+}
+LEAN_EXPORT uint8_t l_Bool_instDecidableForallOfDecidablePred(lean_object* x_1, lean_object* x_2) {
+_start:
+{
+uint8_t x_3; 
+x_3 = l_Bool_instDecidableForallOfDecidablePred___redArg(x_2);
+return x_3;
+}
+}
+LEAN_EXPORT lean_object* l_Bool_instDecidableForallOfDecidablePred___redArg___boxed(lean_object* x_1) {
+_start:
+{
+uint8_t x_2; lean_object* x_3; 
+x_2 = l_Bool_instDecidableForallOfDecidablePred___redArg(x_1);
+x_3 = lean_box(x_2);
+return x_3;
+}
+}
+LEAN_EXPORT lean_object* l_Bool_instDecidableForallOfDecidablePred___boxed(lean_object* x_1, lean_object* x_2) {
+_start:
+{
+uint8_t x_3; lean_object* x_4; 
+x_3 = l_Bool_instDecidableForallOfDecidablePred(x_1, x_2);
+x_4 = lean_box(x_3);
+return x_4;
+}
+}
+LEAN_EXPORT uint8_t l_Bool_instDecidableExistsOfDecidablePred___redArg(lean_object* x_1) {
+_start:
+{
+uint8_t x_2; lean_object* x_3; lean_object* x_4; uint8_t x_5; 
+x_2 = 1;
+x_3 = lean_box(x_2);
+lean_inc_ref(x_1);
+x_4 = lean_apply_1(x_1, x_3);
+x_5 = lean_unbox(x_4);
+if (x_5 == 0)
+{
+lean_object* x_6; uint8_t x_7; 
+x_6 = lean_apply_1(x_1, x_4);
+x_7 = lean_unbox(x_6);
 return x_7;
 }
 else
 {
-uint8_t x_8; lean_object* x_9; lean_object* x_10; 
-x_8 = 0;
-x_9 = lean_box(x_8);
-x_10 = lean_apply_1(x_1, x_9);
-return x_10;
-}
-}
-}
-LEAN_EXPORT lean_object* l_Bool_instDecidableForallOfDecidablePred(lean_object* x_1) {
-_start:
-{
-lean_object* x_2; 
-x_2 = lean_alloc_closure((void*)(l_Bool_instDecidableForallOfDecidablePred___rarg), 1, 0);
-return x_2;
-}
-}
-LEAN_EXPORT lean_object* l_Bool_instDecidableExistsOfDecidablePred___rarg(lean_object* x_1) {
-_start:
-{
-uint8_t x_2; lean_object* x_3; lean_object* x_4; uint8_t x_5; 
-x_2 = 1;
-x_3 = lean_box(x_2);
-lean_inc(x_1);
-x_4 = lean_apply_1(x_1, x_3);
-x_5 = lean_unbox(x_4);
-lean_dec(x_4);
-if (x_5 == 0)
-{
-uint8_t x_6; lean_object* x_7; lean_object* x_8; 
-x_6 = 0;
-x_7 = lean_box(x_6);
-x_8 = lean_apply_1(x_1, x_7);
+uint8_t x_8; 
+lean_dec_ref(x_1);
+x_8 = lean_unbox(x_4);
 return x_8;
 }
-else
-{
-uint8_t x_9; lean_object* x_10; 
-lean_dec(x_1);
-x_9 = 1;
-x_10 = lean_box(x_9);
-return x_10;
 }
 }
-}
-LEAN_EXPORT lean_object* l_Bool_instDecidableExistsOfDecidablePred(lean_object* x_1) {
+LEAN_EXPORT uint8_t l_Bool_instDecidableExistsOfDecidablePred(lean_object* x_1, lean_object* x_2) {
 _start:
 {
-lean_object* x_2; 
-x_2 = lean_alloc_closure((void*)(l_Bool_instDecidableExistsOfDecidablePred___rarg), 1, 0);
-return x_2;
+uint8_t x_3; 
+x_3 = l_Bool_instDecidableExistsOfDecidablePred___redArg(x_2);
+return x_3;
+}
+}
+LEAN_EXPORT lean_object* l_Bool_instDecidableExistsOfDecidablePred___redArg___boxed(lean_object* x_1) {
+_start:
+{
+uint8_t x_2; lean_object* x_3; 
+x_2 = l_Bool_instDecidableExistsOfDecidablePred___redArg(x_1);
+x_3 = lean_box(x_2);
+return x_3;
+}
+}
+LEAN_EXPORT lean_object* l_Bool_instDecidableExistsOfDecidablePred___boxed(lean_object* x_1, lean_object* x_2) {
+_start:
+{
+uint8_t x_3; lean_object* x_4; 
+x_3 = l_Bool_instDecidableExistsOfDecidablePred(x_1, x_2);
+x_4 = lean_box(x_3);
+return x_4;
 }
 }
 static lean_object* _init_l_Bool_instLE() {
@@ -641,9 +675,7 @@ _start:
 {
 uint8_t x_3; uint8_t x_4; uint8_t x_5; lean_object* x_6; 
 x_3 = lean_unbox(x_1);
-lean_dec(x_1);
 x_4 = lean_unbox(x_2);
-lean_dec(x_2);
 x_5 = l_Bool_instDecidableLe(x_3, x_4);
 x_6 = lean_box(x_5);
 return x_6;
@@ -669,15 +701,13 @@ _start:
 {
 uint8_t x_3; uint8_t x_4; uint8_t x_5; lean_object* x_6; 
 x_3 = lean_unbox(x_1);
-lean_dec(x_1);
 x_4 = lean_unbox(x_2);
-lean_dec(x_2);
 x_5 = l_Bool_instDecidableLt(x_3, x_4);
 x_6 = lean_box(x_5);
 return x_6;
 }
 }
-LEAN_EXPORT uint8_t l_Bool_instMax(uint8_t x_1, uint8_t x_2) {
+LEAN_EXPORT uint8_t l_Bool_instMax___lam__0(uint8_t x_1, uint8_t x_2) {
 _start:
 {
 if (x_1 == 0)
@@ -686,33 +716,35 @@ return x_2;
 }
 else
 {
-uint8_t x_3; 
-x_3 = 1;
-return x_3;
+return x_1;
 }
 }
 }
-LEAN_EXPORT lean_object* l_Bool_instMax___boxed(lean_object* x_1, lean_object* x_2) {
+static lean_object* _init_l_Bool_instMax() {
+_start:
+{
+lean_object* x_1; 
+x_1 = lean_alloc_closure((void*)(l_Bool_instMax___lam__0___boxed), 2, 0);
+return x_1;
+}
+}
+LEAN_EXPORT lean_object* l_Bool_instMax___lam__0___boxed(lean_object* x_1, lean_object* x_2) {
 _start:
 {
 uint8_t x_3; uint8_t x_4; uint8_t x_5; lean_object* x_6; 
 x_3 = lean_unbox(x_1);
-lean_dec(x_1);
 x_4 = lean_unbox(x_2);
-lean_dec(x_2);
-x_5 = l_Bool_instMax(x_3, x_4);
+x_5 = l_Bool_instMax___lam__0(x_3, x_4);
 x_6 = lean_box(x_5);
 return x_6;
 }
 }
-LEAN_EXPORT uint8_t l_Bool_instMin(uint8_t x_1, uint8_t x_2) {
+LEAN_EXPORT uint8_t l_Bool_instMin___lam__0(uint8_t x_1, uint8_t x_2) {
 _start:
 {
 if (x_1 == 0)
 {
-uint8_t x_3; 
-x_3 = 0;
-return x_3;
+return x_1;
 }
 else
 {
@@ -720,15 +752,21 @@ return x_2;
 }
 }
 }
-LEAN_EXPORT lean_object* l_Bool_instMin___boxed(lean_object* x_1, lean_object* x_2) {
+static lean_object* _init_l_Bool_instMin() {
+_start:
+{
+lean_object* x_1; 
+x_1 = lean_alloc_closure((void*)(l_Bool_instMin___lam__0___boxed), 2, 0);
+return x_1;
+}
+}
+LEAN_EXPORT lean_object* l_Bool_instMin___lam__0___boxed(lean_object* x_1, lean_object* x_2) {
 _start:
 {
 uint8_t x_3; uint8_t x_4; uint8_t x_5; lean_object* x_6; 
 x_3 = lean_unbox(x_1);
-lean_dec(x_1);
 x_4 = lean_unbox(x_2);
-lean_dec(x_2);
-x_5 = l_Bool_instMin(x_3, x_4);
+x_5 = l_Bool_instMin___lam__0(x_3, x_4);
 x_6 = lean_box(x_5);
 return x_6;
 }
@@ -755,11 +793,54 @@ _start:
 {
 uint8_t x_2; lean_object* x_3; 
 x_2 = lean_unbox(x_1);
-lean_dec(x_1);
 x_3 = l_Bool_toNat(x_2);
 return x_3;
 }
 }
+static lean_object* _init_l_Bool_toInt___closed__0() {
+_start:
+{
+lean_object* x_1; lean_object* x_2; 
+x_1 = lean_unsigned_to_nat(0u);
+x_2 = lean_nat_to_int(x_1);
+return x_2;
+}
+}
+static lean_object* _init_l_Bool_toInt___closed__1() {
+_start:
+{
+lean_object* x_1; lean_object* x_2; 
+x_1 = lean_unsigned_to_nat(1u);
+x_2 = lean_nat_to_int(x_1);
+return x_2;
+}
+}
+LEAN_EXPORT lean_object* l_Bool_toInt(uint8_t x_1) {
+_start:
+{
+if (x_1 == 0)
+{
+lean_object* x_2; 
+x_2 = l_Bool_toInt___closed__0;
+return x_2;
+}
+else
+{
+lean_object* x_3; 
+x_3 = l_Bool_toInt___closed__1;
+return x_3;
+}
+}
+}
+LEAN_EXPORT lean_object* l_Bool_toInt___boxed(lean_object* x_1) {
+_start:
+{
+uint8_t x_2; lean_object* x_3; 
+x_2 = lean_unbox(x_1);
+x_3 = l_Bool_toInt(x_2);
+return x_3;
+}
+}
 LEAN_EXPORT lean_object* l_boolPredToPred(lean_object* x_1) {
 _start:
 {
@@ -781,6 +862,8 @@ _G_initialized = true;
 res = initialize_Init_NotationExtra(builtin, lean_io_mk_world());
 if (lean_io_result_is_error(res)) return res;
 lean_dec_ref(res);
+l_Bool_term___x5e_x5e_____closed__0 = _init_l_Bool_term___x5e_x5e_____closed__0();
+lean_mark_persistent(l_Bool_term___x5e_x5e_____closed__0);
 l_Bool_term___x5e_x5e_____closed__1 = _init_l_Bool_term___x5e_x5e_____closed__1();
 lean_mark_persistent(l_Bool_term___x5e_x5e_____closed__1);
 l_Bool_term___x5e_x5e_____closed__2 = _init_l_Bool_term___x5e_x5e_____closed__2();
@@ -803,10 +886,10 @@ l_Bool_term___x5e_x5e_____closed__10 = _init_l_Bool_term___x5e_x5e_____closed__1
 lean_mark_persistent(l_Bool_term___x5e_x5e_____closed__10);
 l_Bool_term___x5e_x5e_____closed__11 = _init_l_Bool_term___x5e_x5e_____closed__11();
 lean_mark_persistent(l_Bool_term___x5e_x5e_____closed__11);
-l_Bool_term___x5e_x5e_____closed__12 = _init_l_Bool_term___x5e_x5e_____closed__12();
-lean_mark_persistent(l_Bool_term___x5e_x5e_____closed__12);
 l_Bool_term___x5e_x5e__ = _init_l_Bool_term___x5e_x5e__();
 lean_mark_persistent(l_Bool_term___x5e_x5e__);
+l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__0 = _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__0();
+lean_mark_persistent(l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__0);
 l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__1 = _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__1();
 lean_mark_persistent(l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__1);
 l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__2 = _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__2();
@@ -831,16 +914,22 @@ l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___clos
 lean_mark_persistent(l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__11);
 l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__12 = _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__12();
 lean_mark_persistent(l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__12);
-l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__13 = _init_l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__13();
-lean_mark_persistent(l_Bool___aux__Init__Data__Bool______macroRules__Bool__term___x5e_x5e____1___closed__13);
+l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1___closed__0 = _init_l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1___closed__0();
+lean_mark_persistent(l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1___closed__0);
 l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1___closed__1 = _init_l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1___closed__1();
 lean_mark_persistent(l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1___closed__1);
-l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1___closed__2 = _init_l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1___closed__2();
-lean_mark_persistent(l_Bool___aux__Init__Data__Bool______unexpand__Bool__xor__1___closed__2);
 l_Bool_instLE = _init_l_Bool_instLE();
 lean_mark_persistent(l_Bool_instLE);
 l_Bool_instLT = _init_l_Bool_instLT();
 lean_mark_persistent(l_Bool_instLT);
+l_Bool_instMax = _init_l_Bool_instMax();
+lean_mark_persistent(l_Bool_instMax);
+l_Bool_instMin = _init_l_Bool_instMin();
+lean_mark_persistent(l_Bool_instMin);
+l_Bool_toInt___closed__0 = _init_l_Bool_toInt___closed__0();
+lean_mark_persistent(l_Bool_toInt___closed__0);
+l_Bool_toInt___closed__1 = _init_l_Bool_toInt___closed__1();
+lean_mark_persistent(l_Bool_toInt___closed__1);
 return lean_io_result_mk_ok(lean_box(0));
 }
 #ifdef __cplusplus
