@@ -1,6 +1,6 @@
 // Lean compiler output
 // Module: Init.Data.Char
-// Imports: Init.Data.Char.Basic Init.Data.Char.Lemmas
+// Imports: Init.Data.Char.Basic Init.Data.Char.Lemmas Init.Data.Char.Order
 #include <lean/lean.h>
 #if defined(__clang__)
 #pragma clang diagnostic ignored "-Wunused-parameter"
@@ -15,6 +15,7 @@ extern "C" {
 #endif
 lean_object* initialize_Init_Data_Char_Basic(uint8_t builtin, lean_object*);
 lean_object* initialize_Init_Data_Char_Lemmas(uint8_t builtin, lean_object*);
+lean_object* initialize_Init_Data_Char_Order(uint8_t builtin, lean_object*);
 static bool _G_initialized = false;
 LEAN_EXPORT lean_object* initialize_Init_Data_Char(uint8_t builtin, lean_object* w) {
 lean_object * res;
@@ -26,6 +27,9 @@ lean_dec_ref(res);
 res = initialize_Init_Data_Char_Lemmas(builtin, lean_io_mk_world());
 if (lean_io_result_is_error(res)) return res;
 lean_dec_ref(res);
+res = initialize_Init_Data_Char_Order(builtin, lean_io_mk_world());
+if (lean_io_result_is_error(res)) return res;
+lean_dec_ref(res);
 return lean_io_result_mk_ok(lean_box(0));
 }
 #ifdef __cplusplus
