@@ -17,7 +17,6 @@ static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std_
 static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__13;
 static lean_object* l_Std_termF_x21_____closed__3;
 static lean_object* l_Std_termF_x21_____closed__9;
-static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__16;
 static lean_object* l_Std_termF_x21_____closed__5;
 static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__7;
 static lean_object* l_Std_termF_x21_____closed__8;
@@ -33,15 +32,15 @@ static lean_object* l_Std_termF_x21_____closed__7;
 static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__12;
 lean_object* l_Lean_Name_mkStr3(lean_object*, lean_object*, lean_object*);
 static lean_object* l_Std_termF_x21_____closed__12;
+static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__0;
 lean_object* l_Lean_SourceInfo_fromRef(lean_object*, uint8_t);
-static lean_object* l_Std_termF_x21_____closed__15;
 static lean_object* l_Std_termF_x21_____closed__14;
 static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__4;
 lean_object* l_Lean_addMacroScope(lean_object*, lean_object*, lean_object*);
-lean_object* l_Lean_Name_str___override(lean_object*, lean_object*);
 lean_object* l_Lean_Syntax_getArg(lean_object*, lean_object*);
 static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__14;
 static lean_object* l_Std_termF_x21_____closed__6;
+static lean_object* l_Std_termF_x21_____closed__0;
 static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__11;
 static lean_object* l_Std_termF_x21_____closed__1;
 static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__2;
@@ -52,10 +51,11 @@ static lean_object* l_Std_termF_x21_____closed__4;
 static lean_object* l_Std_termF_x21_____closed__13;
 static lean_object* l_Std_termF_x21_____closed__2;
 static lean_object* l_Std_termF_x21_____closed__10;
+lean_object* l_Lean_Name_mkStr1(lean_object*);
 LEAN_EXPORT lean_object* l_Std_termF_x21__;
 lean_object* l_String_toSubstring_x27(lean_object*);
 static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__10;
-static lean_object* _init_l_Std_termF_x21_____closed__1() {
+static lean_object* _init_l_Std_termF_x21_____closed__0() {
 _start:
 {
 lean_object* x_1; 
@@ -63,7 +63,7 @@ x_1 = lean_mk_string_unchecked("Std", 3, 3);
 return x_1;
 }
 }
-static lean_object* _init_l_Std_termF_x21_____closed__2() {
+static lean_object* _init_l_Std_termF_x21_____closed__1() {
 _start:
 {
 lean_object* x_1; 
@@ -71,17 +71,17 @@ x_1 = lean_mk_string_unchecked("termF!_", 7, 7);
 return x_1;
 }
 }
-static lean_object* _init_l_Std_termF_x21_____closed__3() {
+static lean_object* _init_l_Std_termF_x21_____closed__2() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; lean_object* x_3; 
 x_1 = l_Std_termF_x21_____closed__1;
-x_2 = l_Std_termF_x21_____closed__2;
-x_3 = l_Lean_Name_mkStr2(x_1, x_2);
+x_2 = l_Std_termF_x21_____closed__0;
+x_3 = l_Lean_Name_mkStr2(x_2, x_1);
 return x_3;
 }
 }
-static lean_object* _init_l_Std_termF_x21_____closed__4() {
+static lean_object* _init_l_Std_termF_x21_____closed__3() {
 _start:
 {
 lean_object* x_1; 
@@ -89,17 +89,16 @@ x_1 = lean_mk_string_unchecked("andthen", 7, 7);
 return x_1;
 }
 }
-static lean_object* _init_l_Std_termF_x21_____closed__5() {
+static lean_object* _init_l_Std_termF_x21_____closed__4() {
 _start:
 {
-lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = lean_box(0);
-x_2 = l_Std_termF_x21_____closed__4;
-x_3 = l_Lean_Name_str___override(x_1, x_2);
-return x_3;
+lean_object* x_1; lean_object* x_2; 
+x_1 = l_Std_termF_x21_____closed__3;
+x_2 = l_Lean_Name_mkStr1(x_1);
+return x_2;
 }
 }
-static lean_object* _init_l_Std_termF_x21_____closed__6() {
+static lean_object* _init_l_Std_termF_x21_____closed__5() {
 _start:
 {
 lean_object* x_1; 
@@ -107,17 +106,17 @@ x_1 = lean_mk_string_unchecked("f!", 2, 2);
 return x_1;
 }
 }
-static lean_object* _init_l_Std_termF_x21_____closed__7() {
+static lean_object* _init_l_Std_termF_x21_____closed__6() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; 
-x_1 = l_Std_termF_x21_____closed__6;
+x_1 = l_Std_termF_x21_____closed__5;
 x_2 = lean_alloc_ctor(5, 1, 0);
 lean_ctor_set(x_2, 0, x_1);
 return x_2;
 }
 }
-static lean_object* _init_l_Std_termF_x21_____closed__8() {
+static lean_object* _init_l_Std_termF_x21_____closed__7() {
 _start:
 {
 lean_object* x_1; 
@@ -125,17 +124,16 @@ x_1 = lean_mk_string_unchecked("interpolatedStr", 15, 15);
 return x_1;
 }
 }
-static lean_object* _init_l_Std_termF_x21_____closed__9() {
+static lean_object* _init_l_Std_termF_x21_____closed__8() {
 _start:
 {
-lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = lean_box(0);
-x_2 = l_Std_termF_x21_____closed__8;
-x_3 = l_Lean_Name_str___override(x_1, x_2);
-return x_3;
+lean_object* x_1; lean_object* x_2; 
+x_1 = l_Std_termF_x21_____closed__7;
+x_2 = l_Lean_Name_mkStr1(x_1);
+return x_2;
 }
 }
-static lean_object* _init_l_Std_termF_x21_____closed__10() {
+static lean_object* _init_l_Std_termF_x21_____closed__9() {
 _start:
 {
 lean_object* x_1; 
@@ -143,13 +141,24 @@ x_1 = lean_mk_string_unchecked("term", 4, 4);
 return x_1;
 }
 }
+static lean_object* _init_l_Std_termF_x21_____closed__10() {
+_start:
+{
+lean_object* x_1; lean_object* x_2; 
+x_1 = l_Std_termF_x21_____closed__9;
+x_2 = l_Lean_Name_mkStr1(x_1);
+return x_2;
+}
+}
 static lean_object* _init_l_Std_termF_x21_____closed__11() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = lean_box(0);
+x_1 = lean_unsigned_to_nat(0u);
 x_2 = l_Std_termF_x21_____closed__10;
-x_3 = l_Lean_Name_str___override(x_1, x_2);
+x_3 = lean_alloc_ctor(7, 2, 0);
+lean_ctor_set(x_3, 0, x_2);
+lean_ctor_set(x_3, 1, x_1);
 return x_3;
 }
 }
@@ -158,50 +167,38 @@ _start:
 {
 lean_object* x_1; lean_object* x_2; lean_object* x_3; 
 x_1 = l_Std_termF_x21_____closed__11;
-x_2 = lean_unsigned_to_nat(0u);
-x_3 = lean_alloc_ctor(7, 2, 0);
-lean_ctor_set(x_3, 0, x_1);
-lean_ctor_set(x_3, 1, x_2);
+x_2 = l_Std_termF_x21_____closed__8;
+x_3 = lean_alloc_ctor(1, 2, 0);
+lean_ctor_set(x_3, 0, x_2);
+lean_ctor_set(x_3, 1, x_1);
 return x_3;
 }
 }
 static lean_object* _init_l_Std_termF_x21_____closed__13() {
 _start:
 {
-lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = l_Std_termF_x21_____closed__9;
-x_2 = l_Std_termF_x21_____closed__12;
-x_3 = lean_alloc_ctor(1, 2, 0);
-lean_ctor_set(x_3, 0, x_1);
-lean_ctor_set(x_3, 1, x_2);
-return x_3;
+lean_object* x_1; lean_object* x_2; lean_object* x_3; lean_object* x_4; 
+x_1 = l_Std_termF_x21_____closed__12;
+x_2 = l_Std_termF_x21_____closed__6;
+x_3 = l_Std_termF_x21_____closed__4;
+x_4 = lean_alloc_ctor(2, 3, 0);
+lean_ctor_set(x_4, 0, x_3);
+lean_ctor_set(x_4, 1, x_2);
+lean_ctor_set(x_4, 2, x_1);
+return x_4;
 }
 }
 static lean_object* _init_l_Std_termF_x21_____closed__14() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; lean_object* x_3; lean_object* x_4; 
-x_1 = l_Std_termF_x21_____closed__5;
-x_2 = l_Std_termF_x21_____closed__7;
-x_3 = l_Std_termF_x21_____closed__13;
-x_4 = lean_alloc_ctor(2, 3, 0);
-lean_ctor_set(x_4, 0, x_1);
-lean_ctor_set(x_4, 1, x_2);
-lean_ctor_set(x_4, 2, x_3);
-return x_4;
-}
-}
-static lean_object* _init_l_Std_termF_x21_____closed__15() {
-_start:
-{
-lean_object* x_1; lean_object* x_2; lean_object* x_3; lean_object* x_4; 
-x_1 = l_Std_termF_x21_____closed__3;
+x_1 = l_Std_termF_x21_____closed__13;
 x_2 = lean_unsigned_to_nat(1024u);
-x_3 = l_Std_termF_x21_____closed__14;
+x_3 = l_Std_termF_x21_____closed__2;
 x_4 = lean_alloc_ctor(3, 3, 0);
-lean_ctor_set(x_4, 0, x_1);
+lean_ctor_set(x_4, 0, x_3);
 lean_ctor_set(x_4, 1, x_2);
-lean_ctor_set(x_4, 2, x_3);
+lean_ctor_set(x_4, 2, x_1);
 return x_4;
 }
 }
@@ -209,11 +206,11 @@ static lean_object* _init_l_Std_termF_x21__() {
 _start:
 {
 lean_object* x_1; 
-x_1 = l_Std_termF_x21_____closed__15;
+x_1 = l_Std_termF_x21_____closed__14;
 return x_1;
 }
 }
-static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__1() {
+static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__0() {
 _start:
 {
 lean_object* x_1; 
@@ -221,12 +218,21 @@ x_1 = lean_mk_string_unchecked("Format", 6, 6);
 return x_1;
 }
 }
+static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__1() {
+_start:
+{
+lean_object* x_1; lean_object* x_2; 
+x_1 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__0;
+x_2 = l_String_toSubstring_x27(x_1);
+return x_2;
+}
+}
 static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__2() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; 
-x_1 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__1;
-x_2 = l_String_toSubstring_x27(x_1);
+x_1 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__0;
+x_2 = l_Lean_Name_mkStr1(x_1);
 return x_2;
 }
 }
@@ -234,9 +240,9 @@ static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules
 _start:
 {
 lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = lean_box(0);
-x_2 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__1;
-x_3 = l_Lean_Name_str___override(x_1, x_2);
+x_1 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__0;
+x_2 = l_Std_termF_x21_____closed__0;
+x_3 = l_Lean_Name_mkStr2(x_2, x_1);
 return x_3;
 }
 }
@@ -244,40 +250,42 @@ static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules
 _start:
 {
 lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = l_Std_termF_x21_____closed__1;
-x_2 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__1;
-x_3 = l_Lean_Name_mkStr2(x_1, x_2);
-return x_3;
-}
-}
-static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__5() {
-_start:
-{
-lean_object* x_1; lean_object* x_2; lean_object* x_3; 
 x_1 = lean_box(0);
-x_2 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__4;
+x_2 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__3;
 x_3 = lean_alloc_ctor(1, 2, 0);
 lean_ctor_set(x_3, 0, x_2);
 lean_ctor_set(x_3, 1, x_1);
 return x_3;
 }
 }
-static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__6() {
+static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__5() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; 
-x_1 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__4;
+x_1 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__3;
 x_2 = lean_alloc_ctor(0, 1, 0);
 lean_ctor_set(x_2, 0, x_1);
 return x_2;
 }
 }
+static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__6() {
+_start:
+{
+lean_object* x_1; lean_object* x_2; lean_object* x_3; 
+x_1 = lean_box(0);
+x_2 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__5;
+x_3 = lean_alloc_ctor(1, 2, 0);
+lean_ctor_set(x_3, 0, x_2);
+lean_ctor_set(x_3, 1, x_1);
+return x_3;
+}
+}
 static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__7() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = lean_box(0);
-x_2 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__6;
+x_1 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__6;
+x_2 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__4;
 x_3 = lean_alloc_ctor(1, 2, 0);
 lean_ctor_set(x_3, 0, x_2);
 lean_ctor_set(x_3, 1, x_1);
@@ -287,33 +295,21 @@ return x_3;
 static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__8() {
 _start:
 {
-lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__5;
-x_2 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__7;
-x_3 = lean_alloc_ctor(1, 2, 0);
-lean_ctor_set(x_3, 0, x_1);
-lean_ctor_set(x_3, 1, x_2);
-return x_3;
-}
-}
-static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__9() {
-_start:
-{
 lean_object* x_1; 
 x_1 = lean_mk_string_unchecked("Std.format", 10, 10);
 return x_1;
 }
 }
-static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__10() {
+static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__9() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; 
-x_1 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__9;
+x_1 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__8;
 x_2 = l_String_toSubstring_x27(x_1);
 return x_2;
 }
 }
-static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__11() {
+static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__10() {
 _start:
 {
 lean_object* x_1; 
@@ -321,17 +317,17 @@ x_1 = lean_mk_string_unchecked("format", 6, 6);
 return x_1;
 }
 }
-static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__12() {
+static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__11() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = l_Std_termF_x21_____closed__1;
-x_2 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__11;
-x_3 = l_Lean_Name_mkStr2(x_1, x_2);
+x_1 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__10;
+x_2 = l_Std_termF_x21_____closed__0;
+x_3 = l_Lean_Name_mkStr2(x_2, x_1);
 return x_3;
 }
 }
-static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__13() {
+static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__12() {
 _start:
 {
 lean_object* x_1; 
@@ -339,17 +335,29 @@ x_1 = lean_mk_string_unchecked("ToFormat", 8, 8);
 return x_1;
 }
 }
-static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__14() {
+static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__13() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; lean_object* x_3; lean_object* x_4; 
-x_1 = l_Std_termF_x21_____closed__1;
-x_2 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__13;
-x_3 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__11;
-x_4 = l_Lean_Name_mkStr3(x_1, x_2, x_3);
+x_1 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__10;
+x_2 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__12;
+x_3 = l_Std_termF_x21_____closed__0;
+x_4 = l_Lean_Name_mkStr3(x_3, x_2, x_1);
 return x_4;
 }
 }
+static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__14() {
+_start:
+{
+lean_object* x_1; lean_object* x_2; lean_object* x_3; 
+x_1 = lean_box(0);
+x_2 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__13;
+x_3 = lean_alloc_ctor(1, 2, 0);
+lean_ctor_set(x_3, 0, x_2);
+lean_ctor_set(x_3, 1, x_1);
+return x_3;
+}
+}
 static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__15() {
 _start:
 {
@@ -362,29 +370,17 @@ lean_ctor_set(x_3, 1, x_1);
 return x_3;
 }
 }
-static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__16() {
-_start:
-{
-lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = lean_box(0);
-x_2 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__15;
-x_3 = lean_alloc_ctor(1, 2, 0);
-lean_ctor_set(x_3, 0, x_2);
-lean_ctor_set(x_3, 1, x_1);
-return x_3;
-}
-}
 LEAN_EXPORT lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1(lean_object* x_1, lean_object* x_2, lean_object* x_3) {
 _start:
 {
 lean_object* x_4; uint8_t x_5; 
-x_4 = l_Std_termF_x21_____closed__3;
+x_4 = l_Std_termF_x21_____closed__2;
 lean_inc(x_1);
 x_5 = l_Lean_Syntax_isOfKind(x_1, x_4);
 if (x_5 == 0)
 {
 lean_object* x_6; lean_object* x_7; 
-lean_dec(x_2);
+lean_dec_ref(x_2);
 lean_dec(x_1);
 x_6 = lean_box(1);
 x_7 = lean_alloc_ctor(1, 2, 0);
@@ -394,42 +390,40 @@ return x_7;
 }
 else
 {
-lean_object* x_8; lean_object* x_9; lean_object* x_10; uint8_t x_11; lean_object* x_12; lean_object* x_13; lean_object* x_14; lean_object* x_15; lean_object* x_16; lean_object* x_17; lean_object* x_18; lean_object* x_19; lean_object* x_20; lean_object* x_21; lean_object* x_22; lean_object* x_23; lean_object* x_24; lean_object* x_25; 
-x_8 = lean_unsigned_to_nat(1u);
-x_9 = l_Lean_Syntax_getArg(x_1, x_8);
-lean_dec(x_1);
+lean_object* x_8; lean_object* x_9; lean_object* x_10; lean_object* x_11; lean_object* x_12; uint8_t x_13; lean_object* x_14; lean_object* x_15; lean_object* x_16; lean_object* x_17; lean_object* x_18; lean_object* x_19; lean_object* x_20; lean_object* x_21; lean_object* x_22; lean_object* x_23; lean_object* x_24; lean_object* x_25; 
+x_8 = lean_ctor_get(x_2, 1);
+x_9 = lean_ctor_get(x_2, 2);
 x_10 = lean_ctor_get(x_2, 5);
-lean_inc(x_10);
-x_11 = 0;
-x_12 = l_Lean_SourceInfo_fromRef(x_10, x_11);
-lean_dec(x_10);
-x_13 = lean_ctor_get(x_2, 2);
-lean_inc(x_13);
-x_14 = lean_ctor_get(x_2, 1);
+x_11 = lean_unsigned_to_nat(1u);
+x_12 = l_Lean_Syntax_getArg(x_1, x_11);
+lean_dec(x_1);
+x_13 = 0;
+x_14 = l_Lean_SourceInfo_fromRef(x_10, x_13);
+x_15 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__1;
+x_16 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__2;
+lean_inc(x_9);
+lean_inc(x_8);
+x_17 = l_Lean_addMacroScope(x_8, x_16, x_9);
+x_18 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__7;
 lean_inc(x_14);
-x_15 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__3;
-lean_inc(x_13);
-lean_inc(x_14);
-x_16 = l_Lean_addMacroScope(x_14, x_15, x_13);
-x_17 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__2;
-x_18 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__8;
-lean_inc(x_12);
 x_19 = lean_alloc_ctor(3, 4, 0);
-lean_ctor_set(x_19, 0, x_12);
-lean_ctor_set(x_19, 1, x_17);
-lean_ctor_set(x_19, 2, x_16);
+lean_ctor_set(x_19, 0, x_14);
+lean_ctor_set(x_19, 1, x_15);
+lean_ctor_set(x_19, 2, x_17);
 lean_ctor_set(x_19, 3, x_18);
-x_20 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__12;
-x_21 = l_Lean_addMacroScope(x_14, x_20, x_13);
-x_22 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__10;
-x_23 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__16;
+x_20 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__9;
+x_21 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__11;
+lean_inc(x_9);
+lean_inc(x_8);
+x_22 = l_Lean_addMacroScope(x_8, x_21, x_9);
+x_23 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__15;
 x_24 = lean_alloc_ctor(3, 4, 0);
-lean_ctor_set(x_24, 0, x_12);
-lean_ctor_set(x_24, 1, x_22);
-lean_ctor_set(x_24, 2, x_21);
+lean_ctor_set(x_24, 0, x_14);
+lean_ctor_set(x_24, 1, x_20);
+lean_ctor_set(x_24, 2, x_22);
 lean_ctor_set(x_24, 3, x_23);
-x_25 = l_Lean_TSyntax_expandInterpolatedStr(x_9, x_19, x_24, x_2, x_3);
-lean_dec(x_9);
+x_25 = l_Lean_TSyntax_expandInterpolatedStr(x_12, x_19, x_24, x_2, x_3);
+lean_dec(x_12);
 if (lean_obj_tag(x_25) == 0)
 {
 uint8_t x_26; 
@@ -490,6 +484,8 @@ lean_dec_ref(res);
 res = initialize_Init_Data_ToString_Macro(builtin, lean_io_mk_world());
 if (lean_io_result_is_error(res)) return res;
 lean_dec_ref(res);
+l_Std_termF_x21_____closed__0 = _init_l_Std_termF_x21_____closed__0();
+lean_mark_persistent(l_Std_termF_x21_____closed__0);
 l_Std_termF_x21_____closed__1 = _init_l_Std_termF_x21_____closed__1();
 lean_mark_persistent(l_Std_termF_x21_____closed__1);
 l_Std_termF_x21_____closed__2 = _init_l_Std_termF_x21_____closed__2();
@@ -518,10 +514,10 @@ l_Std_termF_x21_____closed__13 = _init_l_Std_termF_x21_____closed__13();
 lean_mark_persistent(l_Std_termF_x21_____closed__13);
 l_Std_termF_x21_____closed__14 = _init_l_Std_termF_x21_____closed__14();
 lean_mark_persistent(l_Std_termF_x21_____closed__14);
-l_Std_termF_x21_____closed__15 = _init_l_Std_termF_x21_____closed__15();
-lean_mark_persistent(l_Std_termF_x21_____closed__15);
 l_Std_termF_x21__ = _init_l_Std_termF_x21__();
 lean_mark_persistent(l_Std_termF_x21__);
+l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__0 = _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__0();
+lean_mark_persistent(l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__0);
 l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__1 = _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__1();
 lean_mark_persistent(l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__1);
 l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__2 = _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__2();
@@ -552,8 +548,6 @@ l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___cl
 lean_mark_persistent(l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__14);
 l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__15 = _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__15();
 lean_mark_persistent(l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__15);
-l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__16 = _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__16();
-lean_mark_persistent(l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__16);
 return lean_io_result_mk_ok(lean_box(0));
 }
 #ifdef __cplusplus
