@@ -1,6 +1,6 @@
 // Lean compiler output
 // Module: Init.Data.Int.Lemmas
-// Imports: Init.Data.Int.Basic Init.Conv Init.NotationExtra Init.PropLemmas
+// Imports: Init.Conv Init.NotationExtra Init.PropLemmas
 #include <lean/lean.h>
 #if defined(__clang__)
 #pragma clang diagnostic ignored "-Wunused-parameter"
@@ -13,7 +13,6 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
-lean_object* initialize_Init_Data_Int_Basic(uint8_t builtin, lean_object*);
 lean_object* initialize_Init_Conv(uint8_t builtin, lean_object*);
 lean_object* initialize_Init_NotationExtra(uint8_t builtin, lean_object*);
 lean_object* initialize_Init_PropLemmas(uint8_t builtin, lean_object*);
@@ -22,9 +21,6 @@ LEAN_EXPORT lean_object* initialize_Init_Data_Int_Lemmas(uint8_t builtin, lean_o
 lean_object * res;
 if (_G_initialized) return lean_io_result_mk_ok(lean_box(0));
 _G_initialized = true;
-res = initialize_Init_Data_Int_Basic(builtin, lean_io_mk_world());
-if (lean_io_result_is_error(res)) return res;
-lean_dec_ref(res);
 res = initialize_Init_Conv(builtin, lean_io_mk_world());
 if (lean_io_result_is_error(res)) return res;
 lean_dec_ref(res);
