@@ -1,6 +1,6 @@
 // Lean compiler output
 // Module: Init.Data.Option.List
-// Imports: Init.Data.List.Lemmas
+// Imports: Init.Data.List.Lemmas Init.Data.List.Control Init.Data.Option.Instances
 #include <lean/lean.h>
 #if defined(__clang__)
 #pragma clang diagnostic ignored "-Wunused-parameter"
@@ -14,6 +14,8 @@
 extern "C" {
 #endif
 lean_object* initialize_Init_Data_List_Lemmas(uint8_t builtin, lean_object*);
+lean_object* initialize_Init_Data_List_Control(uint8_t builtin, lean_object*);
+lean_object* initialize_Init_Data_Option_Instances(uint8_t builtin, lean_object*);
 static bool _G_initialized = false;
 LEAN_EXPORT lean_object* initialize_Init_Data_Option_List(uint8_t builtin, lean_object* w) {
 lean_object * res;
@@ -22,6 +24,12 @@ _G_initialized = true;
 res = initialize_Init_Data_List_Lemmas(builtin, lean_io_mk_world());
 if (lean_io_result_is_error(res)) return res;
 lean_dec_ref(res);
+res = initialize_Init_Data_List_Control(builtin, lean_io_mk_world());
+if (lean_io_result_is_error(res)) return res;
+lean_dec_ref(res);
+res = initialize_Init_Data_Option_Instances(builtin, lean_io_mk_world());
+if (lean_io_result_is_error(res)) return res;
+lean_dec_ref(res);
 return lean_io_result_mk_ok(lean_box(0));
 }
 #ifdef __cplusplus
