@@ -1,6 +1,6 @@
 // Lean compiler output
 // Module: Init.Data.Subtype
-// Imports: Init.Ext
+// Imports: Init.Data.Subtype.Basic Init.Data.Subtype.Order Init.Data.Subtype.OrderExtra
 #include <lean/lean.h>
 #if defined(__clang__)
 #pragma clang diagnostic ignored "-Wunused-parameter"
@@ -13,13 +13,21 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
-lean_object* initialize_Init_Ext(uint8_t builtin, lean_object*);
+lean_object* initialize_Init_Data_Subtype_Basic(uint8_t builtin, lean_object*);
+lean_object* initialize_Init_Data_Subtype_Order(uint8_t builtin, lean_object*);
+lean_object* initialize_Init_Data_Subtype_OrderExtra(uint8_t builtin, lean_object*);
 static bool _G_initialized = false;
 LEAN_EXPORT lean_object* initialize_Init_Data_Subtype(uint8_t builtin, lean_object* w) {
 lean_object * res;
 if (_G_initialized) return lean_io_result_mk_ok(lean_box(0));
 _G_initialized = true;
-res = initialize_Init_Ext(builtin, lean_io_mk_world());
+res = initialize_Init_Data_Subtype_Basic(builtin, lean_io_mk_world());
+if (lean_io_result_is_error(res)) return res;
+lean_dec_ref(res);
+res = initialize_Init_Data_Subtype_Order(builtin, lean_io_mk_world());
+if (lean_io_result_is_error(res)) return res;
+lean_dec_ref(res);
+res = initialize_Init_Data_Subtype_OrderExtra(builtin, lean_io_mk_world());
 if (lean_io_result_is_error(res)) return res;
 lean_dec_ref(res);
 return lean_io_result_mk_ok(lean_box(0));
