@@ -1,6 +1,6 @@
 // Lean compiler output
 // Module: Init.Data.ToString.Macro
-// Imports: Init.Meta Init.Data.ToString.Basic
+// Imports: Init.Meta
 #include <lean/lean.h>
 #if defined(__clang__)
 #pragma clang diagnostic ignored "-Wunused-parameter"
@@ -18,6 +18,7 @@ static lean_object* l_termS_x21_____closed__1;
 static lean_object* l_termS_x21_____closed__13;
 static lean_object* l_termS_x21_____closed__4;
 lean_object* l_Lean_TSyntax_expandInterpolatedStr(lean_object*, lean_object*, lean_object*, lean_object*, lean_object*);
+static lean_object* l_termS_x21_____closed__0;
 static lean_object* l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__7;
 uint8_t l_Lean_Syntax_isOfKind(lean_object*, lean_object*);
 static lean_object* l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__11;
@@ -32,7 +33,6 @@ static lean_object* l_termS_x21_____closed__11;
 static lean_object* l_termS_x21_____closed__7;
 static lean_object* l_termS_x21_____closed__9;
 lean_object* l_Lean_addMacroScope(lean_object*, lean_object*, lean_object*);
-lean_object* l_Lean_Name_str___override(lean_object*, lean_object*);
 lean_object* l_Lean_Syntax_getArg(lean_object*, lean_object*);
 static lean_object* l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__8;
 LEAN_EXPORT lean_object* l_termS_x21__;
@@ -45,13 +45,13 @@ static lean_object* l___aux__Init__Data__ToString__Macro______macroRules__termS_
 static lean_object* l_termS_x21_____closed__8;
 static lean_object* l_termS_x21_____closed__12;
 static lean_object* l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__6;
-static lean_object* l_termS_x21_____closed__14;
+lean_object* l_Lean_Name_mkStr1(lean_object*);
 static lean_object* l_termS_x21_____closed__2;
 static lean_object* l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__9;
-static lean_object* l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__14;
 lean_object* l_String_toSubstring_x27(lean_object*);
+static lean_object* l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__0;
 static lean_object* l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__13;
-static lean_object* _init_l_termS_x21_____closed__1() {
+static lean_object* _init_l_termS_x21_____closed__0() {
 _start:
 {
 lean_object* x_1; 
@@ -59,17 +59,16 @@ x_1 = lean_mk_string_unchecked("termS!_", 7, 7);
 return x_1;
 }
 }
-static lean_object* _init_l_termS_x21_____closed__2() {
+static lean_object* _init_l_termS_x21_____closed__1() {
 _start:
 {
-lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = lean_box(0);
-x_2 = l_termS_x21_____closed__1;
-x_3 = l_Lean_Name_str___override(x_1, x_2);
-return x_3;
+lean_object* x_1; lean_object* x_2; 
+x_1 = l_termS_x21_____closed__0;
+x_2 = l_Lean_Name_mkStr1(x_1);
+return x_2;
 }
 }
-static lean_object* _init_l_termS_x21_____closed__3() {
+static lean_object* _init_l_termS_x21_____closed__2() {
 _start:
 {
 lean_object* x_1; 
@@ -77,17 +76,16 @@ x_1 = lean_mk_string_unchecked("andthen", 7, 7);
 return x_1;
 }
 }
-static lean_object* _init_l_termS_x21_____closed__4() {
+static lean_object* _init_l_termS_x21_____closed__3() {
 _start:
 {
-lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = lean_box(0);
-x_2 = l_termS_x21_____closed__3;
-x_3 = l_Lean_Name_str___override(x_1, x_2);
-return x_3;
+lean_object* x_1; lean_object* x_2; 
+x_1 = l_termS_x21_____closed__2;
+x_2 = l_Lean_Name_mkStr1(x_1);
+return x_2;
 }
 }
-static lean_object* _init_l_termS_x21_____closed__5() {
+static lean_object* _init_l_termS_x21_____closed__4() {
 _start:
 {
 lean_object* x_1; 
@@ -95,17 +93,17 @@ x_1 = lean_mk_string_unchecked("s!", 2, 2);
 return x_1;
 }
 }
-static lean_object* _init_l_termS_x21_____closed__6() {
+static lean_object* _init_l_termS_x21_____closed__5() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; 
-x_1 = l_termS_x21_____closed__5;
+x_1 = l_termS_x21_____closed__4;
 x_2 = lean_alloc_ctor(5, 1, 0);
 lean_ctor_set(x_2, 0, x_1);
 return x_2;
 }
 }
-static lean_object* _init_l_termS_x21_____closed__7() {
+static lean_object* _init_l_termS_x21_____closed__6() {
 _start:
 {
 lean_object* x_1; 
@@ -113,17 +111,16 @@ x_1 = lean_mk_string_unchecked("interpolatedStr", 15, 15);
 return x_1;
 }
 }
-static lean_object* _init_l_termS_x21_____closed__8() {
+static lean_object* _init_l_termS_x21_____closed__7() {
 _start:
 {
-lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = lean_box(0);
-x_2 = l_termS_x21_____closed__7;
-x_3 = l_Lean_Name_str___override(x_1, x_2);
-return x_3;
+lean_object* x_1; lean_object* x_2; 
+x_1 = l_termS_x21_____closed__6;
+x_2 = l_Lean_Name_mkStr1(x_1);
+return x_2;
 }
 }
-static lean_object* _init_l_termS_x21_____closed__9() {
+static lean_object* _init_l_termS_x21_____closed__8() {
 _start:
 {
 lean_object* x_1; 
@@ -131,13 +128,24 @@ x_1 = lean_mk_string_unchecked("term", 4, 4);
 return x_1;
 }
 }
+static lean_object* _init_l_termS_x21_____closed__9() {
+_start:
+{
+lean_object* x_1; lean_object* x_2; 
+x_1 = l_termS_x21_____closed__8;
+x_2 = l_Lean_Name_mkStr1(x_1);
+return x_2;
+}
+}
 static lean_object* _init_l_termS_x21_____closed__10() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = lean_box(0);
+x_1 = lean_unsigned_to_nat(0u);
 x_2 = l_termS_x21_____closed__9;
-x_3 = l_Lean_Name_str___override(x_1, x_2);
+x_3 = lean_alloc_ctor(7, 2, 0);
+lean_ctor_set(x_3, 0, x_2);
+lean_ctor_set(x_3, 1, x_1);
 return x_3;
 }
 }
@@ -146,50 +154,38 @@ _start:
 {
 lean_object* x_1; lean_object* x_2; lean_object* x_3; 
 x_1 = l_termS_x21_____closed__10;
-x_2 = lean_unsigned_to_nat(0u);
-x_3 = lean_alloc_ctor(7, 2, 0);
-lean_ctor_set(x_3, 0, x_1);
-lean_ctor_set(x_3, 1, x_2);
+x_2 = l_termS_x21_____closed__7;
+x_3 = lean_alloc_ctor(1, 2, 0);
+lean_ctor_set(x_3, 0, x_2);
+lean_ctor_set(x_3, 1, x_1);
 return x_3;
 }
 }
 static lean_object* _init_l_termS_x21_____closed__12() {
 _start:
 {
-lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = l_termS_x21_____closed__8;
-x_2 = l_termS_x21_____closed__11;
-x_3 = lean_alloc_ctor(1, 2, 0);
-lean_ctor_set(x_3, 0, x_1);
-lean_ctor_set(x_3, 1, x_2);
-return x_3;
+lean_object* x_1; lean_object* x_2; lean_object* x_3; lean_object* x_4; 
+x_1 = l_termS_x21_____closed__11;
+x_2 = l_termS_x21_____closed__5;
+x_3 = l_termS_x21_____closed__3;
+x_4 = lean_alloc_ctor(2, 3, 0);
+lean_ctor_set(x_4, 0, x_3);
+lean_ctor_set(x_4, 1, x_2);
+lean_ctor_set(x_4, 2, x_1);
+return x_4;
 }
 }
 static lean_object* _init_l_termS_x21_____closed__13() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; lean_object* x_3; lean_object* x_4; 
-x_1 = l_termS_x21_____closed__4;
-x_2 = l_termS_x21_____closed__6;
-x_3 = l_termS_x21_____closed__12;
-x_4 = lean_alloc_ctor(2, 3, 0);
-lean_ctor_set(x_4, 0, x_1);
-lean_ctor_set(x_4, 1, x_2);
-lean_ctor_set(x_4, 2, x_3);
-return x_4;
-}
-}
-static lean_object* _init_l_termS_x21_____closed__14() {
-_start:
-{
-lean_object* x_1; lean_object* x_2; lean_object* x_3; lean_object* x_4; 
-x_1 = l_termS_x21_____closed__2;
+x_1 = l_termS_x21_____closed__12;
 x_2 = lean_unsigned_to_nat(1024u);
-x_3 = l_termS_x21_____closed__13;
+x_3 = l_termS_x21_____closed__1;
 x_4 = lean_alloc_ctor(3, 3, 0);
-lean_ctor_set(x_4, 0, x_1);
+lean_ctor_set(x_4, 0, x_3);
 lean_ctor_set(x_4, 1, x_2);
-lean_ctor_set(x_4, 2, x_3);
+lean_ctor_set(x_4, 2, x_1);
 return x_4;
 }
 }
@@ -197,11 +193,11 @@ static lean_object* _init_l_termS_x21__() {
 _start:
 {
 lean_object* x_1; 
-x_1 = l_termS_x21_____closed__14;
+x_1 = l_termS_x21_____closed__13;
 return x_1;
 }
 }
-static lean_object* _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__1() {
+static lean_object* _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__0() {
 _start:
 {
 lean_object* x_1; 
@@ -209,12 +205,21 @@ x_1 = lean_mk_string_unchecked("String", 6, 6);
 return x_1;
 }
 }
+static lean_object* _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__1() {
+_start:
+{
+lean_object* x_1; lean_object* x_2; 
+x_1 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__0;
+x_2 = l_String_toSubstring_x27(x_1);
+return x_2;
+}
+}
 static lean_object* _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__2() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; 
-x_1 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__1;
-x_2 = l_String_toSubstring_x27(x_1);
+x_1 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__0;
+x_2 = l_Lean_Name_mkStr1(x_1);
 return x_2;
 }
 }
@@ -223,39 +228,41 @@ _start:
 {
 lean_object* x_1; lean_object* x_2; lean_object* x_3; 
 x_1 = lean_box(0);
-x_2 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__1;
-x_3 = l_Lean_Name_str___override(x_1, x_2);
-return x_3;
-}
-}
-static lean_object* _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__4() {
-_start:
-{
-lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = lean_box(0);
-x_2 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__3;
+x_2 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__2;
 x_3 = lean_alloc_ctor(1, 2, 0);
 lean_ctor_set(x_3, 0, x_2);
 lean_ctor_set(x_3, 1, x_1);
 return x_3;
 }
 }
-static lean_object* _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__5() {
+static lean_object* _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__4() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; 
-x_1 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__3;
+x_1 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__2;
 x_2 = lean_alloc_ctor(0, 1, 0);
 lean_ctor_set(x_2, 0, x_1);
 return x_2;
 }
 }
+static lean_object* _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__5() {
+_start:
+{
+lean_object* x_1; lean_object* x_2; lean_object* x_3; 
+x_1 = lean_box(0);
+x_2 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__4;
+x_3 = lean_alloc_ctor(1, 2, 0);
+lean_ctor_set(x_3, 0, x_2);
+lean_ctor_set(x_3, 1, x_1);
+return x_3;
+}
+}
 static lean_object* _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__6() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = lean_box(0);
-x_2 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__5;
+x_1 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__5;
+x_2 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__3;
 x_3 = lean_alloc_ctor(1, 2, 0);
 lean_ctor_set(x_3, 0, x_2);
 lean_ctor_set(x_3, 1, x_1);
@@ -265,57 +272,56 @@ return x_3;
 static lean_object* _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__7() {
 _start:
 {
-lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__4;
-x_2 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__6;
-x_3 = lean_alloc_ctor(1, 2, 0);
-lean_ctor_set(x_3, 0, x_1);
-lean_ctor_set(x_3, 1, x_2);
-return x_3;
+lean_object* x_1; 
+x_1 = lean_mk_string_unchecked("toString", 8, 8);
+return x_1;
 }
 }
 static lean_object* _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__8() {
 _start:
 {
-lean_object* x_1; 
-x_1 = lean_mk_string_unchecked("toString", 8, 8);
-return x_1;
+lean_object* x_1; lean_object* x_2; 
+x_1 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__7;
+x_2 = l_String_toSubstring_x27(x_1);
+return x_2;
 }
 }
 static lean_object* _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__9() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; 
-x_1 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__8;
-x_2 = l_String_toSubstring_x27(x_1);
+x_1 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__7;
+x_2 = l_Lean_Name_mkStr1(x_1);
 return x_2;
 }
 }
 static lean_object* _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__10() {
 _start:
 {
-lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = lean_box(0);
-x_2 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__8;
-x_3 = l_Lean_Name_str___override(x_1, x_2);
-return x_3;
-}
-}
-static lean_object* _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__11() {
-_start:
-{
 lean_object* x_1; 
 x_1 = lean_mk_string_unchecked("ToString", 8, 8);
 return x_1;
 }
 }
+static lean_object* _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__11() {
+_start:
+{
+lean_object* x_1; lean_object* x_2; lean_object* x_3; 
+x_1 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__7;
+x_2 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__10;
+x_3 = l_Lean_Name_mkStr2(x_2, x_1);
+return x_3;
+}
+}
 static lean_object* _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__12() {
 _start:
 {
 lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__11;
-x_2 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__8;
-x_3 = l_Lean_Name_mkStr2(x_1, x_2);
+x_1 = lean_box(0);
+x_2 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__11;
+x_3 = lean_alloc_ctor(1, 2, 0);
+lean_ctor_set(x_3, 0, x_2);
+lean_ctor_set(x_3, 1, x_1);
 return x_3;
 }
 }
@@ -331,29 +337,17 @@ lean_ctor_set(x_3, 1, x_1);
 return x_3;
 }
 }
-static lean_object* _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__14() {
-_start:
-{
-lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = lean_box(0);
-x_2 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__13;
-x_3 = lean_alloc_ctor(1, 2, 0);
-lean_ctor_set(x_3, 0, x_2);
-lean_ctor_set(x_3, 1, x_1);
-return x_3;
-}
-}
 LEAN_EXPORT lean_object* l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1(lean_object* x_1, lean_object* x_2, lean_object* x_3) {
 _start:
 {
 lean_object* x_4; uint8_t x_5; 
-x_4 = l_termS_x21_____closed__2;
+x_4 = l_termS_x21_____closed__1;
 lean_inc(x_1);
 x_5 = l_Lean_Syntax_isOfKind(x_1, x_4);
 if (x_5 == 0)
 {
 lean_object* x_6; lean_object* x_7; 
-lean_dec(x_2);
+lean_dec_ref(x_2);
 lean_dec(x_1);
 x_6 = lean_box(1);
 x_7 = lean_alloc_ctor(1, 2, 0);
@@ -363,42 +357,40 @@ return x_7;
 }
 else
 {
-lean_object* x_8; lean_object* x_9; lean_object* x_10; uint8_t x_11; lean_object* x_12; lean_object* x_13; lean_object* x_14; lean_object* x_15; lean_object* x_16; lean_object* x_17; lean_object* x_18; lean_object* x_19; lean_object* x_20; lean_object* x_21; lean_object* x_22; lean_object* x_23; lean_object* x_24; lean_object* x_25; 
-x_8 = lean_unsigned_to_nat(1u);
-x_9 = l_Lean_Syntax_getArg(x_1, x_8);
-lean_dec(x_1);
+lean_object* x_8; lean_object* x_9; lean_object* x_10; lean_object* x_11; lean_object* x_12; uint8_t x_13; lean_object* x_14; lean_object* x_15; lean_object* x_16; lean_object* x_17; lean_object* x_18; lean_object* x_19; lean_object* x_20; lean_object* x_21; lean_object* x_22; lean_object* x_23; lean_object* x_24; lean_object* x_25; 
+x_8 = lean_ctor_get(x_2, 1);
+x_9 = lean_ctor_get(x_2, 2);
 x_10 = lean_ctor_get(x_2, 5);
-lean_inc(x_10);
-x_11 = 0;
-x_12 = l_Lean_SourceInfo_fromRef(x_10, x_11);
-lean_dec(x_10);
-x_13 = lean_ctor_get(x_2, 2);
-lean_inc(x_13);
-x_14 = lean_ctor_get(x_2, 1);
+x_11 = lean_unsigned_to_nat(1u);
+x_12 = l_Lean_Syntax_getArg(x_1, x_11);
+lean_dec(x_1);
+x_13 = 0;
+x_14 = l_Lean_SourceInfo_fromRef(x_10, x_13);
+x_15 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__1;
+x_16 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__2;
+lean_inc(x_9);
+lean_inc(x_8);
+x_17 = l_Lean_addMacroScope(x_8, x_16, x_9);
+x_18 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__6;
 lean_inc(x_14);
-x_15 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__3;
-lean_inc(x_13);
-lean_inc(x_14);
-x_16 = l_Lean_addMacroScope(x_14, x_15, x_13);
-x_17 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__2;
-x_18 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__7;
-lean_inc(x_12);
 x_19 = lean_alloc_ctor(3, 4, 0);
-lean_ctor_set(x_19, 0, x_12);
-lean_ctor_set(x_19, 1, x_17);
-lean_ctor_set(x_19, 2, x_16);
+lean_ctor_set(x_19, 0, x_14);
+lean_ctor_set(x_19, 1, x_15);
+lean_ctor_set(x_19, 2, x_17);
 lean_ctor_set(x_19, 3, x_18);
-x_20 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__10;
-x_21 = l_Lean_addMacroScope(x_14, x_20, x_13);
-x_22 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__9;
-x_23 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__14;
+x_20 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__8;
+x_21 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__9;
+lean_inc(x_9);
+lean_inc(x_8);
+x_22 = l_Lean_addMacroScope(x_8, x_21, x_9);
+x_23 = l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__13;
 x_24 = lean_alloc_ctor(3, 4, 0);
-lean_ctor_set(x_24, 0, x_12);
-lean_ctor_set(x_24, 1, x_22);
-lean_ctor_set(x_24, 2, x_21);
+lean_ctor_set(x_24, 0, x_14);
+lean_ctor_set(x_24, 1, x_20);
+lean_ctor_set(x_24, 2, x_22);
 lean_ctor_set(x_24, 3, x_23);
-x_25 = l_Lean_TSyntax_expandInterpolatedStr(x_9, x_19, x_24, x_2, x_3);
-lean_dec(x_9);
+x_25 = l_Lean_TSyntax_expandInterpolatedStr(x_12, x_19, x_24, x_2, x_3);
+lean_dec(x_12);
 if (lean_obj_tag(x_25) == 0)
 {
 uint8_t x_26; 
@@ -447,7 +439,6 @@ return x_33;
 }
 }
 lean_object* initialize_Init_Meta(uint8_t builtin, lean_object*);
-lean_object* initialize_Init_Data_ToString_Basic(uint8_t builtin, lean_object*);
 static bool _G_initialized = false;
 LEAN_EXPORT lean_object* initialize_Init_Data_ToString_Macro(uint8_t builtin, lean_object* w) {
 lean_object * res;
@@ -456,9 +447,8 @@ _G_initialized = true;
 res = initialize_Init_Meta(builtin, lean_io_mk_world());
 if (lean_io_result_is_error(res)) return res;
 lean_dec_ref(res);
-res = initialize_Init_Data_ToString_Basic(builtin, lean_io_mk_world());
-if (lean_io_result_is_error(res)) return res;
-lean_dec_ref(res);
+l_termS_x21_____closed__0 = _init_l_termS_x21_____closed__0();
+lean_mark_persistent(l_termS_x21_____closed__0);
 l_termS_x21_____closed__1 = _init_l_termS_x21_____closed__1();
 lean_mark_persistent(l_termS_x21_____closed__1);
 l_termS_x21_____closed__2 = _init_l_termS_x21_____closed__2();
@@ -485,10 +475,10 @@ l_termS_x21_____closed__12 = _init_l_termS_x21_____closed__12();
 lean_mark_persistent(l_termS_x21_____closed__12);
 l_termS_x21_____closed__13 = _init_l_termS_x21_____closed__13();
 lean_mark_persistent(l_termS_x21_____closed__13);
-l_termS_x21_____closed__14 = _init_l_termS_x21_____closed__14();
-lean_mark_persistent(l_termS_x21_____closed__14);
 l_termS_x21__ = _init_l_termS_x21__();
 lean_mark_persistent(l_termS_x21__);
+l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__0 = _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__0();
+lean_mark_persistent(l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__0);
 l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__1 = _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__1();
 lean_mark_persistent(l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__1);
 l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__2 = _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__2();
@@ -515,8 +505,6 @@ l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__1
 lean_mark_persistent(l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__12);
 l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__13 = _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__13();
 lean_mark_persistent(l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__13);
-l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__14 = _init_l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__14();
-lean_mark_persistent(l___aux__Init__Data__ToString__Macro______macroRules__termS_x21____1___closed__14);
 return lean_io_result_mk_ok(lean_box(0));
 }
 #ifdef __cplusplus
