@@ -18,81 +18,105 @@ uint8_t lean_uint32_to_uint8(uint32_t);
 LEAN_EXPORT uint64_t l_UInt64_instOfNat(lean_object*);
 uint16_t lean_uint64_to_uint16(uint64_t);
 lean_object* lean_uint32_to_nat(uint32_t);
+LEAN_EXPORT lean_object* l_UInt16_toFin(uint16_t);
+LEAN_EXPORT lean_object* l_USize_toFin___boxed(lean_object*);
+static lean_object* l_USize_ofNatTruncate___closed__1;
 LEAN_EXPORT uint8_t l_UInt8_instOfNat(lean_object*);
 LEAN_EXPORT uint32_t l_UInt32_ofNatTruncate(lean_object*);
 uint8_t lean_usize_dec_le(size_t, size_t);
 uint64_t lean_uint64_of_nat(lean_object*);
+LEAN_EXPORT lean_object* l_UInt8_toFin(uint8_t);
+static uint16_t l_UInt16_ofNatTruncate___closed__0;
+static lean_object* l_UInt64_ofNatTruncate___closed__1;
 uint32_t lean_uint8_to_uint32(uint8_t);
 LEAN_EXPORT lean_object* l_Nat_toUInt16___boxed(lean_object*);
-LEAN_EXPORT uint8_t l_instDecidableLtUSize(size_t, size_t);
 LEAN_EXPORT lean_object* l_USize_instOfNat___boxed(lean_object*);
+uint16_t lean_uint16_of_nat(lean_object*);
 LEAN_EXPORT lean_object* l_instLEUSize;
 LEAN_EXPORT lean_object* l_Nat_toUSize___boxed(lean_object*);
+LEAN_EXPORT lean_object* l_UInt64_ofNatTruncate___boxed(lean_object*);
 LEAN_EXPORT lean_object* l_UInt8_val___boxed(lean_object*);
+LEAN_EXPORT size_t l_USize_ofNatTruncate(lean_object*);
 LEAN_EXPORT lean_object* l_UInt8_toUInt32___boxed(lean_object*);
-static lean_object* l_instSubUSize___closed__1;
 LEAN_EXPORT lean_object* l_UInt16_val___boxed(lean_object*);
 LEAN_EXPORT lean_object* l_UInt32_toUInt16___boxed(lean_object*);
-static uint32_t l_UInt32_ofNatTruncate___closed__2;
 LEAN_EXPORT lean_object* l_UInt8_toUInt64___boxed(lean_object*);
 LEAN_EXPORT uint32_t l_Nat_toUInt32(lean_object*);
+LEAN_EXPORT lean_object* l_UInt16_ofNatTruncate___boxed(lean_object*);
 size_t lean_usize_of_nat(lean_object*);
+static size_t l_USize_ofNatTruncate___closed__2;
 LEAN_EXPORT lean_object* l_UInt8_ofNat___boxed(lean_object*);
+static uint32_t l_UInt32_ofNatTruncate___closed__0;
 LEAN_EXPORT lean_object* l_UInt16_val(uint16_t);
 LEAN_EXPORT lean_object* l_USize_decLe___boxed(lean_object*, lean_object*);
+LEAN_EXPORT uint64_t l_UInt64_ofNatTruncate(lean_object*);
 LEAN_EXPORT lean_object* l_UInt16_toNat___boxed(lean_object*);
 LEAN_EXPORT lean_object* l_UInt32_instOfNat___boxed(lean_object*);
 uint32_t lean_uint32_of_nat(lean_object*);
+LEAN_EXPORT uint16_t l_UInt16_ofNatTruncate(lean_object*);
 LEAN_EXPORT lean_object* l_UInt64_instOfNat___boxed(lean_object*);
+uint32_t lean_uint32_of_nat(lean_object*);
+LEAN_EXPORT lean_object* l_UInt32_ofNat_x27___redArg___boxed(lean_object*);
 uint64_t lean_uint8_to_uint64(uint8_t);
 LEAN_EXPORT uint16_t l_Nat_toUInt16(lean_object*);
 LEAN_EXPORT lean_object* l_UInt64_val(uint64_t);
+static lean_object* l_instAddUSize___closed__0;
 LEAN_EXPORT lean_object* l_USize_decLt___boxed(lean_object*, lean_object*);
-LEAN_EXPORT lean_object* l_instDecidableLtUSize___boxed(lean_object*, lean_object*);
+static lean_object* l_UInt64_ofNatTruncate___closed__0;
 LEAN_EXPORT lean_object* l_USize_toNat___boxed(lean_object*);
+static uint8_t l_UInt8_ofNatTruncate___closed__0;
 lean_object* lean_uint64_to_nat(uint64_t);
 LEAN_EXPORT lean_object* l_UInt64_toUInt8___boxed(lean_object*);
 uint16_t lean_uint32_to_uint16(uint32_t);
 LEAN_EXPORT uint8_t l_Nat_toUInt8(lean_object*);
+LEAN_EXPORT lean_object* l_UInt32_toFin___boxed(lean_object*);
 lean_object* lean_uint8_to_nat(uint8_t);
+uint64_t lean_uint64_of_nat(lean_object*);
 uint16_t lean_uint8_to_uint16(uint8_t);
+LEAN_EXPORT uint32_t l_UInt32_ofNat_x27___redArg(lean_object*);
+LEAN_EXPORT uint8_t l_UInt8_ofNatTruncate(lean_object*);
 LEAN_EXPORT lean_object* l_UInt64_val___boxed(lean_object*);
 LEAN_EXPORT lean_object* l_UInt64_toUInt16___boxed(lean_object*);
 uint8_t lean_uint64_to_uint8(uint64_t);
 LEAN_EXPORT lean_object* l_UInt32_ofNat___boxed(lean_object*);
+extern lean_object* l_System_Platform_numBits;
 lean_object* lean_usize_to_nat(size_t);
 LEAN_EXPORT lean_object* l_USize_val___boxed(lean_object*);
 uint16_t lean_uint16_of_nat(lean_object*);
 uint32_t lean_uint64_to_uint32(uint64_t);
 LEAN_EXPORT lean_object* l_UInt64_ofNat___boxed(lean_object*);
 uint64_t lean_uint32_to_uint64(uint32_t);
+LEAN_EXPORT lean_object* l_USize_ofNatTruncate___boxed(lean_object*);
 uint8_t lean_uint16_to_uint8(uint16_t);
+static uint64_t l_UInt64_ofNatTruncate___closed__2;
 LEAN_EXPORT lean_object* l_USize_val(size_t);
 LEAN_EXPORT lean_object* l_Nat_toUInt32___boxed(lean_object*);
 lean_object* lean_usize_to_nat(size_t);
 LEAN_EXPORT lean_object* l_UInt64_toNat___boxed(lean_object*);
-static lean_object* l_UInt32_ofNatTruncate___closed__1;
 LEAN_EXPORT lean_object* l_UInt8_toNat___boxed(lean_object*);
 LEAN_EXPORT size_t l_Nat_toUSize(lean_object*);
-LEAN_EXPORT lean_object* l_instDecidableLeUSize___boxed(lean_object*, lean_object*);
+size_t lean_usize_of_nat(lean_object*);
+LEAN_EXPORT lean_object* l_UInt8_ofNatTruncate___boxed(lean_object*);
 LEAN_EXPORT lean_object* l_instLTUSize;
 LEAN_EXPORT lean_object* l_UInt16_toUInt64___boxed(lean_object*);
 uint64_t lean_uint16_to_uint64(uint16_t);
+lean_object* lean_nat_pow(lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_UInt16_toUInt8___boxed(lean_object*);
-uint32_t lean_uint32_of_nat(lean_object*);
+LEAN_EXPORT uint32_t l_UInt32_ofNat_x27(lean_object*, lean_object*);
 uint8_t lean_nat_dec_lt(lean_object*, lean_object*);
 LEAN_EXPORT uint64_t l_Nat_toUInt64(lean_object*);
 LEAN_EXPORT lean_object* l_UInt64_toUInt32___boxed(lean_object*);
-static lean_object* l_instAddUSize___closed__1;
 LEAN_EXPORT lean_object* l_UInt32_toUInt8___boxed(lean_object*);
 lean_object* lean_uint16_to_nat(uint16_t);
 lean_object* lean_nat_sub(lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_UInt8_toUInt16___boxed(lean_object*);
 LEAN_EXPORT lean_object* l_USize_sub___boxed(lean_object*, lean_object*);
+LEAN_EXPORT lean_object* l_UInt32_toFin(uint32_t);
 LEAN_EXPORT lean_object* l_UInt32_ofNat_x27___boxed(lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_UInt16_instOfNat___boxed(lean_object*);
 uint8_t lean_uint8_of_nat(lean_object*);
 LEAN_EXPORT lean_object* l_instSubUSize;
+LEAN_EXPORT lean_object* l_UInt16_toFin___boxed(lean_object*);
 size_t lean_usize_sub(size_t, size_t);
 LEAN_EXPORT lean_object* l_UInt8_instOfNat___boxed(lean_object*);
 lean_object* lean_uint8_to_nat(uint8_t);
@@ -101,21 +125,44 @@ size_t lean_usize_add(size_t, size_t);
 LEAN_EXPORT lean_object* l_UInt16_toUInt32___boxed(lean_object*);
 LEAN_EXPORT lean_object* l_UInt32_toUInt64___boxed(lean_object*);
 LEAN_EXPORT lean_object* l_instAddUSize;
+LEAN_EXPORT lean_object* l_UInt8_toFin___boxed(lean_object*);
 LEAN_EXPORT uint32_t l_UInt32_instOfNat(lean_object*);
-LEAN_EXPORT uint8_t l_instDecidableLeUSize(size_t, size_t);
 LEAN_EXPORT lean_object* l_USize_add___boxed(lean_object*, lean_object*);
 LEAN_EXPORT uint16_t l_UInt16_instOfNat(lean_object*);
 LEAN_EXPORT lean_object* l_USize_ofNat___boxed(lean_object*);
+static lean_object* l_USize_ofNatTruncate___closed__0;
 uint8_t lean_usize_dec_lt(size_t, size_t);
+static lean_object* l_instSubUSize___closed__0;
 LEAN_EXPORT lean_object* l_UInt32_val___boxed(lean_object*);
 lean_object* lean_uint64_to_nat(uint64_t);
+uint8_t lean_uint8_of_nat(lean_object*);
 uint32_t lean_uint16_to_uint32(uint16_t);
 LEAN_EXPORT lean_object* l_UInt32_val(uint32_t);
 LEAN_EXPORT size_t l_USize_instOfNat(lean_object*);
+LEAN_EXPORT lean_object* l_UInt64_toFin___boxed(lean_object*);
 LEAN_EXPORT lean_object* l_UInt16_ofNat___boxed(lean_object*);
 LEAN_EXPORT lean_object* l_Nat_toUInt8___boxed(lean_object*);
 LEAN_EXPORT lean_object* l_Nat_toUInt64___boxed(lean_object*);
+LEAN_EXPORT lean_object* l_USize_toFin(size_t);
+LEAN_EXPORT lean_object* l_UInt64_toFin(uint64_t);
 LEAN_EXPORT lean_object* l_UInt8_val(uint8_t);
+LEAN_EXPORT lean_object* l_UInt8_toFin(uint8_t x_1) {
+_start:
+{
+lean_object* x_2; 
+x_2 = lean_uint8_to_nat(x_1);
+return x_2;
+}
+}
+LEAN_EXPORT lean_object* l_UInt8_toFin___boxed(lean_object* x_1) {
+_start:
+{
+uint8_t x_2; lean_object* x_3; 
+x_2 = lean_unbox(x_1);
+x_3 = l_UInt8_toFin(x_2);
+return x_3;
+}
+}
 LEAN_EXPORT lean_object* l_UInt8_val(uint8_t x_1) {
 _start:
 {
@@ -129,7 +176,6 @@ _start:
 {
 uint8_t x_2; lean_object* x_3; 
 x_2 = lean_unbox(x_1);
-lean_dec(x_1);
 x_3 = l_UInt8_val(x_2);
 return x_3;
 }
@@ -144,6 +190,45 @@ x_3 = lean_box(x_2);
 return x_3;
 }
 }
+static uint8_t _init_l_UInt8_ofNatTruncate___closed__0() {
+_start:
+{
+lean_object* x_1; uint8_t x_2; 
+x_1 = lean_unsigned_to_nat(255u);
+x_2 = lean_uint8_of_nat(x_1);
+return x_2;
+}
+}
+LEAN_EXPORT uint8_t l_UInt8_ofNatTruncate(lean_object* x_1) {
+_start:
+{
+lean_object* x_2; uint8_t x_3; 
+x_2 = lean_unsigned_to_nat(256u);
+x_3 = lean_nat_dec_lt(x_1, x_2);
+if (x_3 == 0)
+{
+uint8_t x_4; 
+x_4 = l_UInt8_ofNatTruncate___closed__0;
+return x_4;
+}
+else
+{
+uint8_t x_5; 
+x_5 = lean_uint8_of_nat(x_1);
+return x_5;
+}
+}
+}
+LEAN_EXPORT lean_object* l_UInt8_ofNatTruncate___boxed(lean_object* x_1) {
+_start:
+{
+uint8_t x_2; lean_object* x_3; 
+x_2 = l_UInt8_ofNatTruncate(x_1);
+lean_dec(x_1);
+x_3 = lean_box(x_2);
+return x_3;
+}
+}
 LEAN_EXPORT uint8_t l_Nat_toUInt8(lean_object* x_1) {
 _start:
 {
@@ -167,7 +252,6 @@ _start:
 {
 uint8_t x_2; lean_object* x_3; 
 x_2 = lean_unbox(x_1);
-lean_dec(x_1);
 x_3 = lean_uint8_to_nat(x_2);
 return x_3;
 }
@@ -190,6 +274,23 @@ x_3 = lean_box(x_2);
 return x_3;
 }
 }
+LEAN_EXPORT lean_object* l_UInt16_toFin(uint16_t x_1) {
+_start:
+{
+lean_object* x_2; 
+x_2 = lean_uint16_to_nat(x_1);
+return x_2;
+}
+}
+LEAN_EXPORT lean_object* l_UInt16_toFin___boxed(lean_object* x_1) {
+_start:
+{
+uint16_t x_2; lean_object* x_3; 
+x_2 = lean_unbox(x_1);
+x_3 = l_UInt16_toFin(x_2);
+return x_3;
+}
+}
 LEAN_EXPORT lean_object* l_UInt16_val(uint16_t x_1) {
 _start:
 {
@@ -203,7 +304,6 @@ _start:
 {
 uint16_t x_2; lean_object* x_3; 
 x_2 = lean_unbox(x_1);
-lean_dec(x_1);
 x_3 = l_UInt16_val(x_2);
 return x_3;
 }
@@ -218,6 +318,45 @@ x_3 = lean_box(x_2);
 return x_3;
 }
 }
+static uint16_t _init_l_UInt16_ofNatTruncate___closed__0() {
+_start:
+{
+lean_object* x_1; uint16_t x_2; 
+x_1 = lean_unsigned_to_nat(65535u);
+x_2 = lean_uint16_of_nat(x_1);
+return x_2;
+}
+}
+LEAN_EXPORT uint16_t l_UInt16_ofNatTruncate(lean_object* x_1) {
+_start:
+{
+lean_object* x_2; uint8_t x_3; 
+x_2 = lean_unsigned_to_nat(65536u);
+x_3 = lean_nat_dec_lt(x_1, x_2);
+if (x_3 == 0)
+{
+uint16_t x_4; 
+x_4 = l_UInt16_ofNatTruncate___closed__0;
+return x_4;
+}
+else
+{
+uint16_t x_5; 
+x_5 = lean_uint16_of_nat(x_1);
+return x_5;
+}
+}
+}
+LEAN_EXPORT lean_object* l_UInt16_ofNatTruncate___boxed(lean_object* x_1) {
+_start:
+{
+uint16_t x_2; lean_object* x_3; 
+x_2 = l_UInt16_ofNatTruncate(x_1);
+lean_dec(x_1);
+x_3 = lean_box(x_2);
+return x_3;
+}
+}
 LEAN_EXPORT uint16_t l_Nat_toUInt16(lean_object* x_1) {
 _start:
 {
@@ -241,7 +380,6 @@ _start:
 {
 uint16_t x_2; lean_object* x_3; 
 x_2 = lean_unbox(x_1);
-lean_dec(x_1);
 x_3 = lean_uint16_to_nat(x_2);
 return x_3;
 }
@@ -251,7 +389,6 @@ _start:
 {
 uint16_t x_2; uint8_t x_3; lean_object* x_4; 
 x_2 = lean_unbox(x_1);
-lean_dec(x_1);
 x_3 = lean_uint16_to_uint8(x_2);
 x_4 = lean_box(x_3);
 return x_4;
@@ -262,7 +399,6 @@ _start:
 {
 uint8_t x_2; uint16_t x_3; lean_object* x_4; 
 x_2 = lean_unbox(x_1);
-lean_dec(x_1);
 x_3 = lean_uint8_to_uint16(x_2);
 x_4 = lean_box(x_3);
 return x_4;
@@ -286,6 +422,24 @@ x_3 = lean_box(x_2);
 return x_3;
 }
 }
+LEAN_EXPORT lean_object* l_UInt32_toFin(uint32_t x_1) {
+_start:
+{
+lean_object* x_2; 
+x_2 = lean_uint32_to_nat(x_1);
+return x_2;
+}
+}
+LEAN_EXPORT lean_object* l_UInt32_toFin___boxed(lean_object* x_1) {
+_start:
+{
+uint32_t x_2; lean_object* x_3; 
+x_2 = lean_unbox_uint32(x_1);
+lean_dec(x_1);
+x_3 = l_UInt32_toFin(x_2);
+return x_3;
+}
+}
 LEAN_EXPORT lean_object* l_UInt32_val(uint32_t x_1) {
 _start:
 {
@@ -314,30 +468,47 @@ x_3 = lean_box_uint32(x_2);
 return x_3;
 }
 }
+LEAN_EXPORT uint32_t l_UInt32_ofNat_x27___redArg(lean_object* x_1) {
+_start:
+{
+uint32_t x_2; 
+x_2 = lean_uint32_of_nat(x_1);
+return x_2;
+}
+}
+LEAN_EXPORT uint32_t l_UInt32_ofNat_x27(lean_object* x_1, lean_object* x_2) {
+_start:
+{
+uint32_t x_3; 
+x_3 = lean_uint32_of_nat(x_1);
+return x_3;
+}
+}
+LEAN_EXPORT lean_object* l_UInt32_ofNat_x27___redArg___boxed(lean_object* x_1) {
+_start:
+{
+uint32_t x_2; lean_object* x_3; 
+x_2 = l_UInt32_ofNat_x27___redArg(x_1);
+lean_dec(x_1);
+x_3 = lean_box_uint32(x_2);
+return x_3;
+}
+}
 LEAN_EXPORT lean_object* l_UInt32_ofNat_x27___boxed(lean_object* x_1, lean_object* x_2) {
 _start:
 {
 uint32_t x_3; lean_object* x_4; 
-x_3 = lean_uint32_of_nat(x_1);
+x_3 = l_UInt32_ofNat_x27(x_1, x_2);
+lean_dec(x_1);
 x_4 = lean_box_uint32(x_3);
 return x_4;
 }
 }
-static lean_object* _init_l_UInt32_ofNatTruncate___closed__1() {
-_start:
-{
-lean_object* x_1; lean_object* x_2; lean_object* x_3; 
-x_1 = lean_cstr_to_nat("4294967296");
-x_2 = lean_unsigned_to_nat(1u);
-x_3 = lean_nat_sub(x_1, x_2);
-return x_3;
-}
-}
-static uint32_t _init_l_UInt32_ofNatTruncate___closed__2() {
+static uint32_t _init_l_UInt32_ofNatTruncate___closed__0() {
 _start:
 {
 lean_object* x_1; uint32_t x_2; 
-x_1 = l_UInt32_ofNatTruncate___closed__1;
+x_1 = lean_unsigned_to_nat(4294967295u);
 x_2 = lean_uint32_of_nat(x_1);
 return x_2;
 }
@@ -351,8 +522,7 @@ x_3 = lean_nat_dec_lt(x_1, x_2);
 if (x_3 == 0)
 {
 uint32_t x_4; 
-lean_dec(x_1);
-x_4 = l_UInt32_ofNatTruncate___closed__2;
+x_4 = l_UInt32_ofNatTruncate___closed__0;
 return x_4;
 }
 else
@@ -368,6 +538,7 @@ _start:
 {
 uint32_t x_2; lean_object* x_3; 
 x_2 = l_UInt32_ofNatTruncate(x_1);
+lean_dec(x_1);
 x_3 = lean_box_uint32(x_2);
 return x_3;
 }
@@ -417,7 +588,6 @@ _start:
 {
 uint8_t x_2; uint32_t x_3; lean_object* x_4; 
 x_2 = lean_unbox(x_1);
-lean_dec(x_1);
 x_3 = lean_uint8_to_uint32(x_2);
 x_4 = lean_box_uint32(x_3);
 return x_4;
@@ -428,7 +598,6 @@ _start:
 {
 uint16_t x_2; uint32_t x_3; lean_object* x_4; 
 x_2 = lean_unbox(x_1);
-lean_dec(x_1);
 x_3 = lean_uint16_to_uint32(x_2);
 x_4 = lean_box_uint32(x_3);
 return x_4;
@@ -452,6 +621,24 @@ x_3 = lean_box_uint32(x_2);
 return x_3;
 }
 }
+LEAN_EXPORT lean_object* l_UInt64_toFin(uint64_t x_1) {
+_start:
+{
+lean_object* x_2; 
+x_2 = lean_uint64_to_nat(x_1);
+return x_2;
+}
+}
+LEAN_EXPORT lean_object* l_UInt64_toFin___boxed(lean_object* x_1) {
+_start:
+{
+uint64_t x_2; lean_object* x_3; 
+x_2 = lean_unbox_uint64(x_1);
+lean_dec(x_1);
+x_3 = l_UInt64_toFin(x_2);
+return x_3;
+}
+}
 LEAN_EXPORT lean_object* l_UInt64_val(uint64_t x_1) {
 _start:
 {
@@ -480,6 +667,61 @@ x_3 = lean_box_uint64(x_2);
 return x_3;
 }
 }
+static lean_object* _init_l_UInt64_ofNatTruncate___closed__0() {
+_start:
+{
+lean_object* x_1; 
+x_1 = lean_cstr_to_nat("18446744073709551616");
+return x_1;
+}
+}
+static lean_object* _init_l_UInt64_ofNatTruncate___closed__1() {
+_start:
+{
+lean_object* x_1; 
+x_1 = lean_cstr_to_nat("18446744073709551615");
+return x_1;
+}
+}
+static uint64_t _init_l_UInt64_ofNatTruncate___closed__2() {
+_start:
+{
+lean_object* x_1; uint64_t x_2; 
+x_1 = l_UInt64_ofNatTruncate___closed__1;
+x_2 = lean_uint64_of_nat(x_1);
+return x_2;
+}
+}
+LEAN_EXPORT uint64_t l_UInt64_ofNatTruncate(lean_object* x_1) {
+_start:
+{
+lean_object* x_2; uint8_t x_3; 
+x_2 = l_UInt64_ofNatTruncate___closed__0;
+x_3 = lean_nat_dec_lt(x_1, x_2);
+if (x_3 == 0)
+{
+uint64_t x_4; 
+x_4 = l_UInt64_ofNatTruncate___closed__2;
+return x_4;
+}
+else
+{
+uint64_t x_5; 
+x_5 = lean_uint64_of_nat(x_1);
+return x_5;
+}
+}
+}
+LEAN_EXPORT lean_object* l_UInt64_ofNatTruncate___boxed(lean_object* x_1) {
+_start:
+{
+uint64_t x_2; lean_object* x_3; 
+x_2 = l_UInt64_ofNatTruncate(x_1);
+lean_dec(x_1);
+x_3 = lean_box_uint64(x_2);
+return x_3;
+}
+}
 LEAN_EXPORT uint64_t l_Nat_toUInt64(lean_object* x_1) {
 _start:
 {
@@ -546,7 +788,6 @@ _start:
 {
 uint8_t x_2; uint64_t x_3; lean_object* x_4; 
 x_2 = lean_unbox(x_1);
-lean_dec(x_1);
 x_3 = lean_uint8_to_uint64(x_2);
 x_4 = lean_box_uint64(x_3);
 return x_4;
@@ -557,7 +798,6 @@ _start:
 {
 uint16_t x_2; uint64_t x_3; lean_object* x_4; 
 x_2 = lean_unbox(x_1);
-lean_dec(x_1);
 x_3 = lean_uint16_to_uint64(x_2);
 x_4 = lean_box_uint64(x_3);
 return x_4;
@@ -592,6 +832,24 @@ x_3 = lean_box_uint64(x_2);
 return x_3;
 }
 }
+LEAN_EXPORT lean_object* l_USize_toFin(size_t x_1) {
+_start:
+{
+lean_object* x_2; 
+x_2 = lean_usize_to_nat(x_1);
+return x_2;
+}
+}
+LEAN_EXPORT lean_object* l_USize_toFin___boxed(lean_object* x_1) {
+_start:
+{
+size_t x_2; lean_object* x_3; 
+x_2 = lean_unbox_usize(x_1);
+lean_dec(x_1);
+x_3 = l_USize_toFin(x_2);
+return x_3;
+}
+}
 LEAN_EXPORT lean_object* l_USize_val(size_t x_1) {
 _start:
 {
@@ -620,6 +878,65 @@ x_3 = lean_box_usize(x_2);
 return x_3;
 }
 }
+static lean_object* _init_l_USize_ofNatTruncate___closed__0() {
+_start:
+{
+lean_object* x_1; lean_object* x_2; lean_object* x_3; 
+x_1 = l_System_Platform_numBits;
+x_2 = lean_unsigned_to_nat(2u);
+x_3 = lean_nat_pow(x_2, x_1);
+return x_3;
+}
+}
+static lean_object* _init_l_USize_ofNatTruncate___closed__1() {
+_start:
+{
+lean_object* x_1; lean_object* x_2; lean_object* x_3; 
+x_1 = lean_unsigned_to_nat(1u);
+x_2 = l_USize_ofNatTruncate___closed__0;
+x_3 = lean_nat_sub(x_2, x_1);
+return x_3;
+}
+}
+static size_t _init_l_USize_ofNatTruncate___closed__2() {
+_start:
+{
+lean_object* x_1; size_t x_2; 
+x_1 = l_USize_ofNatTruncate___closed__1;
+x_2 = lean_usize_of_nat(x_1);
+return x_2;
+}
+}
+LEAN_EXPORT size_t l_USize_ofNatTruncate(lean_object* x_1) {
+_start:
+{
+lean_object* x_2; uint8_t x_3; 
+x_2 = l_USize_ofNatTruncate___closed__0;
+x_3 = lean_nat_dec_lt(x_1, x_2);
+if (x_3 == 0)
+{
+size_t x_4; 
+x_4 = l_USize_ofNatTruncate___closed__2;
+return x_4;
+}
+else
+{
+size_t x_5; 
+x_5 = lean_usize_of_nat(x_1);
+return x_5;
+}
+}
+}
+LEAN_EXPORT lean_object* l_USize_ofNatTruncate___boxed(lean_object* x_1) {
+_start:
+{
+size_t x_2; lean_object* x_3; 
+x_2 = l_USize_ofNatTruncate(x_1);
+lean_dec(x_1);
+x_3 = lean_box_usize(x_2);
+return x_3;
+}
+}
 LEAN_EXPORT size_t l_Nat_toUSize(lean_object* x_1) {
 _start:
 {
@@ -692,7 +1009,7 @@ x_3 = lean_box_usize(x_2);
 return x_3;
 }
 }
-static lean_object* _init_l_instAddUSize___closed__1() {
+static lean_object* _init_l_instAddUSize___closed__0() {
 _start:
 {
 lean_object* x_1; 
@@ -704,11 +1021,11 @@ static lean_object* _init_l_instAddUSize() {
 _start:
 {
 lean_object* x_1; 
-x_1 = l_instAddUSize___closed__1;
+x_1 = l_instAddUSize___closed__0;
 return x_1;
 }
 }
-static lean_object* _init_l_instSubUSize___closed__1() {
+static lean_object* _init_l_instSubUSize___closed__0() {
 _start:
 {
 lean_object* x_1; 
@@ -720,7 +1037,7 @@ static lean_object* _init_l_instSubUSize() {
 _start:
 {
 lean_object* x_1; 
-x_1 = l_instSubUSize___closed__1;
+x_1 = l_instSubUSize___closed__0;
 return x_1;
 }
 }
@@ -766,48 +1083,6 @@ x_6 = lean_box(x_5);
 return x_6;
 }
 }
-LEAN_EXPORT uint8_t l_instDecidableLtUSize(size_t x_1, size_t x_2) {
-_start:
-{
-uint8_t x_3; 
-x_3 = lean_usize_dec_lt(x_1, x_2);
-return x_3;
-}
-}
-LEAN_EXPORT lean_object* l_instDecidableLtUSize___boxed(lean_object* x_1, lean_object* x_2) {
-_start:
-{
-size_t x_3; size_t x_4; uint8_t x_5; lean_object* x_6; 
-x_3 = lean_unbox_usize(x_1);
-lean_dec(x_1);
-x_4 = lean_unbox_usize(x_2);
-lean_dec(x_2);
-x_5 = l_instDecidableLtUSize(x_3, x_4);
-x_6 = lean_box(x_5);
-return x_6;
-}
-}
-LEAN_EXPORT uint8_t l_instDecidableLeUSize(size_t x_1, size_t x_2) {
-_start:
-{
-uint8_t x_3; 
-x_3 = lean_usize_dec_le(x_1, x_2);
-return x_3;
-}
-}
-LEAN_EXPORT lean_object* l_instDecidableLeUSize___boxed(lean_object* x_1, lean_object* x_2) {
-_start:
-{
-size_t x_3; size_t x_4; uint8_t x_5; lean_object* x_6; 
-x_3 = lean_unbox_usize(x_1);
-lean_dec(x_1);
-x_4 = lean_unbox_usize(x_2);
-lean_dec(x_2);
-x_5 = l_instDecidableLeUSize(x_3, x_4);
-x_6 = lean_box(x_5);
-return x_6;
-}
-}
 lean_object* initialize_Init_Data_Fin_Basic(uint8_t builtin, lean_object*);
 lean_object* initialize_Init_Data_BitVec_BasicAux(uint8_t builtin, lean_object*);
 static bool _G_initialized = false;
@@ -821,15 +1096,25 @@ lean_dec_ref(res);
 res = initialize_Init_Data_BitVec_BasicAux(builtin, lean_io_mk_world());
 if (lean_io_result_is_error(res)) return res;
 lean_dec_ref(res);
-l_UInt32_ofNatTruncate___closed__1 = _init_l_UInt32_ofNatTruncate___closed__1();
-lean_mark_persistent(l_UInt32_ofNatTruncate___closed__1);
-l_UInt32_ofNatTruncate___closed__2 = _init_l_UInt32_ofNatTruncate___closed__2();
-l_instAddUSize___closed__1 = _init_l_instAddUSize___closed__1();
-lean_mark_persistent(l_instAddUSize___closed__1);
+l_UInt8_ofNatTruncate___closed__0 = _init_l_UInt8_ofNatTruncate___closed__0();
+l_UInt16_ofNatTruncate___closed__0 = _init_l_UInt16_ofNatTruncate___closed__0();
+l_UInt32_ofNatTruncate___closed__0 = _init_l_UInt32_ofNatTruncate___closed__0();
+l_UInt64_ofNatTruncate___closed__0 = _init_l_UInt64_ofNatTruncate___closed__0();
+lean_mark_persistent(l_UInt64_ofNatTruncate___closed__0);
+l_UInt64_ofNatTruncate___closed__1 = _init_l_UInt64_ofNatTruncate___closed__1();
+lean_mark_persistent(l_UInt64_ofNatTruncate___closed__1);
+l_UInt64_ofNatTruncate___closed__2 = _init_l_UInt64_ofNatTruncate___closed__2();
+l_USize_ofNatTruncate___closed__0 = _init_l_USize_ofNatTruncate___closed__0();
+lean_mark_persistent(l_USize_ofNatTruncate___closed__0);
+l_USize_ofNatTruncate___closed__1 = _init_l_USize_ofNatTruncate___closed__1();
+lean_mark_persistent(l_USize_ofNatTruncate___closed__1);
+l_USize_ofNatTruncate___closed__2 = _init_l_USize_ofNatTruncate___closed__2();
+l_instAddUSize___closed__0 = _init_l_instAddUSize___closed__0();
+lean_mark_persistent(l_instAddUSize___closed__0);
 l_instAddUSize = _init_l_instAddUSize();
 lean_mark_persistent(l_instAddUSize);
-l_instSubUSize___closed__1 = _init_l_instSubUSize___closed__1();
-lean_mark_persistent(l_instSubUSize___closed__1);
+l_instSubUSize___closed__0 = _init_l_instSubUSize___closed__0();
+lean_mark_persistent(l_instSubUSize___closed__0);
 l_instSubUSize = _init_l_instSubUSize();
 lean_mark_persistent(l_instSubUSize);
 l_instLTUSize = _init_l_instLTUSize();
