@@ -1,6 +1,6 @@
 // Lean compiler output
 // Module: Init.Grind.Norm
-// Imports: Init.SimpLemmas Init.Classical Init.ByCases
+// Imports: Init.SimpLemmas Init.PropLemmas Init.Classical Init.ByCases Init.Data.Int.Linear Init.Data.Int.Pow Init.Grind.Ring.Field
 #include <lean/lean.h>
 #if defined(__clang__)
 #pragma clang diagnostic ignored "-Wunused-parameter"
@@ -14,8 +14,12 @@
 extern "C" {
 #endif
 lean_object* initialize_Init_SimpLemmas(uint8_t builtin, lean_object*);
+lean_object* initialize_Init_PropLemmas(uint8_t builtin, lean_object*);
 lean_object* initialize_Init_Classical(uint8_t builtin, lean_object*);
 lean_object* initialize_Init_ByCases(uint8_t builtin, lean_object*);
+lean_object* initialize_Init_Data_Int_Linear(uint8_t builtin, lean_object*);
+lean_object* initialize_Init_Data_Int_Pow(uint8_t builtin, lean_object*);
+lean_object* initialize_Init_Grind_Ring_Field(uint8_t builtin, lean_object*);
 static bool _G_initialized = false;
 LEAN_EXPORT lean_object* initialize_Init_Grind_Norm(uint8_t builtin, lean_object* w) {
 lean_object * res;
@@ -24,12 +28,24 @@ _G_initialized = true;
 res = initialize_Init_SimpLemmas(builtin, lean_io_mk_world());
 if (lean_io_result_is_error(res)) return res;
 lean_dec_ref(res);
+res = initialize_Init_PropLemmas(builtin, lean_io_mk_world());
+if (lean_io_result_is_error(res)) return res;
+lean_dec_ref(res);
 res = initialize_Init_Classical(builtin, lean_io_mk_world());
 if (lean_io_result_is_error(res)) return res;
 lean_dec_ref(res);
 res = initialize_Init_ByCases(builtin, lean_io_mk_world());
 if (lean_io_result_is_error(res)) return res;
 lean_dec_ref(res);
+res = initialize_Init_Data_Int_Linear(builtin, lean_io_mk_world());
+if (lean_io_result_is_error(res)) return res;
+lean_dec_ref(res);
+res = initialize_Init_Data_Int_Pow(builtin, lean_io_mk_world());
+if (lean_io_result_is_error(res)) return res;
+lean_dec_ref(res);
+res = initialize_Init_Grind_Ring_Field(builtin, lean_io_mk_world());
+if (lean_io_result_is_error(res)) return res;
+lean_dec_ref(res);
 return lean_io_result_mk_ok(lean_box(0));
 }
 #ifdef __cplusplus
