@@ -1,6 +1,6 @@
 // Lean compiler output
 // Module: Init.SizeOfLemmas
-// Imports: Init.Meta Init.SizeOf Init.Data.Nat.Linear
+// Imports: Init.Data.Char.Basic Init.Meta Init.SizeOf Init.Data.Nat.Linear
 #include <lean/lean.h>
 #if defined(__clang__)
 #pragma clang diagnostic ignored "-Wunused-parameter"
@@ -13,6 +13,7 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
+lean_object* initialize_Init_Data_Char_Basic(uint8_t builtin, lean_object*);
 lean_object* initialize_Init_Meta(uint8_t builtin, lean_object*);
 lean_object* initialize_Init_SizeOf(uint8_t builtin, lean_object*);
 lean_object* initialize_Init_Data_Nat_Linear(uint8_t builtin, lean_object*);
@@ -21,6 +22,9 @@ LEAN_EXPORT lean_object* initialize_Init_SizeOfLemmas(uint8_t builtin, lean_obje
 lean_object * res;
 if (_G_initialized) return lean_io_result_mk_ok(lean_box(0));
 _G_initialized = true;
+res = initialize_Init_Data_Char_Basic(builtin, lean_io_mk_world());
+if (lean_io_result_is_error(res)) return res;
+lean_dec_ref(res);
 res = initialize_Init_Meta(builtin, lean_io_mk_world());
 if (lean_io_result_is_error(res)) return res;
 lean_dec_ref(res);
