@@ -41,14 +41,12 @@ lean_object* lean_llvm_position_builder_before(size_t, size_t, size_t, lean_obje
 LEAN_EXPORT lean_object* l_LLVM_getNextFunction___boxed(lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_addGlobal___boxed(lean_object*, lean_object*, lean_object*, lean_object*, lean_object*);
 lean_object* lean_llvm_print_module_to_string(size_t, size_t, lean_object*);
-static lean_object* l_LLVM_AttributeIndex_AttributeFunctionIndex___closed__1;
-uint64_t lean_uint64_of_nat(lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_constInt1(size_t, uint64_t, uint8_t, lean_object*);
 lean_object* lean_llvm_build_sext_or_trunc(size_t, size_t, size_t, size_t, lean_object*, lean_object*);
 lean_object* lean_llvm_build_switch(size_t, size_t, size_t, size_t, uint64_t, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_buildUnreachable___boxed(lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_createTargetMachine___boxed(lean_object*, lean_object*, lean_object*, lean_object*, lean_object*, lean_object*);
-LEAN_EXPORT lean_object* l_LLVM_Value_isNull___boxed(lean_object*);
+LEAN_EXPORT lean_object* l_LLVM_Value_isNull___boxed(lean_object*, lean_object*);
 lean_object* lean_llvm_const_int(size_t, size_t, uint64_t, uint8_t, lean_object*);
 lean_object* lean_llvm_get_value_name2(size_t, size_t, lean_object*);
 lean_object* lean_llvm_set_tail_call(size_t, size_t, uint8_t, lean_object*);
@@ -62,7 +60,6 @@ LEAN_EXPORT lean_object* l_LLVM_buildPtrToInt___boxed(lean_object*, lean_object*
 LEAN_EXPORT lean_object* l_LLVM_constInt64(size_t, uint64_t, uint8_t, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_i1Type___boxed(lean_object*, lean_object*);
 lean_object* lean_llvm_write_bitcode_to_file(size_t, size_t, lean_object*, lean_object*);
-LEAN_EXPORT lean_object* l_LLVM_runPassManager___boxed(lean_object*, lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT uint64_t l_LLVM_DLLStorageClass_default;
 LEAN_EXPORT uint64_t l_LLVM_Linkage_internal;
 lean_object* lean_llvm_build_zext(size_t, size_t, size_t, size_t, lean_object*, lean_object*);
@@ -79,7 +76,6 @@ LEAN_EXPORT uint64_t l_LLVM_Linkage_appending;
 lean_object* lean_llvm_get_target_from_triple(size_t, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_addAttributeAtIndex___boxed(lean_object*, lean_object*, lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_functionType___boxed(lean_object*, lean_object*, lean_object*, lean_object*, lean_object*);
-LEAN_EXPORT lean_object* l_LLVM_PassManagerBuilder_setOptLevel___boxed(lean_object*, lean_object*, lean_object*, lean_object*, lean_object*);
 lean_object* lean_llvm_const_array(size_t, size_t, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_getEntryBasicBlock___boxed(lean_object*, lean_object*, lean_object*);
 lean_object* lean_llvm_get_named_global(size_t, size_t, lean_object*, lean_object*);
@@ -91,7 +87,6 @@ lean_object* lean_llvm_build_unreachable(size_t, size_t, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_verifyModule___boxed(lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_i16Type___boxed(lean_object*, lean_object*);
 LEAN_EXPORT uint64_t l_LLVM_Linkage_common;
-LEAN_EXPORT lean_object* l_LLVM_PassManagerBuilder_populateModulePassManager___boxed(lean_object*, lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_constInt8(size_t, uint64_t, uint8_t, lean_object*);
 lean_object* llvm_get_param(size_t, size_t, uint64_t, lean_object*);
 lean_object* lean_llvm_build_global_string(size_t, size_t, lean_object*, lean_object*, lean_object*);
@@ -99,18 +94,15 @@ LEAN_EXPORT lean_object* l_LLVM_createBuilderInContext___boxed(lean_object*, lea
 lean_object* lean_llvm_array_type(size_t, size_t, uint64_t, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_buildCondBr___boxed(lean_object*, lean_object*, lean_object*, lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_buildStore___boxed(lean_object*, lean_object*, lean_object*, lean_object*, lean_object*);
-lean_object* lean_llvm_dispose_pass_manager_builder(size_t, size_t, lean_object*);
 lean_object* lean_llvm_add_attribute_at_index(size_t, size_t, uint64_t, size_t, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_constInt32(size_t, uint64_t, uint8_t, lean_object*);
 lean_object* lean_llvm_initialize_target_info(lean_object*);
-LEAN_EXPORT uint8_t l_LLVM_Value_isNull___rarg(size_t);
 LEAN_EXPORT lean_object* l_LLVM_getInsertBlock___boxed(lean_object*, lean_object*, lean_object*, lean_object*);
 lean_object* lean_llvm_get_undef(size_t, size_t, lean_object*);
 lean_object* lean_llvm_create_context(lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_buildInBoundsGEP2___boxed(lean_object*, lean_object*, lean_object*, lean_object*, lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_voidType___boxed(lean_object*, lean_object*);
 LEAN_EXPORT uint64_t l_LLVM_CodegenFileType_ObjectFile;
-lean_object* lean_llvm_create_pass_manager(size_t, lean_object*);
 lean_object* lean_llvm_parse_bitcode(size_t, size_t, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_getFirstFunction___boxed(lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_clearInsertionPosition___boxed(lean_object*, lean_object*, lean_object*, lean_object*);
@@ -121,17 +113,18 @@ lean_object* lean_llvm_set_linkage(size_t, size_t, uint64_t, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_printModuletoString___boxed(lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT uint64_t l_LLVM_Visibility_default;
 lean_object* lean_llvm_build_ret(size_t, size_t, size_t, lean_object*);
-lean_object* lean_llvm_pass_manager_builder_populate_module_pass_manager(size_t, size_t, size_t, lean_object*);
 lean_object* lean_llvm_target_machine_emit_to_file(size_t, size_t, size_t, lean_object*, uint64_t, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_parseBitcode___boxed(lean_object*, lean_object*, lean_object*);
 lean_object* lean_llvm_build_inbounds_gep2(size_t, size_t, size_t, size_t, lean_object*, lean_object*, lean_object*);
-LEAN_EXPORT lean_object* l_LLVM_Value_isNull(size_t);
+LEAN_EXPORT uint8_t l_LLVM_Value_isNull(size_t, size_t);
 LEAN_EXPORT lean_object* l_LLVM_buildGEP2___boxed(lean_object*, lean_object*, lean_object*, lean_object*, lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_i32Type___boxed(lean_object*, lean_object*);
 lean_object* lean_llvm_add_global(size_t, size_t, lean_object*, size_t, lean_object*);
 lean_object* lean_llvm_verify_module(size_t, size_t, lean_object*);
+uint64_t lean_uint64_add(uint64_t, uint64_t);
 LEAN_EXPORT lean_object* l_LLVM_isDeclaration___boxed(lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_getNextGlobal___boxed(lean_object*, lean_object*, lean_object*);
+static uint64_t l_LLVM_IntPredicate_UGT___closed__0;
 lean_object* lean_llvm_build_gep2(size_t, size_t, size_t, size_t, lean_object*, lean_object*, lean_object*);
 lean_object* llvm_count_params(size_t, size_t, lean_object*);
 LEAN_EXPORT uint64_t l_LLVM_Linkage_linkOnceAny;
@@ -155,9 +148,7 @@ LEAN_EXPORT lean_object* l_LLVM_setVisibility___boxed(lean_object*, lean_object*
 LEAN_EXPORT lean_object* l_LLVM_i8PtrType(size_t, lean_object*);
 lean_object* lean_llvm_get_entry_basic_block(size_t, size_t, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_getUndef___boxed(lean_object*, lean_object*, lean_object*);
-LEAN_EXPORT lean_object* l_LLVM_disposePassManager___boxed(lean_object*, lean_object*, lean_object*);
 lean_object* lean_llvm_create_memory_buffer_with_contents_of_file(size_t, lean_object*, lean_object*);
-lean_object* lean_llvm_run_pass_manager(size_t, size_t, size_t, lean_object*);
 lean_object* lean_llvm_float_type_in_context(size_t, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_constIntSizeT(size_t, uint64_t, uint8_t, lean_object*);
 lean_object* lean_llvm_count_basic_blocks(size_t, size_t, lean_object*);
@@ -186,20 +177,18 @@ LEAN_EXPORT uint64_t l_LLVM_Linkage_external;
 LEAN_EXPORT lean_object* l_LLVM_i32Type(size_t, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_constIntUnsigned(size_t, uint64_t, uint8_t, lean_object*);
 lean_object* lean_llvm_clear_insertion_position(lean_object*, size_t, lean_object*);
-LEAN_EXPORT lean_object* l_LLVM_Value_isNull___rarg___boxed(lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_buildMul___boxed(lean_object*, lean_object*, lean_object*, lean_object*, lean_object*, lean_object*);
 lean_object* lean_llvm_double_type_in_context(size_t, lean_object*);
 lean_object* lean_llvm_get_next_function(size_t, size_t, lean_object*);
-static uint64_t l_LLVM_AttributeIndex_AttributeFunctionIndex___closed__2;
 LEAN_EXPORT lean_object* l_LLVM_constInt___boxed(lean_object*, lean_object*, lean_object*, lean_object*, lean_object*);
 lean_object* lean_llvm_build_store(size_t, size_t, size_t, size_t, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_appendBasicBlockInContext___boxed(lean_object*, lean_object*, lean_object*, lean_object*);
-LEAN_EXPORT lean_object* l_LLVM_disposePassManagerBuilder___boxed(lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT uint64_t l_LLVM_Linkage_linkerPrivate;
 LEAN_EXPORT lean_object* l_LLVM_constPointerNull___boxed(lean_object*, lean_object*, lean_object*);
 lean_object* lean_llvm_dispose_module(size_t, size_t, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_constIntSizeT___boxed(lean_object*, lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_positionBuilderBefore___boxed(lean_object*, lean_object*, lean_object*, lean_object*);
+LEAN_EXPORT lean_object* l_LLVM_Value_isNull___redArg___boxed(lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_buildSub___boxed(lean_object*, lean_object*, lean_object*, lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_getTargetFromTriple___boxed(lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_getNamedFunction___boxed(lean_object*, lean_object*, lean_object*, lean_object*);
@@ -207,17 +196,17 @@ LEAN_EXPORT lean_object* l_LLVM_constString___boxed(lean_object*, lean_object*,
 lean_object* lean_llvm_pointer_type(size_t, size_t, lean_object*);
 LEAN_EXPORT uint64_t l_LLVM_CodegenFileType_AssemblyFile;
 lean_object* lean_llvm_create_string_attribute(size_t, lean_object*, lean_object*, lean_object*);
+LEAN_EXPORT uint8_t l_LLVM_Value_isNull___redArg(size_t);
 lean_object* lean_llvm_build_icmp(size_t, size_t, uint64_t, size_t, size_t, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_getNamedGlobal___boxed(lean_object*, lean_object*, lean_object*, lean_object*);
 lean_object* lean_llvm_build_alloca(size_t, size_t, size_t, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_writeBitcodeToFile___boxed(lean_object*, lean_object*, lean_object*, lean_object*);
 lean_object* lean_llvm_get_first_global(size_t, size_t, lean_object*);
-LEAN_EXPORT lean_object* l_LLVM_createPassManagerBuilder___boxed(lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_i8PtrType___boxed(lean_object*, lean_object*);
-lean_object* lean_llvm_create_pass_manager_builder(size_t, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_opaquePointerTypeInContext___boxed(lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_doubleTypeInContext___boxed(lean_object*, lean_object*);
 LEAN_EXPORT uint64_t l_LLVM_Linkage_externalWeak;
+static uint64_t l_LLVM_IntPredicate_NE___closed__0;
 LEAN_EXPORT lean_object* l_LLVM_buildSwitch___boxed(lean_object*, lean_object*, lean_object*, lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_typeOf___boxed(lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_getParam___boxed(lean_object*, lean_object*, lean_object*, lean_object*);
@@ -230,13 +219,10 @@ LEAN_EXPORT lean_object* l_LLVM_buildNot___boxed(lean_object*, lean_object*, lea
 LEAN_EXPORT lean_object* l_LLVM_targetMachineEmitToFile___boxed(lean_object*, lean_object*, lean_object*, lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_constInt8___boxed(lean_object*, lean_object*, lean_object*, lean_object*);
 lean_object* lean_llvm_void_type_in_context(size_t, lean_object*);
-lean_object* lean_llvm_pass_manager_builder_set_opt_level(size_t, size_t, lean_object*, lean_object*);
 lean_object* llvm_is_declaration(size_t, size_t, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_buildAlloca___boxed(lean_object*, lean_object*, lean_object*, lean_object*, lean_object*);
 LEAN_EXPORT uint64_t l_LLVM_Visibility_hidden;
 LEAN_EXPORT lean_object* l_LLVM_getBasicBlockParent___boxed(lean_object*, lean_object*, lean_object*);
-LEAN_EXPORT lean_object* l_LLVM_createPassManager___boxed(lean_object*, lean_object*);
-lean_object* lean_llvm_dispose_pass_manager(size_t, size_t, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_i64Type(size_t, lean_object*);
 lean_object* lean_llvm_print_module_to_file(size_t, size_t, lean_object*, lean_object*);
 LEAN_EXPORT lean_object* l_LLVM_voidPtrType(size_t, lean_object*);
@@ -285,19 +271,39 @@ x_1 = 32;
 return x_1;
 }
 }
+static uint64_t _init_l_LLVM_IntPredicate_NE___closed__0() {
+_start:
+{
+uint64_t x_1; uint64_t x_2; uint64_t x_3; 
+x_1 = 1;
+x_2 = 32;
+x_3 = lean_uint64_add(x_2, x_1);
+return x_3;
+}
+}
 static uint64_t _init_l_LLVM_IntPredicate_NE() {
 _start:
 {
 uint64_t x_1; 
-x_1 = 33;
+x_1 = l_LLVM_IntPredicate_NE___closed__0;
 return x_1;
 }
 }
+static uint64_t _init_l_LLVM_IntPredicate_UGT___closed__0() {
+_start:
+{
+uint64_t x_1; uint64_t x_2; uint64_t x_3; 
+x_1 = 1;
+x_2 = l_LLVM_IntPredicate_NE;
+x_3 = lean_uint64_add(x_2, x_1);
+return x_3;
+}
+}
 static uint64_t _init_l_LLVM_IntPredicate_UGT() {
 _start:
 {
 uint64_t x_1; 
-x_1 = 34;
+x_1 = l_LLVM_IntPredicate_UGT___closed__0;
 return x_1;
 }
 }
@@ -309,32 +315,15 @@ x_1 = 0;
 return x_1;
 }
 }
-static lean_object* _init_l_LLVM_AttributeIndex_AttributeFunctionIndex___closed__1() {
-_start:
-{
-lean_object* x_1; 
-x_1 = lean_cstr_to_nat("18446744073709551615");
-return x_1;
-}
-}
-static uint64_t _init_l_LLVM_AttributeIndex_AttributeFunctionIndex___closed__2() {
-_start:
-{
-lean_object* x_1; uint64_t x_2; 
-x_1 = l_LLVM_AttributeIndex_AttributeFunctionIndex___closed__1;
-x_2 = lean_uint64_of_nat(x_1);
-return x_2;
-}
-}
 static uint64_t _init_l_LLVM_AttributeIndex_AttributeFunctionIndex() {
 _start:
 {
 uint64_t x_1; 
-x_1 = l_LLVM_AttributeIndex_AttributeFunctionIndex___closed__2;
+x_1 = 18446744073709551615ULL;
 return x_1;
 }
 }
-LEAN_EXPORT uint8_t l_LLVM_Value_isNull___rarg(size_t x_1) {
+LEAN_EXPORT uint8_t l_LLVM_Value_isNull___redArg(size_t x_1) {
 _start:
 {
 size_t x_2; uint8_t x_3; 
@@ -343,33 +332,36 @@ x_3 = lean_usize_dec_eq(x_1, x_2);
 return x_3;
 }
 }
-LEAN_EXPORT lean_object* l_LLVM_Value_isNull(size_t x_1) {
+LEAN_EXPORT uint8_t l_LLVM_Value_isNull(size_t x_1, size_t x_2) {
 _start:
 {
-lean_object* x_2; 
-x_2 = lean_alloc_closure((void*)(l_LLVM_Value_isNull___rarg___boxed), 1, 0);
-return x_2;
+uint8_t x_3; 
+x_3 = l_LLVM_Value_isNull___redArg(x_2);
+return x_3;
 }
 }
-LEAN_EXPORT lean_object* l_LLVM_Value_isNull___rarg___boxed(lean_object* x_1) {
+LEAN_EXPORT lean_object* l_LLVM_Value_isNull___redArg___boxed(lean_object* x_1) {
 _start:
 {
 size_t x_2; uint8_t x_3; lean_object* x_4; 
 x_2 = lean_unbox_usize(x_1);
 lean_dec(x_1);
-x_3 = l_LLVM_Value_isNull___rarg(x_2);
+x_3 = l_LLVM_Value_isNull___redArg(x_2);
 x_4 = lean_box(x_3);
 return x_4;
 }
 }
-LEAN_EXPORT lean_object* l_LLVM_Value_isNull___boxed(lean_object* x_1) {
+LEAN_EXPORT lean_object* l_LLVM_Value_isNull___boxed(lean_object* x_1, lean_object* x_2) {
 _start:
 {
-size_t x_2; lean_object* x_3; 
-x_2 = lean_unbox_usize(x_1);
+size_t x_3; size_t x_4; uint8_t x_5; lean_object* x_6; 
+x_3 = lean_unbox_usize(x_1);
 lean_dec(x_1);
-x_3 = l_LLVM_Value_isNull(x_2);
-return x_3;
+x_4 = lean_unbox_usize(x_2);
+lean_dec(x_2);
+x_5 = l_LLVM_Value_isNull(x_3, x_4);
+x_6 = lean_box(x_5);
+return x_6;
 }
 }
 LEAN_EXPORT lean_object* l_LLVM_Value_getName___boxed(lean_object* x_1, lean_object* x_2, lean_object* x_3) {
@@ -407,7 +399,7 @@ size_t x_4; lean_object* x_5;
 x_4 = lean_unbox_usize(x_1);
 lean_dec(x_1);
 x_5 = lean_llvm_create_module(x_4, x_2, x_3);
-lean_dec(x_2);
+lean_dec_ref(x_2);
 return x_5;
 }
 }
@@ -432,7 +424,7 @@ lean_dec(x_1);
 x_6 = lean_unbox_usize(x_2);
 lean_dec(x_2);
 x_7 = lean_llvm_write_bitcode_to_file(x_5, x_6, x_3, x_4);
-lean_dec(x_3);
+lean_dec_ref(x_3);
 return x_7;
 }
 }
@@ -447,7 +439,7 @@ lean_dec(x_2);
 x_8 = lean_unbox_usize(x_4);
 lean_dec(x_4);
 x_9 = lean_llvm_add_function(x_6, x_7, x_3, x_8, x_5);
-lean_dec(x_3);
+lean_dec_ref(x_3);
 return x_9;
 }
 }
@@ -484,7 +476,7 @@ lean_dec(x_1);
 x_6 = lean_unbox_usize(x_2);
 lean_dec(x_2);
 x_7 = lean_llvm_get_named_function(x_5, x_6, x_3, x_4);
-lean_dec(x_3);
+lean_dec_ref(x_3);
 return x_7;
 }
 }
@@ -499,7 +491,7 @@ lean_dec(x_2);
 x_8 = lean_unbox_usize(x_4);
 lean_dec(x_4);
 x_9 = lean_llvm_add_global(x_6, x_7, x_3, x_8, x_5);
-lean_dec(x_3);
+lean_dec_ref(x_3);
 return x_9;
 }
 }
@@ -512,7 +504,7 @@ lean_dec(x_1);
 x_6 = lean_unbox_usize(x_2);
 lean_dec(x_2);
 x_7 = lean_llvm_get_named_global(x_5, x_6, x_3, x_4);
-lean_dec(x_3);
+lean_dec_ref(x_3);
 return x_7;
 }
 }
@@ -549,7 +541,7 @@ lean_dec(x_1);
 x_7 = lean_unbox_usize(x_2);
 lean_dec(x_2);
 x_8 = lean_llvm_build_global_string(x_6, x_7, x_3, x_4, x_5);
-lean_dec(x_3);
+lean_dec_ref(x_3);
 return x_8;
 }
 }
@@ -588,9 +580,8 @@ lean_dec(x_1);
 x_7 = lean_unbox_usize(x_2);
 lean_dec(x_2);
 x_8 = lean_unbox(x_4);
-lean_dec(x_4);
 x_9 = lean_llvm_function_type(x_6, x_7, x_3, x_8, x_5);
-lean_dec(x_3);
+lean_dec_ref(x_3);
 return x_9;
 }
 }
@@ -683,7 +674,7 @@ lean_dec(x_1);
 x_6 = lean_unbox_usize(x_2);
 lean_dec(x_2);
 x_7 = lean_llvm_const_array(x_5, x_6, x_3, x_4);
-lean_dec(x_3);
+lean_dec_ref(x_3);
 return x_7;
 }
 }
@@ -694,7 +685,7 @@ size_t x_4; lean_object* x_5;
 x_4 = lean_unbox_usize(x_1);
 lean_dec(x_1);
 x_5 = lean_llvm_const_string(x_4, x_2, x_3);
-lean_dec(x_2);
+lean_dec_ref(x_2);
 return x_5;
 }
 }
@@ -741,7 +732,7 @@ lean_dec(x_1);
 x_6 = lean_unbox_usize(x_2);
 lean_dec(x_2);
 x_7 = lean_llvm_append_basic_block_in_context(x_5, x_6, x_3, x_4);
-lean_dec(x_3);
+lean_dec_ref(x_3);
 return x_7;
 }
 }
@@ -820,7 +811,7 @@ lean_dec(x_3);
 x_11 = lean_unbox_usize(x_4);
 lean_dec(x_4);
 x_12 = lean_llvm_build_call2(x_8, x_9, x_10, x_11, x_5, x_6, x_7);
-lean_dec(x_5);
+lean_dec_ref(x_5);
 return x_12;
 }
 }
@@ -833,7 +824,6 @@ lean_dec(x_1);
 x_6 = lean_unbox_usize(x_2);
 lean_dec(x_2);
 x_7 = lean_unbox(x_3);
-lean_dec(x_3);
 x_8 = lean_llvm_set_tail_call(x_5, x_6, x_7, x_4);
 return x_8;
 }
@@ -955,7 +945,7 @@ lean_dec(x_3);
 x_11 = lean_unbox_usize(x_4);
 lean_dec(x_4);
 x_12 = lean_llvm_build_gep2(x_8, x_9, x_10, x_11, x_5, x_6, x_7);
-lean_dec(x_5);
+lean_dec_ref(x_5);
 return x_12;
 }
 }
@@ -972,7 +962,7 @@ lean_dec(x_3);
 x_11 = lean_unbox_usize(x_4);
 lean_dec(x_4);
 x_12 = lean_llvm_build_inbounds_gep2(x_8, x_9, x_10, x_11, x_5, x_6, x_7);
-lean_dec(x_5);
+lean_dec_ref(x_5);
 return x_12;
 }
 }
@@ -1209,7 +1199,6 @@ lean_dec(x_2);
 x_8 = lean_unbox_uint64(x_3);
 lean_dec(x_3);
 x_9 = lean_unbox(x_4);
-lean_dec(x_4);
 x_10 = lean_llvm_const_int(x_6, x_7, x_8, x_9, x_5);
 return x_10;
 }
@@ -1235,7 +1224,7 @@ lean_dec(x_1);
 x_6 = lean_unbox_usize(x_2);
 lean_dec(x_2);
 x_7 = lean_llvm_print_module_to_file(x_5, x_6, x_3, x_4);
-lean_dec(x_3);
+lean_dec_ref(x_3);
 return x_7;
 }
 }
@@ -1272,7 +1261,7 @@ size_t x_4; lean_object* x_5;
 x_4 = lean_unbox_usize(x_1);
 lean_dec(x_1);
 x_5 = lean_llvm_create_memory_buffer_with_contents_of_file(x_4, x_2, x_3);
-lean_dec(x_2);
+lean_dec_ref(x_2);
 return x_5;
 }
 }
@@ -1317,7 +1306,7 @@ size_t x_4; lean_object* x_5;
 x_4 = lean_unbox_usize(x_1);
 lean_dec(x_1);
 x_5 = lean_llvm_get_target_from_triple(x_4, x_2, x_3);
-lean_dec(x_2);
+lean_dec_ref(x_2);
 return x_5;
 }
 }
@@ -1330,9 +1319,9 @@ lean_dec(x_1);
 x_8 = lean_unbox_usize(x_2);
 lean_dec(x_2);
 x_9 = lean_llvm_create_target_machine(x_7, x_8, x_3, x_4, x_5, x_6);
-lean_dec(x_5);
-lean_dec(x_4);
-lean_dec(x_3);
+lean_dec_ref(x_5);
+lean_dec_ref(x_4);
+lean_dec_ref(x_3);
 return x_9;
 }
 }
@@ -1349,94 +1338,10 @@ lean_dec(x_3);
 x_10 = lean_unbox_uint64(x_5);
 lean_dec(x_5);
 x_11 = lean_llvm_target_machine_emit_to_file(x_7, x_8, x_9, x_4, x_10, x_6);
-lean_dec(x_4);
+lean_dec_ref(x_4);
 return x_11;
 }
 }
-LEAN_EXPORT lean_object* l_LLVM_createPassManager___boxed(lean_object* x_1, lean_object* x_2) {
-_start:
-{
-size_t x_3; lean_object* x_4; 
-x_3 = lean_unbox_usize(x_1);
-lean_dec(x_1);
-x_4 = lean_llvm_create_pass_manager(x_3, x_2);
-return x_4;
-}
-}
-LEAN_EXPORT lean_object* l_LLVM_disposePassManager___boxed(lean_object* x_1, lean_object* x_2, lean_object* x_3) {
-_start:
-{
-size_t x_4; size_t x_5; lean_object* x_6; 
-x_4 = lean_unbox_usize(x_1);
-lean_dec(x_1);
-x_5 = lean_unbox_usize(x_2);
-lean_dec(x_2);
-x_6 = lean_llvm_dispose_pass_manager(x_4, x_5, x_3);
-return x_6;
-}
-}
-LEAN_EXPORT lean_object* l_LLVM_runPassManager___boxed(lean_object* x_1, lean_object* x_2, lean_object* x_3, lean_object* x_4) {
-_start:
-{
-size_t x_5; size_t x_6; size_t x_7; lean_object* x_8; 
-x_5 = lean_unbox_usize(x_1);
-lean_dec(x_1);
-x_6 = lean_unbox_usize(x_2);
-lean_dec(x_2);
-x_7 = lean_unbox_usize(x_3);
-lean_dec(x_3);
-x_8 = lean_llvm_run_pass_manager(x_5, x_6, x_7, x_4);
-return x_8;
-}
-}
-LEAN_EXPORT lean_object* l_LLVM_createPassManagerBuilder___boxed(lean_object* x_1, lean_object* x_2) {
-_start:
-{
-size_t x_3; lean_object* x_4; 
-x_3 = lean_unbox_usize(x_1);
-lean_dec(x_1);
-x_4 = lean_llvm_create_pass_manager_builder(x_3, x_2);
-return x_4;
-}
-}
-LEAN_EXPORT lean_object* l_LLVM_disposePassManagerBuilder___boxed(lean_object* x_1, lean_object* x_2, lean_object* x_3) {
-_start:
-{
-size_t x_4; size_t x_5; lean_object* x_6; 
-x_4 = lean_unbox_usize(x_1);
-lean_dec(x_1);
-x_5 = lean_unbox_usize(x_2);
-lean_dec(x_2);
-x_6 = lean_llvm_dispose_pass_manager_builder(x_4, x_5, x_3);
-return x_6;
-}
-}
-LEAN_EXPORT lean_object* l_LLVM_PassManagerBuilder_setOptLevel___boxed(lean_object* x_1, lean_object* x_2, lean_object* x_3, lean_object* x_4, lean_object* x_5) {
-_start:
-{
-size_t x_6; size_t x_7; lean_object* x_8; 
-x_6 = lean_unbox_usize(x_1);
-lean_dec(x_1);
-x_7 = lean_unbox_usize(x_3);
-lean_dec(x_3);
-x_8 = lean_llvm_pass_manager_builder_set_opt_level(x_6, x_7, x_4, x_5);
-return x_8;
-}
-}
-LEAN_EXPORT lean_object* l_LLVM_PassManagerBuilder_populateModulePassManager___boxed(lean_object* x_1, lean_object* x_2, lean_object* x_3, lean_object* x_4) {
-_start:
-{
-size_t x_5; size_t x_6; size_t x_7; lean_object* x_8; 
-x_5 = lean_unbox_usize(x_1);
-lean_dec(x_1);
-x_6 = lean_unbox_usize(x_2);
-lean_dec(x_2);
-x_7 = lean_unbox_usize(x_3);
-lean_dec(x_3);
-x_8 = lean_llvm_pass_manager_builder_populate_module_pass_manager(x_5, x_6, x_7, x_4);
-return x_8;
-}
-}
 LEAN_EXPORT lean_object* l_LLVM_disposeTargetMachine___boxed(lean_object* x_1, lean_object* x_2, lean_object* x_3) {
 _start:
 {
@@ -1823,45 +1728,19 @@ return x_4;
 LEAN_EXPORT lean_object* l_LLVM_voidPtrType(size_t x_1, lean_object* x_2) {
 _start:
 {
-uint64_t x_3; lean_object* x_4; 
+uint64_t x_3; lean_object* x_4; lean_object* x_5; lean_object* x_6; size_t x_7; lean_object* x_8; 
 x_3 = 8;
 x_4 = lean_llvm_int_type_in_context(x_1, x_3, x_2);
-if (lean_obj_tag(x_4) == 0)
-{
-lean_object* x_5; lean_object* x_6; size_t x_7; lean_object* x_8; 
 x_5 = lean_ctor_get(x_4, 0);
 lean_inc(x_5);
 x_6 = lean_ctor_get(x_4, 1);
 lean_inc(x_6);
-lean_dec(x_4);
+lean_dec_ref(x_4);
 x_7 = lean_unbox_usize(x_5);
 lean_dec(x_5);
 x_8 = lean_llvm_pointer_type(x_1, x_7, x_6);
 return x_8;
 }
-else
-{
-uint8_t x_9; 
-x_9 = !lean_is_exclusive(x_4);
-if (x_9 == 0)
-{
-return x_4;
-}
-else
-{
-lean_object* x_10; lean_object* x_11; lean_object* x_12; 
-x_10 = lean_ctor_get(x_4, 0);
-x_11 = lean_ctor_get(x_4, 1);
-lean_inc(x_11);
-lean_inc(x_10);
-lean_dec(x_4);
-x_12 = lean_alloc_ctor(1, 2, 0);
-lean_ctor_set(x_12, 0, x_10);
-lean_ctor_set(x_12, 1, x_11);
-return x_12;
-}
-}
-}
 }
 LEAN_EXPORT lean_object* l_LLVM_voidPtrType___boxed(lean_object* x_1, lean_object* x_2) {
 _start:
@@ -1894,16 +1773,13 @@ return x_4;
 LEAN_EXPORT lean_object* l_LLVM_constTrue(size_t x_1, lean_object* x_2) {
 _start:
 {
-lean_object* x_3; 
+lean_object* x_3; lean_object* x_4; lean_object* x_5; uint64_t x_6; uint8_t x_7; size_t x_8; lean_object* x_9; 
 x_3 = l_LLVM_i1Type(x_1, x_2);
-if (lean_obj_tag(x_3) == 0)
-{
-lean_object* x_4; lean_object* x_5; uint64_t x_6; uint8_t x_7; size_t x_8; lean_object* x_9; 
 x_4 = lean_ctor_get(x_3, 0);
 lean_inc(x_4);
 x_5 = lean_ctor_get(x_3, 1);
 lean_inc(x_5);
-lean_dec(x_3);
+lean_dec_ref(x_3);
 x_6 = 1;
 x_7 = 0;
 x_8 = lean_unbox_usize(x_4);
@@ -1911,29 +1787,6 @@ lean_dec(x_4);
 x_9 = lean_llvm_const_int(x_1, x_8, x_6, x_7, x_5);
 return x_9;
 }
-else
-{
-uint8_t x_10; 
-x_10 = !lean_is_exclusive(x_3);
-if (x_10 == 0)
-{
-return x_3;
-}
-else
-{
-lean_object* x_11; lean_object* x_12; lean_object* x_13; 
-x_11 = lean_ctor_get(x_3, 0);
-x_12 = lean_ctor_get(x_3, 1);
-lean_inc(x_12);
-lean_inc(x_11);
-lean_dec(x_3);
-x_13 = lean_alloc_ctor(1, 2, 0);
-lean_ctor_set(x_13, 0, x_11);
-lean_ctor_set(x_13, 1, x_12);
-return x_13;
-}
-}
-}
 }
 LEAN_EXPORT lean_object* l_LLVM_constTrue___boxed(lean_object* x_1, lean_object* x_2) {
 _start:
@@ -1948,16 +1801,13 @@ return x_4;
 LEAN_EXPORT lean_object* l_LLVM_constFalse(size_t x_1, lean_object* x_2) {
 _start:
 {
-lean_object* x_3; 
+lean_object* x_3; lean_object* x_4; lean_object* x_5; uint64_t x_6; uint8_t x_7; size_t x_8; lean_object* x_9; 
 x_3 = l_LLVM_i1Type(x_1, x_2);
-if (lean_obj_tag(x_3) == 0)
-{
-lean_object* x_4; lean_object* x_5; uint64_t x_6; uint8_t x_7; size_t x_8; lean_object* x_9; 
 x_4 = lean_ctor_get(x_3, 0);
 lean_inc(x_4);
 x_5 = lean_ctor_get(x_3, 1);
 lean_inc(x_5);
-lean_dec(x_3);
+lean_dec_ref(x_3);
 x_6 = 0;
 x_7 = 0;
 x_8 = lean_unbox_usize(x_4);
@@ -1965,29 +1815,6 @@ lean_dec(x_4);
 x_9 = lean_llvm_const_int(x_1, x_8, x_6, x_7, x_5);
 return x_9;
 }
-else
-{
-uint8_t x_10; 
-x_10 = !lean_is_exclusive(x_3);
-if (x_10 == 0)
-{
-return x_3;
-}
-else
-{
-lean_object* x_11; lean_object* x_12; lean_object* x_13; 
-x_11 = lean_ctor_get(x_3, 0);
-x_12 = lean_ctor_get(x_3, 1);
-lean_inc(x_12);
-lean_inc(x_11);
-lean_dec(x_3);
-x_13 = lean_alloc_ctor(1, 2, 0);
-lean_ctor_set(x_13, 0, x_11);
-lean_ctor_set(x_13, 1, x_12);
-return x_13;
-}
-}
-}
 }
 LEAN_EXPORT lean_object* l_LLVM_constFalse___boxed(lean_object* x_1, lean_object* x_2) {
 _start:
@@ -2002,44 +1829,18 @@ return x_4;
 LEAN_EXPORT lean_object* l_LLVM_constInt_x27(size_t x_1, uint64_t x_2, uint64_t x_3, uint8_t x_4, lean_object* x_5) {
 _start:
 {
-lean_object* x_6; 
+lean_object* x_6; lean_object* x_7; lean_object* x_8; size_t x_9; lean_object* x_10; 
 x_6 = lean_llvm_int_type_in_context(x_1, x_2, x_5);
-if (lean_obj_tag(x_6) == 0)
-{
-lean_object* x_7; lean_object* x_8; size_t x_9; lean_object* x_10; 
 x_7 = lean_ctor_get(x_6, 0);
 lean_inc(x_7);
 x_8 = lean_ctor_get(x_6, 1);
 lean_inc(x_8);
-lean_dec(x_6);
+lean_dec_ref(x_6);
 x_9 = lean_unbox_usize(x_7);
 lean_dec(x_7);
 x_10 = lean_llvm_const_int(x_1, x_9, x_3, x_4, x_8);
 return x_10;
 }
-else
-{
-uint8_t x_11; 
-x_11 = !lean_is_exclusive(x_6);
-if (x_11 == 0)
-{
-return x_6;
-}
-else
-{
-lean_object* x_12; lean_object* x_13; lean_object* x_14; 
-x_12 = lean_ctor_get(x_6, 0);
-x_13 = lean_ctor_get(x_6, 1);
-lean_inc(x_13);
-lean_inc(x_12);
-lean_dec(x_6);
-x_14 = lean_alloc_ctor(1, 2, 0);
-lean_ctor_set(x_14, 0, x_12);
-lean_ctor_set(x_14, 1, x_13);
-return x_14;
-}
-}
-}
 }
 LEAN_EXPORT lean_object* l_LLVM_constInt_x27___boxed(lean_object* x_1, lean_object* x_2, lean_object* x_3, lean_object* x_4, lean_object* x_5) {
 _start:
@@ -2052,7 +1853,6 @@ lean_dec(x_2);
 x_8 = lean_unbox_uint64(x_3);
 lean_dec(x_3);
 x_9 = lean_unbox(x_4);
-lean_dec(x_4);
 x_10 = l_LLVM_constInt_x27(x_6, x_7, x_8, x_9, x_5);
 return x_10;
 }
@@ -2075,7 +1875,6 @@ lean_dec(x_1);
 x_6 = lean_unbox_uint64(x_2);
 lean_dec(x_2);
 x_7 = lean_unbox(x_3);
-lean_dec(x_3);
 x_8 = l_LLVM_constInt1(x_5, x_6, x_7, x_4);
 return x_8;
 }
@@ -2098,7 +1897,6 @@ lean_dec(x_1);
 x_6 = lean_unbox_uint64(x_2);
 lean_dec(x_2);
 x_7 = lean_unbox(x_3);
-lean_dec(x_3);
 x_8 = l_LLVM_constInt8(x_5, x_6, x_7, x_4);
 return x_8;
 }
@@ -2121,7 +1919,6 @@ lean_dec(x_1);
 x_6 = lean_unbox_uint64(x_2);
 lean_dec(x_2);
 x_7 = lean_unbox(x_3);
-lean_dec(x_3);
 x_8 = l_LLVM_constInt32(x_5, x_6, x_7, x_4);
 return x_8;
 }
@@ -2144,7 +1941,6 @@ lean_dec(x_1);
 x_6 = lean_unbox_uint64(x_2);
 lean_dec(x_2);
 x_7 = lean_unbox(x_3);
-lean_dec(x_3);
 x_8 = l_LLVM_constInt64(x_5, x_6, x_7, x_4);
 return x_8;
 }
@@ -2167,7 +1963,6 @@ lean_dec(x_1);
 x_6 = lean_unbox_uint64(x_2);
 lean_dec(x_2);
 x_7 = lean_unbox(x_3);
-lean_dec(x_3);
 x_8 = l_LLVM_constIntSizeT(x_5, x_6, x_7, x_4);
 return x_8;
 }
@@ -2190,7 +1985,6 @@ lean_dec(x_1);
 x_6 = lean_unbox_uint64(x_2);
 lean_dec(x_2);
 x_7 = lean_unbox(x_3);
-lean_dec(x_3);
 x_8 = l_LLVM_constIntUnsigned(x_5, x_6, x_7, x_4);
 return x_8;
 }
@@ -2207,12 +2001,11 @@ lean_dec_ref(res);
 l_LLVM_CodegenFileType_AssemblyFile = _init_l_LLVM_CodegenFileType_AssemblyFile();
 l_LLVM_CodegenFileType_ObjectFile = _init_l_LLVM_CodegenFileType_ObjectFile();
 l_LLVM_IntPredicate_EQ = _init_l_LLVM_IntPredicate_EQ();
+l_LLVM_IntPredicate_NE___closed__0 = _init_l_LLVM_IntPredicate_NE___closed__0();
 l_LLVM_IntPredicate_NE = _init_l_LLVM_IntPredicate_NE();
+l_LLVM_IntPredicate_UGT___closed__0 = _init_l_LLVM_IntPredicate_UGT___closed__0();
 l_LLVM_IntPredicate_UGT = _init_l_LLVM_IntPredicate_UGT();
 l_LLVM_AttributeIndex_AttributeReturnIndex = _init_l_LLVM_AttributeIndex_AttributeReturnIndex();
-l_LLVM_AttributeIndex_AttributeFunctionIndex___closed__1 = _init_l_LLVM_AttributeIndex_AttributeFunctionIndex___closed__1();
-lean_mark_persistent(l_LLVM_AttributeIndex_AttributeFunctionIndex___closed__1);
-l_LLVM_AttributeIndex_AttributeFunctionIndex___closed__2 = _init_l_LLVM_AttributeIndex_AttributeFunctionIndex___closed__2();
 l_LLVM_AttributeIndex_AttributeFunctionIndex = _init_l_LLVM_AttributeIndex_AttributeFunctionIndex();
 l_LLVM_Visibility_default = _init_l_LLVM_Visibility_default();
 l_LLVM_Visibility_hidden = _init_l_LLVM_Visibility_hidden();
