@@ -1,6 +1,6 @@
 // Lean compiler output
 // Module: Std.Internal
-// Imports: Std.Internal.Parsec
+// Imports: Std.Internal.Async Std.Internal.Parsec Std.Internal.UV
 #include <lean/lean.h>
 #if defined(__clang__)
 #pragma clang diagnostic ignored "-Wunused-parameter"
@@ -13,15 +13,23 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
+lean_object* initialize_Std_Internal_Async(uint8_t builtin, lean_object*);
 lean_object* initialize_Std_Internal_Parsec(uint8_t builtin, lean_object*);
+lean_object* initialize_Std_Internal_UV(uint8_t builtin, lean_object*);
 static bool _G_initialized = false;
 LEAN_EXPORT lean_object* initialize_Std_Internal(uint8_t builtin, lean_object* w) {
 lean_object * res;
 if (_G_initialized) return lean_io_result_mk_ok(lean_box(0));
 _G_initialized = true;
+res = initialize_Std_Internal_Async(builtin, lean_io_mk_world());
+if (lean_io_result_is_error(res)) return res;
+lean_dec_ref(res);
 res = initialize_Std_Internal_Parsec(builtin, lean_io_mk_world());
 if (lean_io_result_is_error(res)) return res;
 lean_dec_ref(res);
+res = initialize_Std_Internal_UV(builtin, lean_io_mk_world());
+if (lean_io_result_is_error(res)) return res;
+lean_dec_ref(res);
 return lean_io_result_mk_ok(lean_box(0));
 }
 #ifdef __cplusplus
