@@ -1,6 +1,6 @@
 // Lean compiler output
 // Module: Std.Tactic
-// Imports: Std.Tactic.BVDecide
+// Imports: Std.Tactic.BVDecide Std.Tactic.Do
 #include <lean/lean.h>
 #if defined(__clang__)
 #pragma clang diagnostic ignored "-Wunused-parameter"
@@ -14,6 +14,7 @@
 extern "C" {
 #endif
 lean_object* initialize_Std_Tactic_BVDecide(uint8_t builtin, lean_object*);
+lean_object* initialize_Std_Tactic_Do(uint8_t builtin, lean_object*);
 static bool _G_initialized = false;
 LEAN_EXPORT lean_object* initialize_Std_Tactic(uint8_t builtin, lean_object* w) {
 lean_object * res;
@@ -22,6 +23,9 @@ _G_initialized = true;
 res = initialize_Std_Tactic_BVDecide(builtin, lean_io_mk_world());
 if (lean_io_result_is_error(res)) return res;
 lean_dec_ref(res);
+res = initialize_Std_Tactic_Do(builtin, lean_io_mk_world());
+if (lean_io_result_is_error(res)) return res;
+lean_dec_ref(res);
 return lean_io_result_mk_ok(lean_box(0));
 }
 #ifdef __cplusplus
