@@ -1,4 +1,4 @@
 #!/usr/bin/env bash
 
 rm -rf .lake/build
-lake build && ./.lake/build/bin/user_attr
+lake exe user_attr
